(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     17513,        672]*)
(*NotebookOutlinePosition[     18158,        694]*)
(*  CellTagsIndexPosition[     18114,        690]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Continuous-Stirred Tank Reactor",
  FontFamily->"Times New Roman",
  FontSize->24]], "Title",
  TextAlignment->Center,
  Background->RGBColor[0.623529, 1, 0.811765]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = 
      NDSolve[{\[IndentingNewLine]\(c'\)[t] \[Equal] 
            k1\ a[t]\ b[t] - k2\ c[t] - k0\ c[t], \[IndentingNewLine]\(a'\)[
              t] \[Equal] \(-k1\)\ a[t]\ b[t] + k2\ c[t] + 
              k0\ \((0.01 - a[t])\), \[IndentingNewLine]\(b'\)[
              t] == \(-k1\)\ a[t]\ b[t] + k2\ c[t] + k0\ \((0.02 - b[t])\), 
          a[0] \[Equal] 10^\(-2\), b[0] \[Equal] 2\ 10^\(-2\), 
          c[0] \[Equal] 0}, {a, b, c}, {t, 0, 300}]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"a", "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 300.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{"b", "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 300.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{"c", "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 300.`}}, "<>"]\),
              False,
              Editable->False]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(k1 = 1; k2 = 10^\(-2\); k0 = d/V; V = 10; d = 0.6;\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[Evaluate[1000\ c[t] /. sol], {t, 0, 300}, 
      PlotRange \[Rule] {0, 8}, 
      PlotStyle \[Rule] RGBColor[1, 0, 0]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0031746 0 0.0772542 [
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -9 -9 ]
[.65873 -0.0125 9 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -6 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -6 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -6 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -6 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 0 m
.18254 .00625 L
s
[(50)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(100)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(150)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(200)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(250)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(300)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(1)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(2)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(4)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(6)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(7)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(8)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 0 m
.03279 .03807 L
.04262 .06919 L
.05288 .09301 L
.06244 .10935 L
.0731 .12273 L
.0828 .13165 L
.094 .13916 L
.10458 .14425 L
.11428 .14768 L
.12455 .15036 L
.13333 .15208 L
.14299 .15351 L
.15313 .15462 L
.1624 .15538 L
.17311 .15603 L
.18328 .15648 L
.19287 .15679 L
.20309 .15704 L
.21273 .15722 L
.22147 .15734 L
.2315 .15744 L
.24072 .15751 L
.25085 .15757 L
.26154 .15761 L
.27102 .15764 L
.28118 .15766 L
.29077 .15768 L
.29951 .15769 L
.30943 .1577 L
.3186 .15771 L
.32866 .15771 L
.33936 .15772 L
.34873 .15772 L
.35883 .15772 L
.36837 .15772 L
.37711 .15773 L
.38691 .15773 L
.39603 .15773 L
.40604 .15773 L
.41673 .15773 L
.42698 .15773 L
.43808 .15773 L
.44856 .15773 L
.45823 .15773 L
.46792 .15773 L
.47699 .15773 L
.48694 .15773 L
.49763 .15773 L
.50776 .15773 L
Mistroke
.51881 .15773 L
.52924 .15773 L
.53891 .15773 L
.5495 .15773 L
.55947 .15773 L
.57809 .15773 L
.58788 .15773 L
.59821 .15773 L
.60703 .15773 L
.61203 .15773 L
.61669 .15773 L
.62172 .15773 L
.62455 .15773 L
.62591 .15773 L
.62717 .15773 L
.62837 .15773 L
.62946 .15773 L
.63068 .15773 L
.63198 .15773 L
.63317 .15773 L
.63447 .15773 L
.63513 .15773 L
.63583 .15773 L
.63709 .15773 L
.63834 .15773 L
.63949 .15773 L
.6421 .15773 L
.64439 .15773 L
.64682 .15773 L
.65566 .15773 L
.66512 .15773 L
.67527 .15773 L
.68478 .15773 L
.6936 .15773 L
.70375 .15773 L
.70911 .15773 L
.71185 .15773 L
.71481 .15773 L
.71738 .15773 L
.71851 .15773 L
.71974 .15773 L
.72083 .15773 L
.72199 .15773 L
.72322 .15773 L
.72437 .15773 L
.72508 .15773 L
.72573 .15773 L
.72645 .15773 L
.72721 .15773 L
.72849 .15773 L
Mistroke
.72922 .15773 L
.7299 .15773 L
.73116 .15773 L
.73232 .15773 L
.73492 .15773 L
.73743 .15773 L
.7397 .15773 L
.74478 .15773 L
.75392 .15773 L
.76472 .15773 L
.77465 .15773 L
.78384 .15773 L
.79391 .15773 L
.79915 .15773 L
.80404 .15773 L
.80921 .15773 L
.8121 .15773 L
.81346 .15773 L
.81474 .15773 L
.81593 .15773 L
.81703 .15773 L
.81824 .15773 L
.81955 .15773 L
.82074 .15773 L
.82204 .15773 L
.8227 .15773 L
.8234 .15773 L
.82466 .15773 L
.82585 .15773 L
.82714 .15773 L
.82947 .15773 L
.83174 .15773 L
.83384 .15773 L
.83901 .15773 L
.84457 .15773 L
.84981 .15773 L
.8546 .15773 L
.85922 .15773 L
.86424 .15773 L
.86898 .15773 L
.87338 .15773 L
.88402 .15773 L
.88924 .15773 L
.89403 .15773 L
.89884 .15773 L
.90392 .15773 L
.90945 .15773 L
.91461 .15773 L
.91926 .15773 L
.92349 .15773 L
Mistroke
.9282 .15773 L
.93323 .15773 L
.93806 .15773 L
.94318 .15773 L
.94755 .15773 L
.95237 .15773 L
.95753 .15773 L
.96309 .15773 L
.96834 .15773 L
.97315 .15773 L
.97619 .15773 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000iOol2
0004Ool2000MOol50002Ool20004Ool2000JOol50002Ool20004Ool2000JOol40003Ool20004Ool2
000JOol40003Ool20004Ool2000LOol20004Ool20004Ool2000>Ool003Qoo`04001oogoo0002Ool0
1000Oomoo`007Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`0IOol01@00Oomo
ogoo00000Woo00@007ooOol0009oo`03001oogoo01Moo`03001oogoo00=oo`04001oogoo0002Ool0
1000Oomoo`006Goo00<007ooOol00goo00@007ooOol0009oo`04001oogoo000JOol01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000=Ool003]oo`04001oogoo0002Ool00`00Oomoo`0LOol0
1@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo01Uoo`03001oogoo00Aoo`04001oogoo
0002Ool00`00Oomoo`0HOol00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol001Yoo`03001o
ogoo00Eoo`04001oogoo0002Ool00`00Oomoo`0JOol01@00Oomoogoo00000Woo00@007ooOol0009o
o`03001oogoo00]oo`00>Goo0P000goo00@007ooOol001ioo`05001oogooOol00002Ool01000Oomo
o`000Woo00<007ooOol06Goo00<007ooOol00Woo0P000goo00@007ooOol001]oo`05001oogooOol0
0002Ool01000Oomoo`000Woo00<007ooOol06Goo00<007ooOol00Woo0P000goo00@007ooOol001eo
o`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol02goo000iOol00`00Oomoo`02Ool01000
Oomoo`007Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`0IOol00`00Oomoo`02
Ool00`00Oomoo`02Ool01000Oomoo`006Goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`006Goo00@007ooOol000=oo`03001oogoo009oo`04001oogoo000JOol01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000=Ool003Uoo`<000=oo`8001ioo`8000Aoo`8000Aoo`8001]oo`80
00Aoo`<000=oo`8001]oo`8000Aoo`8000Aoo`8001]oo`8000Aoo`<000=oo`8001aoo`8000Aoo`80
00Aoo`8000ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000ioool000D0
00ioo`0057oo00=l07ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol01Woo00<007ooOol04Woo000DOol00g`0Oomoo`3oOol:Ool001Aoo`03001l07oo0?moo`Yo
o`0057oo00<007`0Ool0ogoo2Woo000DOol00`00O01oo`3oOol:Ool001Aoo`03001l07oo0?moo`Yo
o`0057oo00<007`0Ool0ogoo2Woo000DOol200000g`0Oomoo`3oOol8Ool001Aoo`03001oog`00?mo
o`Yoo`0057oo00<007ooO000ogoo2Woo000DOol00`00Ooml003oOol:Ool001Aoo`800003Ooml07oo
0?moo`Qoo`0057oo00@007ooOoml0?moo`Uoo`0057oo00D007ooOomoog`00?moo`Qoo`0057oo00D0
07ooOomoog`00?moo`Qoo`0057oo0P000Woo00=l07ooOol0ogoo1Woo000DOol00`00Oomoo`02Ool0
0g`0Oomoo`3oOol5Ool000]oo`D000Aoo`03001oogoo009oo`03O01oogoo0?moo`Eoo`003Goo00<0
07ooOol017oo00<007ooOol00Woo00=l07ooOol0ogoo1Goo000=Ool00`00Oomoo`04Ool20004Ool0
0g`0Oomoo`3oOol4Ool000eoo`03001oogoo00Aoo`03001oogoo00=oo`03O01oogoo0?moo`Aoo`00
3Goo00<007ooOol017oo00<007ooOol00goo00=l07ooOol0ogoo17oo000<Ool20006Ool00`00Oomo
o`04Ool00g`0Oomoo`3oOol3Ool001Aoo`8000Eoo`03O01oogoo0?moo`=oo`0057oo00<007ooOol0
1Goo00=l07ooOol0ogoo0Woo000DOol00`00Oomoo`06Ool00g`0Oomoo`3oOol1Ool001Aoo`03001o
ogoo00Ioo`03O01oogoo0?moo`5oo`0057oo0P0027oo00=l07ooOol0ogoo000DOol00`00Oomoo`08
Ool00g`0Oomoo`3nOol001Aoo`03001oogoo00Qoo`03O01oogoo0?ioo`0057oo00<007ooOol02Goo
00=l07ooOol0oGoo000DOol2000:Ool00g`0Oomoo`3mOol001Aoo`03001oogoo00Yoo`9l0?eoo`00
57oo00<007ooOol037oo00=l07ooOol0nWoo000DOol00`00Oomoo`0=Ool2O03jOol001Aoo`80011o
o`9l0?Qoo`0057oo00<007ooOol04Goo0W`0mWoo000;Ool40005Ool00`00Oomoo`0COol3O03cOol0
00]oo`03001oogoo00Ioo`03001oogoo01Ioo`El0>ioo`0037oo00<007ooOol01Goo0P0077oo3g`0
ggoo000=Ool00`00Oomoo`04Ool00`00Oomoo`0ZOoo;O00DOol000]oo`04001oogoo0005Ool00`00
Oomoo`3oOol:Ool000aoo`8000Ioo`03001oogoo0?moo`Yoo`0057oo0P00ogoo2goo000DOol00`00
Oomoo`3oOol:Ool001Aoo`03001oogoo0?moo`Yoo`0057oo00<007ooOol0ogoo2Woo000DOol2003o
Ool;Ool001Aoo`03001oogoo0?moo`Yoo`0057oo00<007ooOol0ogoo2Woo000DOol00`00Oomoo`3o
Ool:Ool001Aoo`800?moo`]oo`0057oo00<007ooOol0ogoo2Woo000DOol00`00Oomoo`3oOol:Ool0
01Aoo`03001oogoo0?moo`Yoo`0057oo0P00ogoo2goo000DOol00`00Oomoo`3oOol:Ool000aoo`80
00Ioo`03001oogoo0?moo`Yoo`002goo00@007ooOol000Eoo`03001oogoo0?moo`Yoo`003Goo00<0
07ooOol017oo0P00ogoo2goo000>Ool00`00Oomoo`03Ool00`00Oomoo`3oOol:Ool000]oo`04001o
ogoo0005Ool00`00Oomoo`3oOol:Ool000aoo`8000Ioo`03001oogoo0?moo`Yoo`0057oo0P00ogoo
2goo000DOol00`00Oomoo`3oOol:Ool001Aoo`03001oogoo0?moo`Yoo`0057oo00<007ooOol0ogoo
2Woo000DOol2003oOol;Ool001Aoo`03001oogoo0?moo`Yoo`0057oo00<007ooOol0ogoo2Woo000D
Ool00`00Oomoo`3oOol:Ool001Aoo`800?moo`]oo`0057oo00<007ooOol0ogoo2Woo000DOol00`00
Oomoo`3oOol:Ool001Aoo`03001oogoo0?moo`Yoo`0057oo0P00ogoo2goo000DOol00`00Oomoo`3o
Ool:Ool000eoo`<000Aoo`03001oogoo0?moo`Yoo`003Woo00<007ooOol00goo00<007ooOol0ogoo
2Woo000;Ool50004Ool2003oOol;Ool000]oo`04001oogoo0005Ool00`00Oomoo`3oOol:Ool000ao
o`03001oo`0000Eoo`03001oogoo0?moo`Yoo`003Goo0P001Goo00<007ooOol0ogoo2Woo000DOol2
003oOol;Ool001Aoo`03001oogoo0?moo`Yoo`0057oo00<007ooOol0ogoo2Woo000DOol00`00Oomo
o`3oOol:Ool001Aoo`800?moo`]oo`0057oo00<007ooOol0ogoo2Woo000DOol00`00Oomoo`3oOol:
Ool001Aoo`03001oogoo0?moo`Yoo`0057oo0P00ogoo2goo000DOol00`00Oomoo`3oOol:Ool001Ao
o`03001oogoo0?moo`Yoo`0057oo00<007ooOol0ogoo2Woo000DOol2003oOol;Ool001Aoo`03001o
ogoo0?moo`Yoo`0037oo0P001Woo00<007ooOol0ogoo2Woo000;Ool01000Oomoo`001Goo00<007oo
Ool0ogoo2Woo000>Ool00`00Oomoo`03Ool2003oOol;Ool000aoo`8000Ioo`03001oogoo0?moo`Yo
o`0037oo00<007ooOol01Goo00<007ooOol0ogoo2Woo000<Ool30005Ool00`00Oomoo`3oOol:Ool0
01Aoo`800?moo`]oo`0057oo00<007ooOol0ogoo2Woo000DOol00`00Oomoo`3oOol:Ool001Aoo`03
001oogoo0?moo`Yoo`0057oo0P00ogoo2goo000DOol00`00Oomoo`3oOol:Ool001Aoo`03001oogoo
0?moo`Yoo`0057oo00<007ooOol0ogoo2Woo000DOol2003oOol;Ool001Aoo`03001oogoo0?moo`Yo
o`0057oo00<007ooOol0ogoo2Woo000DOol00`00Oomoo`3oOol:Ool001Aoo`800?moo`]oo`0057oo
00<007ooOol0ogoo2Woo000;Ool30006Ool00`00Oomoo`3oOol:Ool000]oo`04001oogoo0005Ool0
0`00Oomoo`3oOol:Ool000]oo`04001oogoo0005Ool2003oOol;Ool000]oo`<000Ioo`03001oogoo
0?moo`Yoo`0037oo00<007ooOol01Goo00<007ooOol0ogoo2Woo000<Ool30005Ool00`00Oomoo`3o
Ool:Ool001Aoo`800?moo`]oo`0057oo00<007ooOol0ogoo2Woo000DOol00`00Oomoo`3oOol:Ool0
01Aoo`03001oogoo0?moo`Yoo`0057oo0P00ogoo2goo000DOol00`00Oomoo`3oOol:Ool001Aoo`03
001oogoo0?moo`Yoo`0057oo00<007ooOol0ogoo2Woo000DOol2003oOol;Ool001Aoo`03001oogoo
0?moo`Yoo`0057oo00<007ooOol0ogoo2Woo000DOol00`00Oomoo`3oOol:Ool001Aoo`800?moo`]o
o`0057oo00<007ooOol0ogoo2Woo000=Ool00`00Oomoo`04Ool00`00Oomoo`3oOol:Ool000eoo`03
001oogoo00Aoo`03001oogoo0?moo`Yoo`003Goo00<007ooOol017oo0P00ogoo2goo000>Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol:Ool000]oo`04001oogoo0005Ool00`00Oomoo`3oOol:Ool000]o
o`@000Eoo`03001oogoo0?moo`Yoo`0057oo0P00ogoo2goo000DOol00`00Oomoo`3oOol:Ool001Ao
o`03001oogoo0?moo`Yoo`0057oo00<007ooOol0ogoo2Woo000DOol2003oOol;Ool001Aoo`03001o
ogoo0?moo`Yoo`0057oo00<007ooOol0ogoo2Woo000DOol00`00Oomoo`3oOol:Ool001Aoo`800?mo
o`]oo`0057oo00<007ooOol0ogoo2Woo000DOol00`00Oomoo`3oOol:Ool001Aoo`03001oogoo0?mo
o`Yoo`0057oo0P00ogoo2goo000DOol00`00Oomoo`3oOol:Ool000aoo`8000Ioo`03001oogoo0?mo
o`Yoo`002goo00@007ooOol000Eoo`03001oogoo0?moo`Yoo`002goo00@007ooOol000Eoo`800?mo
o`]oo`0037oo0P00ogoo4goo000;Ool01000Oomoo`00ogoo4Woo000<Ool2003oOolCOol00?moob5o
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-24.5356, -0.611292, \
1.21526, 0.0499386}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowSize->{496, 537},
WindowMargins->{{27, Automatic}, {Automatic, 29}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 189, 4, 94, "Title"],

Cell[CellGroupData[{
Cell[1990, 61, 487, 8, 130, "Input"],
Cell[2480, 71, 581, 15, 67, "Output"]
}, Open  ]],
Cell[3076, 89, 83, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[3184, 94, 156, 3, 50, "Input"],
Cell[3343, 99, 14009, 564, 186, 6636, 468, "GraphicsData", "PostScript", \
"Graphics"],
Cell[17355, 665, 130, 3, 29, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

