(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     61208,       2019]*)
(*NotebookOutlinePosition[     61873,       2042]*)
(*  CellTagsIndexPosition[     61829,       2038]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Isobar VLE Calculations \nCase of Ethanol-Water \
Binary System",
  FontSize->20]], "Title",
  TextAlignment->Center,
  Background->RGBColor[0.623529, 1, 0.811765]],

Cell[CellGroupData[{

Cell["Vapor pressure using Antoine's equation", "Subsubtitle",
  Background->RGBColor[0.929702, 0.996109, 0.566415]],

Cell[BoxData[{
    \(A1 = 8.07131; B1 = 1730.630; C1 = 233.426;\), "\[IndentingNewLine]", 
    \(A2 = 8.11220; B2 = 1592.864; C2 = 226.184;\)}], "Input"],

Cell[BoxData[{
    \(\(PS2 = 10^\((A1 - B1/\((C1 + T)\))\);\)\), "\[IndentingNewLine]", 
    \(\(PS1 = 10^\((A2 - B2/\((C2 + T)\))\);\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Boiling temperatures at 1 atm ", "Subsubtitle",
  Background->RGBColor[0.929702, 0.996109, 0.566415]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindRoot[PS1 \[Equal] \ 760, \ {T, 100}]\)], "Input"],

Cell[BoxData[
    \({T \[Rule] 78.29819188122651`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindRoot[PS2 \[Equal] \ 760, \ {T, 100}]\)], "Input"],

Cell[BoxData[
    \({T \[Rule] 99.99682973671642`}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Activity coefficients using Van Laar's model", "Subsubtitle",
  Background->RGBColor[0.929702, 0.996109, 0.566415]],

Cell[BoxData[{
    \(G1[i_] := 
      Exp[A12\ \((A21\ \((1 - x[i])\)/\((A12\ x[i] + 
                      A21\ \((1 - x[i])\))\))\)^2]\), "\[IndentingNewLine]", 
    \(G2[i_] := 
      Exp[A21\ \((A12\ x[
                    i]/\((A12\ x[i] + 
                      A21\ \((1 - x[i])\))\))\)^2]\)}], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(A12 = 1.6798; A21 = 0.9227;\)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Total Pressure ", "Subsubtitle",
  Background->RGBColor[0.929702, 0.996109, 0.566415]],

Cell[BoxData[
    \(i = 0; P = 760; T =. \)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["While loop to get bubble temperature and vapor mole fraction", \
"Subsubtitle",
  Background->RGBColor[0.929702, 0.996109, 0.566415]],

Cell[BoxData[
    \(While[
      i < 101, {x[i] = i\ 0.01, 
        T[i] = \(FindRoot[
              P \[Equal] \ PS1\ G1[i]\ x[i] + PS2\ G2[i]\ \((1 - x[i])\), {T, 
                80}]\)[\([1, 2]\)], 
        y[i] = PS1\ G1[i]\ x[i]/P /. T \[Rule] \ T[i], \(i++\)}]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Ploting the VLE data  ", "Subsubtitle",
  Background->RGBColor[0.929702, 0.996109, 0.566415]],

Cell[BoxData[
    \(\(tb = Table[{x[i], y[i]}, {i, 0, 100}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(plt1 = 
      ListPlot[tb, PlotStyle \[Rule] RGBColor[1, 0, 0], 
        PlotJoined \[Rule] \ True, 
        Epilog \[Rule] \ {RGBColor[0, 1, 0], 
            Line[{{0, 0}, {1, 1}}]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .01472 m
.03333 .075 L
.04286 .12006 L
.05238 .15491 L
.0619 .18259 L
.07143 .20506 L
.08095 .22363 L
.09048 .2392 L
.1 .25244 L
.10952 .26382 L
.11905 .27369 L
.12857 .28235 L
.1381 .29 L
.14762 .29681 L
.15714 .30293 L
.16667 .30844 L
.17619 .31346 L
.18571 .31805 L
.19524 .32227 L
.20476 .32618 L
.21429 .32982 L
.22381 .33323 L
.23333 .33643 L
.24286 .33947 L
.25238 .34235 L
.2619 .3451 L
.27143 .34775 L
.28095 .35029 L
.29048 .35276 L
.3 .35516 L
.30952 .3575 L
.31905 .3598 L
.32857 .36205 L
.3381 .36427 L
.34762 .36647 L
.35714 .36866 L
.36667 .37083 L
.37619 .37299 L
.38571 .37515 L
.39524 .37732 L
.40476 .37949 L
.41429 .38167 L
.42381 .38387 L
.43333 .38608 L
.44286 .38831 L
.45238 .39057 L
.4619 .39285 L
.47143 .39516 L
.48095 .3975 L
.49048 .39987 L
Mistroke
.5 .40227 L
.50952 .40471 L
.51905 .40719 L
.52857 .40971 L
.5381 .41227 L
.54762 .41487 L
.55714 .41752 L
.56667 .42021 L
.57619 .42296 L
.58571 .42575 L
.59524 .42859 L
.60476 .43149 L
.61429 .43444 L
.62381 .43744 L
.63333 .4405 L
.64286 .44362 L
.65238 .4468 L
.6619 .45004 L
.67143 .45335 L
.68095 .45672 L
.69048 .46015 L
.7 .46365 L
.70952 .46723 L
.71905 .47087 L
.72857 .47458 L
.7381 .47837 L
.74762 .48224 L
.75714 .48618 L
.76667 .4902 L
.77619 .4943 L
.78571 .49849 L
.79524 .50276 L
.80476 .50712 L
.81429 .51157 L
.82381 .51611 L
.83333 .52074 L
.84286 .52547 L
.85238 .5303 L
.8619 .53523 L
.87143 .54027 L
.88095 .54541 L
.89048 .55066 L
.9 .55602 L
.90952 .56149 L
.91905 .56709 L
.92857 .5728 L
.9381 .57864 L
.94762 .58461 L
.95714 .59071 L
.96667 .59694 L
Mistroke
.97619 .60332 L
Mfstroke
0 1 0 r
.02381 .01472 m
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0012Ool2
0004Ool20003Ool4000UOol20004Ool20005Ool3000SOol20004Ool20003Ool3000VOol20004Ool2
0004Ool2000[Ool50005Ool0045oo`04001oogoo0008Ool00`00Oomoo`0UOol01000Oomoo`002goo
00<007ooOol08Goo00@007ooOol000Qoo`04001oogoo000TOol01000Oomoo`0027oo00@007ooOol0
02aoo`03001oogoo00Eoo`00@Goo00@007ooOol000Uoo`03001oogoo02Aoo`04001oogoo0008Ool5
000ROol01000Oomoo`0027oo00@007ooOol002Aoo`04001oogoo0008Ool01000Oomoo`00;7oo00<0
07ooOol01Goo0011Ool01000Oomoo`002Woo00<007ooOol08goo00@007ooOol000Qoo`04001oogoo
000SOol01000Oomoo`0027oo0`009Goo00@007ooOol000Uoo`8002eoo`03001oogoo00Eoo`00@Goo
00@007ooOol000Qoo`04001oogoo000TOol01000Oomoo`002Goo00<007oo00008goo00@007ooOol0
00Uoo`03001oogoo02Aoo`04001oogoo0008Ool01000Oomoo`00;7oo00<007ooOol01Goo0012Ool2
000:Ool2000VOol2000;Ool2000TOol2000:Ool3000UOol2000:Ool2000/Ool20007Ool00?moob5o
o`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uo
o`005Goo00<007ooOol0ogoo2Goo000?Ool600000`?P0000003o00080001Ool001Eoo`03O003h0?P
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Eoo`005Goo00=l07ooOol00P?P;goo00<007ooOol0<Goo00<007ooOol0<7oo00<007ooOol0<Goo
00<007ooOol0<Goo00<007ooOol01Goo000EOol00`00O01oo`02Ool00`?POomoo`3oOol4Ool001Eo
o`03001l07oo00=oo`83h?moo`Aoo`005Goo00<007`0Ool01Goo00<3h7ooOol0ogoo0Goo000EOol0
0`00O01oo`06Ool20n3oOol1Ool001Eoo`03001l07oo00Qoo`83h?ioo`005Goo0P0000=l07ooOol0
27oo00<3h7ooOol0ngoo000EOol00`00Ooml000;Ool20n3kOol001Eoo`03001oog`000eoo`030n1o
ogoo0?Qoo`005Goo00<007ooO0003Woo0P?Pn7oo000EOol00`00Ooml000@Ool20n3fOol001Eoo`03
001oog`0019oo`030n1oogoo0?=oo`005Goo00@007ooOoml019oo`83h?=oo`005Goo00@007ooOoml
01Aoo`83h?5oo`005Goo0P0000=oog`0Ool05Goo00<3h7ooOol0kWoo000EOol01000Oomoog`05goo
0P?PkWoo000EOol01000Oomoog`06Goo00<3h7ooOol0jgoo000EOol01000Oomoog`06Woo0P?Pjgoo
000EOol01@00OomoogooO0006goo0P?PjGoo000EOol01@00OomoogooO0007Goo00<3h7ooOol0iWoo
000EOol01@00OomoogooO0007Woo0P?PiWoo000EOol01@00OomoogooO00087oo0P?Pi7oo000EOol2
0002Ool00g`0Oomoo`0POol00`?POomoo`3QOol001Eoo`05001oogooOoml000SOol20n3QOol001Eo
o`03001oogoo009oo`03O01oogoo029oo`030n1oogoo0=ioo`005Goo00<007ooOol00Woo00=l07oo
Ool08goo0P?PgWoo000EOol00`00Oomoo`02Ool00g`0Oomoo`0UOol20n3LOol001Eoo`03001oogoo
009oo`03O01oogoo02Moo`030n1oogoo0=Uoo`000Woo0P0017oo0P000goo100017oo00<007ooOol0
0Woo00=l07ooOol0:7oo0P?PfGoo00001Goo001oogoo000027oo00<007ooOol01Goo00<007ooOol0
0goo00=l07ooOol0:Goo00<3h7ooOol0eWoo00001Goo001oogoo00002Goo00<007ooOol017oo0`00
0goo00=l07ooOol0:Woo0P?PeWoo00001Goo001oogoo00002Woo00<007ooOol00goo00<007ooOol0
0goo00=l07ooOol0;7oo0P?Pe7oo00001Goo001oogoo000027oo00@007ooOol000Aoo`03001oogoo
00Aoo`03O01oogoo02eoo`030n1oogoo0=5oo`000Woo0P002Woo0P001Goo00<007ooOol017oo00=l
07ooOol0;Woo0P?PdGoo000EOol00`00Oomoo`04Ool00g`0Oomoo`0`Ool20n3?Ool001Eoo`03001o
ogoo00Eoo`03O01oogoo035oo`030n1oogoo0<aoo`005Goo00<007ooOol01Goo00=l07ooOol0<Woo
0P?Pc7oo000EOol00`00Oomoo`05Ool00g`0Oomoo`0dOol00`?POomoo`39Ool001Eoo`8000Moo`03
O01oogoo03Aoo`83h<Uoo`005Goo00<007ooOol01Woo00=l07ooOol0=Woo0P?Pagoo000EOol00`00
Oomoo`06Ool00g`0Oomoo`0hOol00`?POomoo`34Ool001Eoo`03001oogoo00Ioo`03O01oogoo03Uo
o`83h<Aoo`005Goo00<007ooOol01goo00=l07ooOol0>Woo0P?P`Woo000EOol00`00Oomoo`07Ool0
0g`0Oomoo`0lOol00`?POomoo`2oOol001Eoo`03001oogoo00Moo`03O01oogoo03eoo`83h;moo`00
5Goo00<007ooOol027oo00=l07ooOol0?Woo00<3h7ooOol0_7oo000EOol20009Ool00g`0Oomoo`0o
Ool20n2lOol001Eoo`03001oogoo00Uoo`03O01oogoo041oo`83h;Yoo`005Goo00<007ooOol02Goo
00=l07ooOol0@Woo00<3h7ooOol0]goo000EOol00`00Oomoo`0:Ool00g`0Oomoo`12Ool20n2gOol0
01Eoo`03001oogoo00Yoo`03O01oogoo04Aoo`030n1oogoo0;Aoo`005Goo00<007ooOol02goo00=l
07ooOol0A7oo0P?P]7oo000EOol00`00Oomoo`0;Ool00g`0Oomoo`16Ool20n2bOol001Eoo`03001o
ogoo00aoo`03O01oogoo04Moo`030n1oogoo0:moo`005Goo0P003Goo00=l07ooOol0B7oo0P?P[goo
000EOol00`00Oomoo`0=Ool00g`0Oomoo`19Ool20n2]Ool001Eoo`03001oogoo00ioo`03O01oogoo
04Yoo`030n1oogoo0:Yoo`005Goo00<007ooOol03Woo00=l07ooOol0Bgoo0P?PZWoo000EOol00`00
Oomoo`0?Ool00g`0Oomoo`1<Ool00`?POomoo`2WOol001Eoo`03001oogoo00moo`03O01oogoo04eo
o`83h:Moo`000Woo0P0017oo0P001Goo0`000goo00<007ooOol047oo00=l07ooOol0CWoo0P?PYGoo
00001Goo001oogoo00002goo00<007ooOol00Woo00<007ooOol04Goo00=l07ooOol0Cgoo00<3h7oo
Ool0XWoo00001Goo001oogoo000027oo1@000goo0`004Goo00=l07ooOol0D7oo0P?PXWoo00001Goo
001oogoo000027oo00@007ooOol000Aoo`03001oogoo019oo`03O01oogoo055oo`83h:1oo`0000Eo
o`00Oomoo`0000Uoo`03001oo`0000Aoo`03001oogoo01=oo`03O01oogoo059oo`030n1oogoo09eo
o`000Woo0P002goo0P0017oo00<007ooOol04goo00=l07ooOol0Dgoo0P?PWGoo000EOol00`00Oomo
o`0DOol00g`0Oomoo`1DOol00`?POomoo`2JOol001Eoo`03001oogoo01Eoo`9l05Eoo`83h9Yoo`00
5Goo00<007ooOol05goo00=l07ooOol0E7oo0P?PV7oo000EOol00`00Oomoo`0HOol00g`0Oomoo`1E
Ool00`?POomoo`2EOol001Eoo`8001Uoo`03O01oogoo05Ioo`83h9Eoo`005Goo00<007ooOol06Goo
00=l07ooOol0Egoo00<3h7ooOol0TWoo000EOol00`00Oomoo`0JOol2O01HOol20n2BOol001Eoo`03
001oogoo01aoo`03O01oogoo05Moo`83h91oo`005Goo00<007ooOol07Goo0W`0FGoo00<3h7ooOol0
SGoo000EOol00`00Oomoo`0OOol00g`0Oomoo`1GOol20n2=Ool001Eoo`03001oogoo021oo`9l05Uo
o`83h8]oo`005Goo00<007ooOol08Woo0W`0FGoo00<3h7ooOol0R7oo000EOol2000UOol00g`0Oomo
o`1GOol20n28Ool001Eoo`03001oogoo02Eoo`=l05Qoo`030n1oogoo08Eoo`005Goo00<007ooOol0
:7oo0W`0Egoo0P?PQGoo000EOol00`00Oomoo`0ZOol2O01GOol20n23Ool001Eoo`03001oogoo02ao
o`03O01oogoo05Ioo`030n1oogoo081oo`005Goo00<007ooOol0;Goo0g`0EWoo0P?PP7oo000EOol0
0`00Oomoo`0`Ool2O01FOol20n1nOol001Eoo`03001oogoo039oo`Il059oo`030n1oogoo07]oo`00
5Goo0P00>Goo0W`0DGoo0P?PNgoo000EOol00`00Oomoo`0jOol3O01@Ool00`?POomoo`1hOol001Eo
o`03001oogoo03eoo`9l04moo`83h7Qoo`005Goo00<007ooOol0?goo1G`0C7oo0P?PMWoo000EOol0
0`00Oomoo`14Ool3O01;Ool00`?POomoo`1cOol001Eoo`03001oogoo04Moo`El04Moo`83h7=oo`00
0Woo0P0017oo0P000goo0`001Goo00<007ooOol0C7oo1G`0A7oo00<3h7ooOol0L7oo00001Goo001o
ogoo000027oo00@007ooOol000Aoo`03001oogoo055oo`=l049oo`83h71oo`0000Eoo`00Oomoo`00
00Qoo`04001oogoo0004Ool3001DOol5O00oOol20n1^Ool00005Ool007ooOol00008Ool30005Ool0
0`00Oomoo`1IOol5O00lOol00`?POomoo`1[Ool00005Ool007ooOol00009Ool00`00Oomoo`04Ool0
0`00Oomoo`1NOol3O00jOol20n1[Ool0009oo`8000Yoo`<000Aoo`03001oogoo065oo`El03Moo`83
h6Uoo`005Goo00<007ooOol0IWoo1G`0=7oo00<3h7ooOol0IWoo000EOol00`00Oomoo`1[Ool3O00b
Ool20n1VOol001Eoo`03001oogoo06ioo`El02moo`030n1oogoo06=oo`005Goo00<007ooOol0Lgoo
1G`0:goo0P?PHgoo000EOol2001iOol3O00ZOol20n1QOol001Eoo`03001oogoo07]oo`El02Moo`03
0n1oogoo05ioo`005Goo00<007ooOol0P7oo0g`09Goo0P?PGWoo000EOol00`00Oomoo`23Ool5O00R
Ool20n1LOol001Eoo`03001oogoo08Qoo`9l029oo`030n1oogoo05Uoo`005Goo00<007ooOol0RWoo
1W`07Goo0P?PFGoo000EOol00`00Oomoo`2@Ool2O00MOol00`?POomoo`1FOol001Eoo`03001oogoo
099oo`=l01]oo`83h5Ioo`005Goo0P00UWoo1G`067oo0P?PE7oo000EOol00`00Oomoo`2JOol3O00G
Ool00`?POomoo`1AOol001Eoo`03001oogoo09eoo`9l01Ioo`83h55oo`005Goo00<007ooOol0Wgoo
0g`05Goo00<3h7ooOol0CWoo000EOol00`00Oomoo`2ROol2O00DOol20n1>Ool001Eoo`03001oogoo
0:Aoo`El015oo`83h4aoo`005Goo00<007ooOol0ZGoo0g`047oo00<3h7ooOol0BGoo000EOol00`00
Oomoo`2/Ool3O00>Ool20n19Ool001Eoo`800;1oo`9l00ioo`83h4Moo`005Goo00<007ooOol0/Goo
0g`03Goo00<3h7ooOol0A7oo000EOol00`00Oomoo`2dOol2O00<Ool20n14Ool001Eoo`03001oogoo
0;Ioo`=l00]oo`030n1oogoo045oo`005Goo00<007ooOol0^Goo0g`02Goo0P?P@Goo000EOol00`00
Oomoo`2lOol2O009Ool20n0oOol0009oo`8000Aoo`8000Aoo`8000Eoo`03001oogoo0;ioo`=l00Qo
o`030n1oogoo03aoo`0000Eoo`00Oomoo`0000Qoo`04001oogoo0004Ool00`00Oomoo`31Ool2O007
Ool20n0lOol00005Ool007ooOol00008Ool01000Oomoo`0017oo0`00`goo0g`01Woo0P?P>Woo0000
1Goo001oogoo00002Goo0P001Goo00<007ooOol0aWoo0g`01Goo00<3h7ooOol0=goo00001Goo001o
ogoo000027oo00@007ooOol000Aoo`03001oogoo0<Uoo`9l00Aoo`83h3Moo`000Woo0P002Woo0P00
1Goo00<007ooOol0bgoo0W`017oo00<3h7ooOol0=7oo000EOol00`00Oomoo`3=Ool2O003Ool20n0d
Ool001Eoo`03001oogoo0<moo`03O01oogoo009oo`83h39oo`005Goo00<007ooOol0d7oo0g`00goo
00<3h7ooOol0;goo000EOol00`00Oomoo`3COol3O0000goo0n03h00_Ool001Eoo`800=Moo`9l0003
Ool3h7oo02eoo`005Goo00<007ooOol0f7oo00Al07oo0n03h2aoo`005Goo00<007ooOol0fGoo0W`0
00=oo`?P0n00:Woo000EOol00`00Oomoo`3KOol2O0000goo0n1oo`0XOol001Eoo`03001oogoo0=eo
o`9l0083h2Moo`005Goo00<007ooOol0h7oo00=l00?P0n009Goo000EOol00`00Oomoo`3ROol00g`0
0n1oo`0SOol001Eoo`03001oogoo0>=oo`03O003h0?P029oo`005Goo0P00iWoo00=l00?POol087oo
000EOol00`00Oomoo`3WOol20n0OOol001Eoo`03001oogoo0>Uoo`83h1eoo`005Goo00<007ooOol0
jWoo00=l00?POol06goo000EOol00`00Oomoo`3/Ool20n0JOol001Eoo`03001oogoo0>ioo`83h1Qo
o`005Goo00<007ooOol0kgoo00=l00?POol05Woo000EOol00`00Oomoo`3aOol20n0EOol001Eoo`80
0?Aoo`030n1l07oo019oo`005Goo00<007ooOol0m7oo0P?P00=l07ooOol03goo000EOol00`00Oomo
o`3fOol20n0@Ool001Eoo`03001oogoo0?Qoo`030n1oogoo00eoo`005Goo00<007ooOol0nGoo0P?P
3Goo000EOol00`00Oomoo`3kOol00`?POomoo`0:Ool000eoo`D000=oo`03001oogoo0?aoo`83h0Yo
o`003goo00<007ooOol00goo00<007ooOol0oWoo0P?P27oo000?Ool00`00Oomoo`03Ool3003oOol1
Ool00`?POomoo`05Ool000moo`03001oogoo00=oo`03001oogoo0?moo`Uoo`003goo00<007ooOol0
0goo00<007ooOol0ogoo2Goo000>Ool20005Ool00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?mo
o`Uoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0829852, -0.07747, \
0.00386179, 0.00624851}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(tb = Table[{x[i], y[i]}, {i, 0, 100}];\)\)], "Input"],

Cell[BoxData[
    \(\(tb2 = Table[{x[i], T[i]}, {i, 0, 100}];\)\)], "Input"],

Cell[BoxData[
    \(\(tb3 = Table[{y[i], T[i]}, {i, 0, 100}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(plt1 = 
      ListPlot[tb2, PlotStyle \[Rule] RGBColor[1, 0, 0], 
        PlotJoined \[Rule] \ True, PlotRange \[Rule] All]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -2.097 0.0270041 [
[.21429 .05082 -9 -9 ]
[.21429 .05082 9 0 ]
[.40476 .05082 -9 -9 ]
[.40476 .05082 9 0 ]
[.59524 .05082 -9 -9 ]
[.59524 .05082 9 0 ]
[.78571 .05082 -9 -9 ]
[.78571 .05082 9 0 ]
[.97619 .05082 -3 -9 ]
[.97619 .05082 3 0 ]
[.01131 .19834 -12 -4.5 ]
[.01131 .19834 0 4.5 ]
[.01131 .33336 -12 -4.5 ]
[.01131 .33336 0 4.5 ]
[.01131 .46838 -12 -4.5 ]
[.01131 .46838 0 4.5 ]
[.01131 .6034 -18 -4.5 ]
[.01131 .6034 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .06332 m
.21429 .06957 L
s
[(0.2)] .21429 .05082 0 1 Mshowa
.40476 .06332 m
.40476 .06957 L
s
[(0.4)] .40476 .05082 0 1 Mshowa
.59524 .06332 m
.59524 .06957 L
s
[(0.6)] .59524 .05082 0 1 Mshowa
.78571 .06332 m
.78571 .06957 L
s
[(0.8)] .78571 .05082 0 1 Mshowa
.97619 .06332 m
.97619 .06957 L
s
[(1)] .97619 .05082 0 1 Mshowa
.125 Mabswid
.07143 .06332 m
.07143 .06707 L
s
.11905 .06332 m
.11905 .06707 L
s
.16667 .06332 m
.16667 .06707 L
s
.2619 .06332 m
.2619 .06707 L
s
.30952 .06332 m
.30952 .06707 L
s
.35714 .06332 m
.35714 .06707 L
s
.45238 .06332 m
.45238 .06707 L
s
.5 .06332 m
.5 .06707 L
s
.54762 .06332 m
.54762 .06707 L
s
.64286 .06332 m
.64286 .06707 L
s
.69048 .06332 m
.69048 .06707 L
s
.7381 .06332 m
.7381 .06707 L
s
.83333 .06332 m
.83333 .06707 L
s
.88095 .06332 m
.88095 .06707 L
s
.92857 .06332 m
.92857 .06707 L
s
.25 Mabswid
0 .06332 m
1 .06332 L
s
.02381 .19834 m
.03006 .19834 L
s
[(85)] .01131 .19834 1 0 Mshowa
.02381 .33336 m
.03006 .33336 L
s
[(90)] .01131 .33336 1 0 Mshowa
.02381 .46838 m
.03006 .46838 L
s
[(95)] .01131 .46838 1 0 Mshowa
.02381 .6034 m
.03006 .6034 L
s
[(100)] .01131 .6034 1 0 Mshowa
.125 Mabswid
.02381 .09033 m
.02756 .09033 L
s
.02381 .11733 m
.02756 .11733 L
s
.02381 .14433 m
.02756 .14433 L
s
.02381 .17134 m
.02756 .17134 L
s
.02381 .22535 m
.02756 .22535 L
s
.02381 .25235 m
.02756 .25235 L
s
.02381 .27936 m
.02756 .27936 L
s
.02381 .30636 m
.02756 .30636 L
s
.02381 .36037 m
.02756 .36037 L
s
.02381 .38737 m
.02756 .38737 L
s
.02381 .41438 m
.02756 .41438 L
s
.02381 .44138 m
.02756 .44138 L
s
.02381 .49539 m
.02756 .49539 L
s
.02381 .52239 m
.02756 .52239 L
s
.02381 .5494 m
.02756 .5494 L
s
.02381 .5764 m
.02756 .5764 L
s
.02381 .03632 m
.02756 .03632 L
s
.02381 .00931 m
.02756 .00931 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.03333 .52987 L
.04286 .47106 L
.05238 .42302 L
.0619 .38318 L
.07143 .34969 L
.08095 .32125 L
.09048 .29687 L
.1 .2758 L
.10952 .25745 L
.11905 .24138 L
.12857 .22721 L
.1381 .21464 L
.14762 .20345 L
.15714 .19341 L
.16667 .18438 L
.17619 .17621 L
.18571 .16878 L
.19524 .16199 L
.20476 .15577 L
.21429 .15003 L
.22381 .14472 L
.23333 .13979 L
.24286 .13518 L
.25238 .13086 L
.2619 .1268 L
.27143 .12296 L
.28095 .11932 L
.29048 .11585 L
.3 .11254 L
.30952 .10937 L
.31905 .10632 L
.32857 .10338 L
.3381 .10054 L
.34762 .09779 L
.35714 .09512 L
.36667 .09253 L
.37619 .09 L
.38571 .08753 L
.39524 .08511 L
.40476 .08275 L
.41429 .08043 L
.42381 .07816 L
.43333 .07593 L
.44286 .07374 L
.45238 .07159 L
.4619 .06948 L
.47143 .0674 L
.48095 .06535 L
.49048 .06334 L
Mistroke
.5 .06136 L
.50952 .05941 L
.51905 .05749 L
.52857 .05561 L
.5381 .05376 L
.54762 .05194 L
.55714 .05016 L
.56667 .0484 L
.57619 .04669 L
.58571 .045 L
.59524 .04336 L
.60476 .04174 L
.61429 .04017 L
.62381 .03863 L
.63333 .03713 L
.64286 .03567 L
.65238 .03424 L
.6619 .03286 L
.67143 .03152 L
.68095 .03023 L
.69048 .02898 L
.7 .02777 L
.70952 .02661 L
.71905 .02549 L
.72857 .02442 L
.7381 .0234 L
.74762 .02244 L
.75714 .02152 L
.76667 .02065 L
.77619 .01984 L
.78571 .01909 L
.79524 .01839 L
.80476 .01774 L
.81429 .01716 L
.82381 .01663 L
.83333 .01617 L
.84286 .01576 L
.85238 .01542 L
.8619 .01515 L
.87143 .01494 L
.88095 .01479 L
.89048 .01472 L
.9 .01472 L
.90952 .01478 L
.91905 .01492 L
.92857 .01513 L
.9381 .01542 L
.94762 .01579 L
.95714 .01623 L
.96667 .01676 L
Mistroke
.97619 .01737 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`00
5Goo0P00ogoo2Woo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0==oobil00Moo`005Goo
00<007ooOol0aWoo3G`0=Goo000EOol00`00Oomoo`0ZOol20004Ool20003Ool4000UOol20004Ool2
0005Ool3000SOol20004Ool20003Ool3000MOol:O0000`00Oomoo`02Ool20004Ool2000[Ool50005
Ool001Eoo`03001oogoo02Uoo`04001oogoo0008Ool00`00Oomoo`0UOol01000Oomoo`002goo00<0
07ooOol08Goo00@007ooOol000Qoo`04001oogoo000DOol8O008Ool01000Oomoo`0027oo00@007oo
Ool002aoo`03001oogoo00Eoo`005Goo00<007ooOol0:Goo00@007ooOol000Uoo`03001oogoo02Ao
o`04001oogoo0008Ool5000ROol01000Oomoo`0027oo00@007ooOol000eoo`Ml011oo`04001oogoo
0008Ool01000Oomoo`00;7oo00<007ooOol01Goo000EOol00`00Oomoo`0YOol01000Oomoo`002Woo
00<007ooOol08goo00@007ooOol000Qoo`04001oogoo000SOol01000Oomoo`0027oo0`001Woo27`0
5goo00@007ooOol000Uoo`8002eoo`03001oogoo00Eoo`005Goo0P00:Woo00@007ooOol000Qoo`04
001oogoo000TOol01000Oomoo`002Goo00<007oo00008goo00@007ooOol000Uoo`03001oogoo00El
01moo`04001oogoo0008Ool01000Oomoo`00;7oo00<007ooOol01Goo000EOol00`00Oomoo`0ZOol2
000:Ool2000VOol2000;Ool2000TOol20005Ool8O00UOol2000:Ool2000/Ool20007Ool001Eoo`03
001oogoo09=oo`El071oo`005Goo00<007ooOol0SGoo1W`0MGoo000EOol00`00Oomoo`28Ool5O01k
Ool001Eoo`03001oogoo08=oo`El081oo`005Goo00<007ooOol0OWoo1G`0QGoo000>Oon30005O02:
000001Eoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`04001o
ogooOol3O005Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`05Ool001Eoo`03001oogoo035oo`03001oogoo035oo`03001oogoo
00Uoo`El029oo`03001oogoo035oo`03001oogoo035oo`03001oogoo00Eoo`005Goo00<007ooOol0
K7oo1G`0Ugoo000EOol00`00Oomoo`1YOol3O02LOol001Eoo`03001oogoo06Aoo`El09moo`005Goo
00<007ooOol0HGoo0g`0Y7oo000EOol2001MOol5O02WOol001Eoo`03001oogoo05Yoo`9l0:aoo`00
5Goo00<007ooOol0E7oo1W`0[Woo000EOol00`00Oomoo`1BOol2O02dOol001Eoo`03001oogoo04mo
o`=l0;Ioo`005Goo00<007ooOol0BWoo1G`0^Goo000EOol00`00Oomoo`17Ool3O02nOol001Eoo`03
001oogoo04Eoo`9l0<5oo`005Goo0P00@goo0g`0`goo000EOol00`00Oomoo`10Ool2O036Ool001Eo
o`03001oogoo03eoo`=l0<Qoo`005Goo00<007ooOol0>goo0W`0bgoo000EOol00`00Oomoo`0iOol2
O03=Ool001Eoo`03001oogoo03Moo`9l0<moo`005Goo00<007ooOol0=Goo0W`0dGoo000EOol2000d
Ool2O03COol001Eoo`03001oogoo039oo`03O01oogoo0==oo`005Goo00<007ooOol0<7oo0W`0eWoo
000EOol00`00Oomoo`0^Ool2O03HOol001Eoo`03001oogoo02eoo`03O01oogoo0=Qoo`005Goo00<0
07ooOol0;7oo00=l07ooOol0fGoo000EOol00`00Oomoo`0ZOol2O03LOol001Eoo`8002Yoo`03O01o
ogoo0=aoo`005Goo00<007ooOol09goo0W`0ggoo000EOol00`00Oomoo`0VOol00g`0Oomoo`3OOol0
01Eoo`03001oogoo02Eoo`03O01oogoo0>1oo`005Goo00<007ooOol097oo00=l07ooOol0hGoo000E
Ool00`00Oomoo`0ROol2O03TOol000Qoo`8000Aoo`8000Eoo`03001oogoo025oo`03O01oogoo0>Ao
o`001goo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`0POol00g`0Oomoo`3UOol000Mo
o`04001oogoo0005Ool00`00Oomoo`02Ool3000POol00g`0Oomoo`3UOol000Qoo`8000Aoo`8000Eo
o`03001oogoo01moo`03O01oogoo0>Ioo`001goo00@007ooOol000=oo`03001oogoo00Aoo`03001o
ogoo01ioo`03O01oogoo0>Moo`0027oo0P0017oo0`0017oo00<007ooOol07Goo00=l07ooOol0j7oo
000EOol00`00Oomoo`0LOol00g`0Oomoo`3YOol001Eoo`03001oogoo01]oo`03O01oogoo0>Yoo`00
5Goo00<007ooOol06Woo00=l07ooOol0jgoo000EOol2000KOol00g`0Oomoo`3[Ool001Eoo`03001o
ogoo01Uoo`03O01oogoo0>aoo`005Goo00<007ooOol067oo00=l07ooOol0kGoo000EOol00`00Oomo
o`0HOol00g`0Oomoo`3]Ool001Eoo`03001oogoo01Moo`03O01oogoo0>ioo`005Goo00<007ooOol0
5Woo00=l07ooOol0kgoo000EOol00`00Oomoo`0FOol00g`0Oomoo`3_Ool001Eoo`8001Ioo`03O01o
ogoo0?1oo`005Goo00<007ooOol05Goo00=l07ooOol0l7oo000EOol00`00Oomoo`0DOol00g`0Oomo
o`3aOol001Eoo`03001oogoo01Aoo`03O01oogoo0?5oo`005Goo00<007ooOol04goo00=l07ooOol0
lWoo000EOol00`00Oomoo`0COol00g`0Oomoo`3bOol001Eoo`03001oogoo019oo`03O01oogoo0?=o
o`005Goo00<007ooOol04Woo00=l07ooOol0lgoo000EOol2000BOol00g`0Oomoo`3dOol001Eoo`03
001oogoo015oo`03O01oogoo0?Aoo`005Goo00<007ooOol047oo00=l07ooOol0mGoo000EOol00`00
Oomoo`0@Ool00g`0Oomoo`3eOol001Eoo`03001oogoo00moo`03O01oogoo0?Ioo`005Goo00<007oo
Ool03goo00=l07ooOol0mWoo000EOol00`00Oomoo`0>Ool00g`0Oomoo`3gOol001Eoo`8000moo`03
O01oogoo0?Moo`005Goo00<007ooOol03Goo00=l07ooOol0n7oo000EOol00`00Oomoo`0=Ool00g`0
Oomoo`3hOol001Eoo`03001oogoo00aoo`03O01oogoo0?Uoo`005Goo00<007ooOol037oo00=l07oo
Ool0nGoo0007Ool30004Ool20005Ool00`00Oomoo`0<Ool00g`0Oomoo`3iOol000Uoo`05001oogoo
Ool00002Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00g`0Oomoo`3jOol000Qoo`<0009oo`04001o
ogoo0004Ool3000;Ool00g`0Oomoo`3jOol000Moo`04001oogoo0002Ool01000Oomoo`0017oo00<0
07ooOol02goo00=l07ooOol0nWoo0007Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo
00]oo`03O01oogoo0?Yoo`0027oo0`000goo0P001Goo00<007ooOol02Woo00=l07ooOol0ngoo000E
Ool00`00Oomoo`0:Ool00g`0Oomoo`3kOol001Eoo`03001oogoo00Yoo`03O01oogoo0?]oo`005Goo
00<007ooOol02Woo00=l07ooOol0ngoo000EOol00`00Oomoo`09Ool00g`0Oomoo`3lOol001Eoo`80
00Yoo`03O01oogoo0?aoo`005Goo00<007ooOol02Goo00=l07ooOol0o7oo000EOol00`00Oomoo`08
Ool00g`0Oomoo`3mOol001Eoo`03001oogoo00Qoo`03O01oogoo0?eoo`005Goo00<007ooOol027oo
00=l07ooOol0oGoo000EOol00`00Oomoo`07Ool00g`0Oomoo`3nOol001Eoo`03001oogoo00Moo`03
O01oogoo0?ioo`005Goo0P0027oo00=l07ooOol0oWoo000EOol00`00Oomoo`07Ool00g`0Oomoo`3n
Ool001Eoo`03001oogoo00Ioo`03O01oogoo0?moo`005Goo00<007ooOol01Woo00=l07ooOol0ogoo
000EOol00`00Oomoo`06Ool00g`0Oomoo`3oOol001Eoo`03001oogoo00Ioo`03O01oogoo0?moo`00
5Goo00<007ooOol01Woo00=l07ooOol0ogoo000EOol20007Ool00g`0Oomoo`3oOol001Eoo`03001o
ogoo00Eoo`03O01oogoo0?moo`5oo`005Goo00<007ooOol01Goo00=l07ooOol0ogoo0Goo000EOol0
0`00Oomoo`05Ool00g`0Oomoo`3oOol1Ool001Eoo`03001oogoo00Eoo`03O01oogoo0?moo`5oo`00
5Goo00<007ooOol01Goo00=l07ooOol0ogoo0Goo000EOol00`00Oomoo`04Ool00g`0Oomoo`3oOol2
Ool001Eoo`03001oogoo00Aoo`03O01oogoo0?moo`9oo`005Goo0P001Goo00=l07ooOol0ogoo0Woo
000EOol00`00Oomoo`04Ool00g`0Oomoo`3oOol2Ool001Eoo`03001oogoo00=oo`03O01oogoo0?mo
o`=oo`005Goo00<007ooOol00goo00=l07ooOol0ogoo0goo000EOol00`00Oomoo`03Ool00g`0Oomo
o`3oOol3Ool000Moo`<000Aoo`8000Eoo`03001oogoo00=oo`03O01oogoo0?moo`=oo`002Goo00D0
07ooOomoo`00009oo`03001oogoo009oo`03001oogoo009oo`03O01oogoo0?moo`Aoo`0027oo0`00
1Goo00<007ooOol00Woo0`000Woo00=l07ooOol0ogoo17oo0007Ool01000Oomoo`000goo0P001Goo
00<007ooOol00Woo00=l07ooOol0ogoo17oo0007Ool01000Oomoo`000goo00<007ooOol017oo00<0
07ooOol00Woo00=l07ooOol0ogoo17oo0008Ool30003Ool30004Ool00`00Oomoo`02Ool00g`0Oomo
o`3oOol4Ool001Eoo`05001oogooOoml003oOol7Ool001Eoo`05001oogooOoml003oOol7Ool001Eo
o`05001oogooOoml003oOol7Ool001Eoo`80009oo`03O01oogoo0?moo`Eoo`005Goo00D007ooOomo
og`00?moo`Moo`005Goo00@007ooOoml0?moo`Qoo`005Goo00@007ooOoml0?moo`Qoo`005Goo00@0
07ooOoml0?moo`Qoo`005Goo00@007ooOoml0?moo`Qoo`005Goo00@007ooOoml0?moo`Qoo`005Goo
00@007ooOoml0?moo`Qoo`005Goo0P0000=l07ooOol0ogoo1goo000EOol00`00Ooml003oOol9Ool0
01Eoo`03001oog`00?moo`Uoo`005Goo00<007ooO000ogoo2Goo000EOol00`00Ooml003oOol9Ool0
01Eoo`03001oog`00?moo`Uoo`005Goo00<007ooO000ogoo2Goo000EOol00`00O01oo`3oOol9Ool0
01Eoo`03001l07oo0?moo`Uoo`005Goo00<007`0Ool0ogoo2Goo000EOol00`00O01oo`3oOol9Ool0
01Eoo`03001l07oo0?moo`Uoo`005Goo00<007`0Ool0ogoo2Goo000EOol00`00O01oo`3oOol9Ool0
01Eoo`03001l07oo0?moo`Uoo`005Goo00<007`0Ool0ogoo2Goo000EOol00`00O01oo`3oOol9Ool0
01Eoo`03O01oogoo0?moo`Uoo`005Goo00=l07ooOol0ogoo2Goo000EOol00g`0Oomoo`3oOol9Ool0
0003Ool0000000<0009oo`8000Aoo`8000Eoo`03O01oogoo0?moo`Uoo`000goo00D007ooOomoo`00
009oo`04001oogoo0002Ool00`00Oomoo`02Ool00g`0Oomoo`3oOol9Ool000=oo`05001oogooOol0
0002Ool01000Oomoo`000Woo00<007ooOol00Woo00=l00000000ogoo2Goo0003Ool01@00Oomoogoo
00000Woo00@007ooOol0009oo`03001oogoo009oo`03001oogoo0?moo`Uoo`000goo00D007ooOomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`3oOol9Ool0009oo`8000Aoo`80
00Aoo`8000Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0825959, 77.0922, \
0.00385924, 0.136108}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(tb3 = Table[{y[i], T[i]}, {i, 0, 100}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(plt2 = 
      ListPlot[tb3, PlotStyle \[Rule] RGBColor[0, 0, 1], 
        PlotJoined \[Rule] \ True, PlotRange \[Rule] All]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -2.097 0.0270041 [
[.21429 .05082 -9 -9 ]
[.21429 .05082 9 0 ]
[.40476 .05082 -9 -9 ]
[.40476 .05082 9 0 ]
[.59524 .05082 -9 -9 ]
[.59524 .05082 9 0 ]
[.78571 .05082 -9 -9 ]
[.78571 .05082 9 0 ]
[.97619 .05082 -3 -9 ]
[.97619 .05082 3 0 ]
[.01131 .19834 -12 -4.5 ]
[.01131 .19834 0 4.5 ]
[.01131 .33336 -12 -4.5 ]
[.01131 .33336 0 4.5 ]
[.01131 .46838 -12 -4.5 ]
[.01131 .46838 0 4.5 ]
[.01131 .6034 -18 -4.5 ]
[.01131 .6034 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .06332 m
.21429 .06957 L
s
[(0.2)] .21429 .05082 0 1 Mshowa
.40476 .06332 m
.40476 .06957 L
s
[(0.4)] .40476 .05082 0 1 Mshowa
.59524 .06332 m
.59524 .06957 L
s
[(0.6)] .59524 .05082 0 1 Mshowa
.78571 .06332 m
.78571 .06957 L
s
[(0.8)] .78571 .05082 0 1 Mshowa
.97619 .06332 m
.97619 .06957 L
s
[(1)] .97619 .05082 0 1 Mshowa
.125 Mabswid
.07143 .06332 m
.07143 .06707 L
s
.11905 .06332 m
.11905 .06707 L
s
.16667 .06332 m
.16667 .06707 L
s
.2619 .06332 m
.2619 .06707 L
s
.30952 .06332 m
.30952 .06707 L
s
.35714 .06332 m
.35714 .06707 L
s
.45238 .06332 m
.45238 .06707 L
s
.5 .06332 m
.5 .06707 L
s
.54762 .06332 m
.54762 .06707 L
s
.64286 .06332 m
.64286 .06707 L
s
.69048 .06332 m
.69048 .06707 L
s
.7381 .06332 m
.7381 .06707 L
s
.83333 .06332 m
.83333 .06707 L
s
.88095 .06332 m
.88095 .06707 L
s
.92857 .06332 m
.92857 .06707 L
s
.25 Mabswid
0 .06332 m
1 .06332 L
s
.02381 .19834 m
.03006 .19834 L
s
[(85)] .01131 .19834 1 0 Mshowa
.02381 .33336 m
.03006 .33336 L
s
[(90)] .01131 .33336 1 0 Mshowa
.02381 .46838 m
.03006 .46838 L
s
[(95)] .01131 .46838 1 0 Mshowa
.02381 .6034 m
.03006 .6034 L
s
[(100)] .01131 .6034 1 0 Mshowa
.125 Mabswid
.02381 .09033 m
.02756 .09033 L
s
.02381 .11733 m
.02756 .11733 L
s
.02381 .14433 m
.02756 .14433 L
s
.02381 .17134 m
.02756 .17134 L
s
.02381 .22535 m
.02756 .22535 L
s
.02381 .25235 m
.02756 .25235 L
s
.02381 .27936 m
.02756 .27936 L
s
.02381 .30636 m
.02756 .30636 L
s
.02381 .36037 m
.02756 .36037 L
s
.02381 .38737 m
.02756 .38737 L
s
.02381 .41438 m
.02756 .41438 L
s
.02381 .44138 m
.02756 .44138 L
s
.02381 .49539 m
.02756 .49539 L
s
.02381 .52239 m
.02756 .52239 L
s
.02381 .5494 m
.02756 .5494 L
s
.02381 .5764 m
.02756 .5764 L
s
.02381 .03632 m
.02756 .03632 L
s
.02381 .00931 m
.02756 .00931 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 1 r
.5 Mabswid
.02381 .60332 m
.12135 .52987 L
.19426 .47106 L
.25065 .42302 L
.29544 .38318 L
.3318 .34969 L
.36184 .32125 L
.38704 .29687 L
.40845 .2758 L
.42686 .25745 L
.44285 .24138 L
.45686 .22721 L
.46923 .21464 L
.48026 .20345 L
.49014 .19341 L
.49907 .18438 L
.50719 .17621 L
.51462 .16878 L
.52145 .16199 L
.52778 .15577 L
.53366 .15003 L
.53918 .14472 L
.54436 .13979 L
.54927 .13518 L
.55393 .13086 L
.55839 .1268 L
.56266 .12296 L
.56679 .11932 L
.57078 .11585 L
.57466 .11254 L
.57845 .10937 L
.58216 .10632 L
.58581 .10338 L
.58941 .10054 L
.59297 .09779 L
.5965 .09512 L
.60001 .09253 L
.60351 .09 L
.60701 .08753 L
.61051 .08511 L
.61403 .08275 L
.61756 .08043 L
.62111 .07816 L
.62469 .07593 L
.6283 .07374 L
.63195 .07159 L
.63564 .06948 L
.63938 .0674 L
.64316 .06535 L
.647 .06334 L
Mistroke
.65089 .06136 L
.65484 .05941 L
.65885 .05749 L
.66292 .05561 L
.66707 .05376 L
.67128 .05194 L
.67556 .05016 L
.67992 .0484 L
.68436 .04669 L
.68888 .045 L
.69348 .04336 L
.69816 .04174 L
.70293 .04017 L
.70779 .03863 L
.71275 .03713 L
.7178 .03567 L
.72294 .03424 L
.72819 .03286 L
.73353 .03152 L
.73898 .03023 L
.74454 .02898 L
.75021 .02777 L
.75599 .02661 L
.76188 .02549 L
.76789 .02442 L
.77402 .0234 L
.78027 .02244 L
.78665 .02152 L
.79316 .02065 L
.7998 .01984 L
.80657 .01909 L
.81349 .01839 L
.82054 .01774 L
.82774 .01716 L
.83508 .01663 L
.84258 .01617 L
.85023 .01576 L
.85805 .01542 L
.86602 .01515 L
.87417 .01494 L
.88249 .01479 L
.89098 .01472 L
.89965 .01472 L
.90851 .01478 L
.91757 .01492 L
.92681 .01513 L
.93626 .01542 L
.94592 .01579 L
.95579 .01623 L
.96588 .01676 L
Mistroke
.97619 .01737 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`00
5Goo0P00ogoo2Woo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0=QoobT07`Moo`005Goo
00<007ooOol0cWoo2P0O<7oo000EOol00`00Oomoo`0ZOol20004Ool20003Ool4000UOol20004Ool2
0005Ool3000SOol20004Ool20003Ool3000VOol2000701l3Ool2000[Ool50005Ool001Eoo`03001o
ogoo02Uoo`04001oogoo0008Ool00`00Oomoo`0UOol01000Oomoo`002goo00<007ooOol08Goo00@0
07ooOol000Qoo`04001oogoo000SOol401l00`00Oomoo`06Ool01000Oomoo`00;7oo00<007ooOol0
1Goo000EOol00`00Oomoo`0YOol01000Oomoo`002Goo00<007ooOol097oo00@007ooOol000Qoo`D0
029oo`04001oogoo0008Ool01000Oomoo`007Woo1@0O00Eoo`00Oomoo`0000Qoo`04001oogoo000/
Ool00`00Oomoo`05Ool001Eoo`03001oogoo02Uoo`04001oogoo000:Ool00`00Oomoo`0SOol01000
Oomoo`0027oo00@007ooOol002=oo`04001oogoo0008Ool3000KOol401l6Ool01000Oomoo`002Goo
0P00;Goo00<007ooOol01Goo000EOol2000ZOol01000Oomoo`0027oo00@007ooOol002Aoo`04001o
ogoo0009Ool00`00Ool0000SOol01000Oomoo`002Goo00<007ooOol05goo0`0O2Woo00@007ooOol0
00Qoo`04001oogoo000/Ool00`00Oomoo`05Ool001Eoo`03001oogoo02Yoo`8000Yoo`8002Ioo`80
00]oo`8002Aoo`8000Yoo`<001=oo`@07`ioo`8000Yoo`8002aoo`8000Moo`005Goo00<007ooOol0
/Goo0P0OEGoo000EOol00`00Oomoo`2^Ool301mGOol001Eoo`03001oogoo0:aoo`807eYoo`005Goo
00<007ooOol0ZWoo0P0OG7oo000EOol00`00Oomoo`2XOol201mNOol000ioojl000<07f0000005Goo
00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo
00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo
00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo00<07`00Ool02goo00<007ooOol02Woo
00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo
00<007ooOol01Goo000EOol00`00Oomoo`0aOol00`00Oomoo`0aOol00`00Oomoo`0`Ool00`00Oomo
o`07Ool201lXOol00`00Oomoo`0aOol00`00Oomoo`05Ool001Eoo`03001oogoo0:1oo`807fIoo`00
5Goo00<007ooOol0Wgoo00<07gooOol0IWoo000EOol00`00Oomoo`2MOol201mYOol001Eoo`03001o
ogoo09eoo`0301moogoo06Qoo`005Goo0P00W7oo0P0OJgoo000EOol00`00Oomoo`2JOol00`0OOomo
o`1[Ool001Eoo`03001oogoo09Qoo`807fioo`005Goo00<007ooOol0Ugoo00<07gooOol0KWoo000E
Ool00`00Oomoo`2FOol00`0OOomoo`1_Ool001Eoo`03001oogoo09Aoo`807g9oo`005Goo00<007oo
Ool0Tgoo00<07gooOol0LWoo000EOol00`00Oomoo`2BOol00`0OOomoo`1cOol001Eoo`80099oo`03
01moogoo07Aoo`005Goo00<007ooOol0T7oo00<07gooOol0MGoo000EOol00`00Oomoo`2>Ool201mh
Ool001Eoo`03001oogoo08eoo`0301moogoo07Qoo`005Goo00<007ooOol0S7oo00<07gooOol0NGoo
000EOol00`00Oomoo`2;Ool00`0OOomoo`1jOol001Eoo`03001oogoo08]oo`0301moogoo07Yoo`00
5Goo0P00RWoo0P0OOGoo000EOol00`00Oomoo`28Ool00`0OOomoo`1mOol001Eoo`03001oogoo08Qo
o`0301moogoo07eoo`005Goo00<007ooOol0QWoo0P0OP7oo000EOol00`00Oomoo`25Ool00`0OOomo
o`20Ool001Eoo`03001oogoo08Aoo`0301moogoo085oo`005Goo00<007ooOol0Pgoo00<07gooOol0
PWoo000EOol20023Ool00`0OOomoo`23Ool001Eoo`03001oogoo085oo`0301moogoo08Aoo`005Goo
00<007ooOol0P7oo00<07gooOol0QGoo000EOol00`00Oomoo`1oOol00`0OOomoo`26Ool001Eoo`03
001oogoo07ioo`0301moogoo08Moo`005Goo00<007ooOol0OGoo00<07gooOol0R7oo0008Ool20004
Ool20005Ool00`00Oomoo`1lOol00`0OOomoo`29Ool000Moo`04001oogoo0002Ool01000Oomoo`00
17oo00<007ooOol0Ngoo00<07gooOol0RWoo0007Ool01000Oomoo`001Goo00<007ooOol00Woo0`00
NWoo00<07gooOol0Rgoo0008Ool20004Ool20005Ool00`00Oomoo`1iOol00`0OOomoo`2<Ool000Mo
o`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`1hOol00`0OOomoo`2=Ool000Qoo`8000Ao
o`<000Aoo`03001oogoo07Moo`0301moogoo08ioo`005Goo00<007ooOol0MWoo00<07gooOol0Sgoo
000EOol00`00Oomoo`1eOol00`0OOomoo`2@Ool001Eoo`03001oogoo07Aoo`0301moogoo095oo`00
5Goo0P00MGoo00<07gooOol0TGoo000EOol00`00Oomoo`1cOol00`0OOomoo`2BOol001Eoo`03001o
ogoo079oo`0301moogoo09=oo`005Goo00<007ooOol0L7oo0P0OUWoo000EOol00`00Oomoo`1_Ool0
0`0OOomoo`2FOol001Eoo`03001oogoo06ioo`0301moogoo09Moo`005Goo00<007ooOol0KGoo00<0
7gooOol0V7oo000EOol2001^Ool00`0OOomoo`2HOol001Eoo`03001oogoo06aoo`0301moogoo09Uo
o`005Goo00<007ooOol0Jgoo00<07gooOol0VWoo000EOol00`00Oomoo`1ZOol00`0OOomoo`2KOol0
01Eoo`03001oogoo06Uoo`0301moogoo09aoo`005Goo00<007ooOol0J7oo00<07gooOol0WGoo000E
Ool00`00Oomoo`1WOol00`0OOomoo`2NOol001Eoo`03001oogoo06Ioo`0301moogoo09moo`005Goo
0P00IWoo00<07gooOol0X7oo000EOol00`00Oomoo`1TOol00`0OOomoo`2QOol001Eoo`03001oogoo
069oo`807jAoo`005Goo00<007ooOol0HGoo00<07gooOol0Y7oo000EOol00`00Oomoo`1POol00`0O
Oomoo`2UOol001Eoo`03001oogoo05moo`0301moogoo0:Ioo`005Goo00<007ooOol0GWoo00<07goo
Ool0Ygoo000EOol2001NOol00`0OOomoo`2XOol001Eoo`03001oogoo05aoo`0301moogoo0:Uoo`00
5Goo00<007ooOol0Fgoo00<07gooOol0ZWoo000EOol00`00Oomoo`1JOol00`0OOomoo`2[Ool001Eo
o`03001oogoo05Uoo`0301moogoo0:aoo`001goo0`0017oo0P001Goo00<007ooOol0F7oo00<07goo
Ool0[Goo0009Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol0Egoo00<07gooOol0
[Woo0008Ool30002Ool01000Oomoo`0017oo0`00EWoo00<07gooOol0[goo0007Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`03001oogoo05Eoo`0301moogoo0;1oo`001goo00@007ooOol0009oo`04
001oogoo0004Ool00`00Oomoo`1DOol00`0OOomoo`2aOol000Qoo`<000=oo`8000Eoo`03001oogoo
05=oo`0301moogoo0;9oo`005Goo00<007ooOol0DWoo00<07gooOol0/goo000EOol00`00Oomoo`1A
Ool00`0OOomoo`2dOol001Eoo`03001oogoo051oo`0301moogoo0;Eoo`005Goo00<007ooOol0Cgoo
00<07gooOol0]Woo000EOol2001?Ool00`0OOomoo`2gOol001Eoo`03001oogoo04eoo`0301moogoo
0;Qoo`005Goo00<007ooOol0Bgoo0P0O^goo000EOol00`00Oomoo`1:Ool00`0OOomoo`2kOol001Eo
o`03001oogoo04Uoo`0301moogoo0;aoo`005Goo00<007ooOol0B7oo00<07gooOol0_Goo000EOol0
0`00Oomoo`17Ool00`0OOomoo`2nOol001Eoo`8004Moo`0301moogoo0;moo`005Goo00<007ooOol0
AGoo00<07gooOol0`7oo000EOol00`00Oomoo`14Ool00`0OOomoo`31Ool001Eoo`03001oogoo04=o
o`0301moogoo0<9oo`005Goo00<007ooOol0@Woo00<07gooOol0`goo000EOol00`00Oomoo`10Ool2
01o6Ool001Eoo`03001oogoo03moo`0301moogoo0<Ioo`005Goo0P00?goo00<07gooOol0agoo000E
Ool00`00Oomoo`0mOol00`0OOomoo`38Ool001Eoo`03001oogoo03aoo`0301moogoo0<Uoo`005Goo
00<007ooOol0>goo00<07gooOol0bWoo000EOol00`00Oomoo`0jOol00`0OOomoo`3;Ool001Eoo`03
001oogoo03Qoo`807lioo`005Goo00<007ooOol0=goo00<07gooOol0cWoo000EOol00`00Oomoo`0f
Ool00`0OOomoo`3?Ool001Eoo`8003Ioo`0301moogoo0=1oo`005Goo00<007ooOol0=7oo00<07goo
Ool0dGoo000EOol00`00Oomoo`0bOol201oDOol001Eoo`03001oogoo035oo`0301moogoo0=Aoo`00
5Goo00<007ooOol0<7oo00<07gooOol0eGoo0007Ool30004Ool20005Ool00`00Oomoo`0_Ool00`0O
Oomoo`3FOol000Uoo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`0]Ool201oIOol0
00Qoo`<000Eoo`03001oogoo009oo`<002aoo`0301moogoo0=Uoo`001goo00@007ooOol000=oo`80
00Eoo`03001oogoo02]oo`0301moogoo0=Yoo`001goo00@007ooOol000=oo`03001oogoo00Aoo`03
001oogoo02Yoo`0301moogoo0=]oo`0027oo0`000goo0`0017oo00<007ooOol0:7oo0P0OgWoo000E
Ool00`00Oomoo`0WOol00`0OOomoo`3NOol001Eoo`03001oogoo02Ioo`0301moogoo0=moo`005Goo
00<007ooOol09Goo00<07gooOol0h7oo000EOol2000TOol201oSOol001Eoo`03001oogoo029oo`03
01moogoo0>=oo`005Goo00<007ooOol08Goo00<07gooOol0i7oo000EOol00`00Oomoo`0POol00`0O
Oomoo`3UOol001Eoo`03001oogoo01ioo`807nQoo`005Goo00<007ooOol07Goo00<07gooOol0j7oo
000EOol00`00Oomoo`0LOol00`0OOomoo`3YOol001Eoo`03001oogoo01]oo`0301moogoo0>Yoo`00
5Goo0P006Woo0P0OkGoo000EOol00`00Oomoo`0HOol00`0OOomoo`3]Ool001Eoo`03001oogoo01Mo
o`0301moogoo0>ioo`005Goo00<007ooOol05Woo00<07gooOol0kgoo000EOol00`00Oomoo`0DOol2
01obOol001Eoo`03001oogoo01=oo`0301moogoo0?9oo`005Goo00<007ooOol04Woo00<07gooOol0
lgoo000EOol2000AOol201ofOol001Eoo`03001oogoo00moo`0301moogoo0?Ioo`005Goo00<007oo
Ool03Woo00<07gooOol0mgoo000EOol00`00Oomoo`0<Ool201ojOol001Eoo`03001oogoo00]oo`03
01moogoo0?Yoo`005Goo00<007ooOol02Woo00<07gooOol0ngoo000EOol00`00Oomoo`09Ool00`0O
Oomoo`3lOol001Eoo`03001oogoo00Moo`807omoo`005Goo0P001goo00<07gooOol0ogoo000EOol0
0`00Oomoo`05Ool00`0OOomoo`3oOol1Ool001Eoo`03001oogoo00=oo`807omoo`Aoo`005Goo00<0
07ooOol00Woo00<07gooOol0ogoo17oo000EOol01@00Oomoogoo01l0ogoo1goo00000goo00000003
0002Ool20004Ool20005Ool01000Ool07`0Oogoo27oo0003Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`03001oogoo009oo`0300007goo0?moo`Uoo`000goo00D007ooOomoo`00009oo`04001o
ogoo0002Ool00`00Oomoo`02Ool00`0O0000003oOol9Ool000=oo`05001oogooOol00002Ool01000
Oomoo`000Woo00<007ooOol00Woo00<007ooOol0ogoo2Goo0003Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`03001oogoo009oo`03001oogoo0?moo`Uoo`000Woo0P0017oo0P0017oo0P001Goo
00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0825959, 77.0922, \
0.00385924, 0.136108}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[plt1, plt2]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -2.097 0.0270041 [
[.21429 .05082 -9 -9 ]
[.21429 .05082 9 0 ]
[.40476 .05082 -9 -9 ]
[.40476 .05082 9 0 ]
[.59524 .05082 -9 -9 ]
[.59524 .05082 9 0 ]
[.78571 .05082 -9 -9 ]
[.78571 .05082 9 0 ]
[.97619 .05082 -3 -9 ]
[.97619 .05082 3 0 ]
[.01131 .19834 -12 -4.5 ]
[.01131 .19834 0 4.5 ]
[.01131 .33336 -12 -4.5 ]
[.01131 .33336 0 4.5 ]
[.01131 .46838 -12 -4.5 ]
[.01131 .46838 0 4.5 ]
[.01131 .6034 -18 -4.5 ]
[.01131 .6034 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .06332 m
.21429 .06957 L
s
[(0.2)] .21429 .05082 0 1 Mshowa
.40476 .06332 m
.40476 .06957 L
s
[(0.4)] .40476 .05082 0 1 Mshowa
.59524 .06332 m
.59524 .06957 L
s
[(0.6)] .59524 .05082 0 1 Mshowa
.78571 .06332 m
.78571 .06957 L
s
[(0.8)] .78571 .05082 0 1 Mshowa
.97619 .06332 m
.97619 .06957 L
s
[(1)] .97619 .05082 0 1 Mshowa
.125 Mabswid
.07143 .06332 m
.07143 .06707 L
s
.11905 .06332 m
.11905 .06707 L
s
.16667 .06332 m
.16667 .06707 L
s
.2619 .06332 m
.2619 .06707 L
s
.30952 .06332 m
.30952 .06707 L
s
.35714 .06332 m
.35714 .06707 L
s
.45238 .06332 m
.45238 .06707 L
s
.5 .06332 m
.5 .06707 L
s
.54762 .06332 m
.54762 .06707 L
s
.64286 .06332 m
.64286 .06707 L
s
.69048 .06332 m
.69048 .06707 L
s
.7381 .06332 m
.7381 .06707 L
s
.83333 .06332 m
.83333 .06707 L
s
.88095 .06332 m
.88095 .06707 L
s
.92857 .06332 m
.92857 .06707 L
s
.25 Mabswid
0 .06332 m
1 .06332 L
s
.02381 .19834 m
.03006 .19834 L
s
[(85)] .01131 .19834 1 0 Mshowa
.02381 .33336 m
.03006 .33336 L
s
[(90)] .01131 .33336 1 0 Mshowa
.02381 .46838 m
.03006 .46838 L
s
[(95)] .01131 .46838 1 0 Mshowa
.02381 .6034 m
.03006 .6034 L
s
[(100)] .01131 .6034 1 0 Mshowa
.125 Mabswid
.02381 .09033 m
.02756 .09033 L
s
.02381 .11733 m
.02756 .11733 L
s
.02381 .14433 m
.02756 .14433 L
s
.02381 .17134 m
.02756 .17134 L
s
.02381 .22535 m
.02756 .22535 L
s
.02381 .25235 m
.02756 .25235 L
s
.02381 .27936 m
.02756 .27936 L
s
.02381 .30636 m
.02756 .30636 L
s
.02381 .36037 m
.02756 .36037 L
s
.02381 .38737 m
.02756 .38737 L
s
.02381 .41438 m
.02756 .41438 L
s
.02381 .44138 m
.02756 .44138 L
s
.02381 .49539 m
.02756 .49539 L
s
.02381 .52239 m
.02756 .52239 L
s
.02381 .5494 m
.02756 .5494 L
s
.02381 .5764 m
.02756 .5764 L
s
.02381 .03632 m
.02756 .03632 L
s
.02381 .00931 m
.02756 .00931 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.03333 .52987 L
.04286 .47106 L
.05238 .42302 L
.0619 .38318 L
.07143 .34969 L
.08095 .32125 L
.09048 .29687 L
.1 .2758 L
.10952 .25745 L
.11905 .24138 L
.12857 .22721 L
.1381 .21464 L
.14762 .20345 L
.15714 .19341 L
.16667 .18438 L
.17619 .17621 L
.18571 .16878 L
.19524 .16199 L
.20476 .15577 L
.21429 .15003 L
.22381 .14472 L
.23333 .13979 L
.24286 .13518 L
.25238 .13086 L
.2619 .1268 L
.27143 .12296 L
.28095 .11932 L
.29048 .11585 L
.3 .11254 L
.30952 .10937 L
.31905 .10632 L
.32857 .10338 L
.3381 .10054 L
.34762 .09779 L
.35714 .09512 L
.36667 .09253 L
.37619 .09 L
.38571 .08753 L
.39524 .08511 L
.40476 .08275 L
.41429 .08043 L
.42381 .07816 L
.43333 .07593 L
.44286 .07374 L
.45238 .07159 L
.4619 .06948 L
.47143 .0674 L
.48095 .06535 L
.49048 .06334 L
Mistroke
.5 .06136 L
.50952 .05941 L
.51905 .05749 L
.52857 .05561 L
.5381 .05376 L
.54762 .05194 L
.55714 .05016 L
.56667 .0484 L
.57619 .04669 L
.58571 .045 L
.59524 .04336 L
.60476 .04174 L
.61429 .04017 L
.62381 .03863 L
.63333 .03713 L
.64286 .03567 L
.65238 .03424 L
.6619 .03286 L
.67143 .03152 L
.68095 .03023 L
.69048 .02898 L
.7 .02777 L
.70952 .02661 L
.71905 .02549 L
.72857 .02442 L
.7381 .0234 L
.74762 .02244 L
.75714 .02152 L
.76667 .02065 L
.77619 .01984 L
.78571 .01909 L
.79524 .01839 L
.80476 .01774 L
.81429 .01716 L
.82381 .01663 L
.83333 .01617 L
.84286 .01576 L
.85238 .01542 L
.8619 .01515 L
.87143 .01494 L
.88095 .01479 L
.89048 .01472 L
.9 .01472 L
.90952 .01478 L
.91905 .01492 L
.92857 .01513 L
.9381 .01542 L
.94762 .01579 L
.95714 .01623 L
.96667 .01676 L
Mistroke
.97619 .01737 L
Mfstroke
0 0 1 r
.02381 .60332 m
.12135 .52987 L
.19426 .47106 L
.25065 .42302 L
.29544 .38318 L
.3318 .34969 L
.36184 .32125 L
.38704 .29687 L
.40845 .2758 L
.42686 .25745 L
.44285 .24138 L
.45686 .22721 L
.46923 .21464 L
.48026 .20345 L
.49014 .19341 L
.49907 .18438 L
.50719 .17621 L
.51462 .16878 L
.52145 .16199 L
.52778 .15577 L
.53366 .15003 L
.53918 .14472 L
.54436 .13979 L
.54927 .13518 L
.55393 .13086 L
.55839 .1268 L
.56266 .12296 L
.56679 .11932 L
.57078 .11585 L
.57466 .11254 L
.57845 .10937 L
.58216 .10632 L
.58581 .10338 L
.58941 .10054 L
.59297 .09779 L
.5965 .09512 L
.60001 .09253 L
.60351 .09 L
.60701 .08753 L
.61051 .08511 L
.61403 .08275 L
.61756 .08043 L
.62111 .07816 L
.62469 .07593 L
.6283 .07374 L
.63195 .07159 L
.63564 .06948 L
.63938 .0674 L
.64316 .06535 L
.647 .06334 L
Mistroke
.65089 .06136 L
.65484 .05941 L
.65885 .05749 L
.66292 .05561 L
.66707 .05376 L
.67128 .05194 L
.67556 .05016 L
.67992 .0484 L
.68436 .04669 L
.68888 .045 L
.69348 .04336 L
.69816 .04174 L
.70293 .04017 L
.70779 .03863 L
.71275 .03713 L
.7178 .03567 L
.72294 .03424 L
.72819 .03286 L
.73353 .03152 L
.73898 .03023 L
.74454 .02898 L
.75021 .02777 L
.75599 .02661 L
.76188 .02549 L
.76789 .02442 L
.77402 .0234 L
.78027 .02244 L
.78665 .02152 L
.79316 .02065 L
.7998 .01984 L
.80657 .01909 L
.81349 .01839 L
.82054 .01774 L
.82774 .01716 L
.83508 .01663 L
.84258 .01617 L
.85023 .01576 L
.85805 .01542 L
.86602 .01515 L
.87417 .01494 L
.88249 .01479 L
.89098 .01472 L
.89965 .01472 L
.90851 .01478 L
.91757 .01492 L
.92681 .01513 L
.93626 .01542 L
.94592 .01579 L
.95579 .01623 L
.96588 .01676 L
Mistroke
.97619 .01737 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`00
5Goo0P00ogoo2Woo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0==oo`El02T07`Moo`00
5Goo00<007ooOol0aWoo27`02P0O<7oo000EOol00`00Oomoo`0ZOol20004Ool20003Ool4000UOol2
0004Ool20005Ool3000SOol20004Ool20003Ool3000MOol:O0000`0001l07`0501l3Ool2000[Ool5
0005Ool001Eoo`03001oogoo02Uoo`04001oogoo0008Ool00`00Oomoo`0UOol01000Oomoo`002goo
00<007ooOol08Goo00@007ooOol000Qoo`04001oogoo000DOol8O007Ool401l00`00Oomoo`06Ool0
1000Oomoo`00;7oo00<007ooOol01Goo000EOol00`00Oomoo`0YOol01000Oomoo`002Goo00<007oo
Ool097oo00@007ooOol000Qoo`D0029oo`04001oogoo0008Ool01000Oomoo`003Goo1g`02Woo1@0O
00Eoo`00Oomoo`0000Qoo`04001oogoo000/Ool00`00Oomoo`05Ool001Eoo`03001oogoo02Uoo`04
001oogoo000:Ool00`00Oomoo`0SOol01000Oomoo`0027oo00@007ooOol002=oo`04001oogoo0008
Ool30006Ool8O00=Ool401l6Ool01000Oomoo`002Goo0P00;Goo00<007ooOol01Goo000EOol2000Z
Ool01000Oomoo`0027oo00@007ooOol002Aoo`04001oogoo0009Ool00`00Ool0000SOol01000Oomo
o`002Goo00<007ooOol01G`04Woo0`0O2Woo00@007ooOol000Qoo`04001oogoo000/Ool00`00Oomo
o`05Ool001Eoo`03001oogoo02Yoo`8000Yoo`8002Ioo`8000]oo`8002Aoo`8000Eoo`Ql01=oo`@0
7`ioo`8000Yoo`8002aoo`8000Moo`005Goo00<007ooOol0Tgoo1G`06Goo0P0OEGoo000EOol00`00
Oomoo`2=Ool6O00KOol301mGOol001Eoo`03001oogoo08Qoo`El01moo`807eYoo`005Goo00<007oo
Ool0Pgoo1G`08Woo0P0OG7oo000EOol00`00Oomoo`1nOol5O00UOol201mNOol000iooh<000El02L0
00<07f0000005Goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo
00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo
00@007ooOomoo`=l00Eoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`0301l007oo
00]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Eoo`005Goo00<007ooOol0<Goo00<007ooOol0<Goo00<0
07ooOol02Goo1G`08Woo00<007ooOol01goo0P0O:7oo00<007ooOol0<Goo00<007ooOol01Goo000E
Ool00`00Oomoo`1/Ool5O00_Ool201mVOol001Eoo`03001oogoo06Uoo`=l03=oo`0301moogoo06Io
o`005Goo00<007ooOol0I7oo1G`0=7oo0P0OJGoo000EOol00`00Oomoo`1QOol3O00iOol00`0OOomo
o`1XOol001Eoo`8005eoo`El03Yoo`807f]oo`005Goo00<007ooOol0FWoo0W`0?Woo00<07gooOol0
Jgoo000EOol00`00Oomoo`1DOol6O00nOol201m^Ool001Eoo`03001oogoo059oo`9l04=oo`0301mo
ogoo06ioo`005Goo00<007ooOol0Cgoo0g`0A7oo00<07gooOol0Kgoo000EOol00`00Oomoo`1:Ool5
O015Ool201mbOol001Eoo`03001oogoo04Moo`=l04Uoo`0301moogoo079oo`005Goo00<007ooOol0
AGoo0W`0Bgoo00<07gooOol0Lgoo000EOol20013Ool3O01<Ool00`0OOomoo`1dOol001Eoo`03001o
ogoo041oo`9l04ioo`0301moogoo07Eoo`005Goo00<007ooOol0?Goo0g`0CWoo0P0ON7oo000EOol0
0`00Oomoo`0kOol2O01@Ool00`0OOomoo`1hOol001Eoo`03001oogoo03Uoo`9l055oo`0301moogoo
07Uoo`005Goo00<007ooOol0=goo0W`0DWoo00<07gooOol0NWoo000EOol00`00Oomoo`0eOol2O01D
Ool00`0OOomoo`1jOol001Eoo`8003Aoo`9l05Aoo`807geoo`005Goo00<007ooOol0<Woo00=l07oo
Ool0Dgoo00<07gooOol0OGoo000EOol00`00Oomoo`0`Ool2O01FOol00`0OOomoo`1mOol001Eoo`03
001oogoo02ioo`9l05Ioo`807h1oo`005Goo00<007ooOol0;Goo00=l07ooOol0EGoo00<07gooOol0
P7oo000EOol00`00Oomoo`0/Ool00g`0Oomoo`1EOol00`0OOomoo`21Ool001Eoo`03001oogoo02Yo
o`9l05Moo`0301moogoo089oo`005Goo0P00:Woo00=l07ooOol0EWoo00<07gooOol0Pgoo000EOol0
0`00Oomoo`0WOol2O01HOol00`0OOomoo`24Ool001Eoo`03001oogoo02Ioo`03O01oogoo05Moo`03
01moogoo08Eoo`005Goo00<007ooOol09Goo00=l07ooOol0Egoo00<07gooOol0QWoo000EOol00`00
Oomoo`0TOol00g`0Oomoo`1GOol00`0OOomoo`27Ool001Eoo`03001oogoo029oo`9l05Uoo`0301mo
ogoo08Qoo`0027oo0P0017oo0P001Goo00<007ooOol08Goo00=l07ooOol0F7oo00<07gooOol0RGoo
0007Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo021oo`03O01oogoo05Qoo`0301mo
ogoo08Yoo`001goo00@007ooOol000Eoo`03001oogoo009oo`<0021oo`03O01oogoo05Moo`0301mo
ogoo08]oo`0027oo0P0017oo0P001Goo00<007ooOol07goo00=l07ooOol0Egoo00<07gooOol0S7oo
0007Ool01000Oomoo`000goo00<007ooOol017oo00<007ooOol07Woo00=l07ooOol0Egoo00<07goo
Ool0SGoo0008Ool20004Ool30004Ool00`00Oomoo`0MOol00g`0Oomoo`1GOol00`0OOomoo`2>Ool0
01Eoo`03001oogoo01aoo`03O01oogoo05Moo`0301moogoo08moo`005Goo00<007ooOol06goo00=l
07ooOol0Egoo00<07gooOol0T7oo000EOol00`00Oomoo`0JOol00g`0Oomoo`1GOol00`0OOomoo`2A
Ool001Eoo`8001]oo`03O01oogoo05Moo`0301moogoo095oo`005Goo00<007ooOol06Goo00=l07oo
Ool0Egoo00<07gooOol0TWoo000EOol00`00Oomoo`0HOol00g`0Oomoo`1GOol00`0OOomoo`2COol0
01Eoo`03001oogoo01Qoo`03O01oogoo05Eoo`807iIoo`005Goo00<007ooOol05goo00=l07ooOol0
EGoo00<07gooOol0UWoo000EOol00`00Oomoo`0FOol00g`0Oomoo`1EOol00`0OOomoo`2GOol001Eo
o`03001oogoo01Ioo`03O01oogoo05Aoo`0301moogoo09Qoo`005Goo0P005Woo00=l07ooOol0EGoo
00<07gooOol0V7oo000EOol00`00Oomoo`0EOol00g`0Oomoo`1DOol00`0OOomoo`2IOol001Eoo`03
001oogoo01Aoo`03O01oogoo05Aoo`0301moogoo09Yoo`005Goo00<007ooOol057oo00=l07ooOol0
Dgoo00<07gooOol0Vgoo000EOol00`00Oomoo`0COol00g`0Oomoo`1COol00`0OOomoo`2LOol001Eo
o`03001oogoo01=oo`03O01oogoo059oo`0301moogoo09eoo`005Goo00<007ooOol04Woo00=l07oo
Ool0DWoo00<07gooOol0WWoo000EOol00`00Oomoo`0BOol00g`0Oomoo`1AOol00`0OOomoo`2OOol0
01Eoo`80019oo`03O01oogoo055oo`0301moogoo0:1oo`005Goo00<007ooOol04Goo00=l07ooOol0
D7oo00<07gooOol0XGoo000EOol00`00Oomoo`0@Ool00g`0Oomoo`1?Ool201nTOol001Eoo`03001o
ogoo011oo`03O01oogoo04ioo`0301moogoo0:Aoo`005Goo00<007ooOol03goo00=l07ooOol0CWoo
00<07gooOol0YGoo000EOol00`00Oomoo`0?Ool00g`0Oomoo`1=Ool00`0OOomoo`2VOol001Eoo`03
001oogoo00ioo`03O01oogoo04eoo`0301moogoo0:Moo`005Goo0P003goo00=l07ooOol0C7oo00<0
7gooOol0Z7oo000EOol00`00Oomoo`0=Ool00g`0Oomoo`1<Ool00`0OOomoo`2YOol001Eoo`03001o
ogoo00eoo`03O01oogoo04]oo`0301moogoo0:Yoo`005Goo00<007ooOol037oo00=l07ooOol0Bgoo
00<07gooOol0Zgoo000EOol00`00Oomoo`0<Ool00g`0Oomoo`1:Ool00`0OOomoo`2/Ool000Moo`<0
00Aoo`8000Eoo`03001oogoo00aoo`03O01oogoo04Uoo`0301moogoo0:eoo`002Goo00D007ooOomo
o`00009oo`03001oogoo009oo`03001oogoo00]oo`03O01oogoo04Uoo`0301moogoo0:ioo`0027oo
0`000Woo00@007ooOol000Aoo`<000]oo`03O01oogoo04Qoo`0301moogoo0:moo`001goo00@007oo
Ool0009oo`04001oogoo0004Ool00`00Oomoo`0;Ool00g`0Oomoo`17Ool00`0OOomoo`2`Ool000Mo
o`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol02goo00=l07ooOol0AWoo00<07gooOol0
/Goo0008Ool30003Ool20005Ool00`00Oomoo`0:Ool00g`0Oomoo`16Ool00`0OOomoo`2bOol001Eo
o`03001oogoo00Yoo`03O01oogoo04Eoo`0301moogoo0;=oo`005Goo00<007ooOol02Woo00=l07oo
Ool0A7oo00<07gooOol0]7oo000EOol00`00Oomoo`0:Ool00g`0Oomoo`13Ool00`0OOomoo`2eOol0
01Eoo`03001oogoo00Uoo`03O01oogoo04=oo`0301moogoo0;Ioo`005Goo0P002Woo00=l07ooOol0
@Woo00<07gooOol0]goo000EOol00`00Oomoo`09Ool00g`0Oomoo`11Ool00`0OOomoo`2hOol001Eo
o`03001oogoo00Qoo`03O01oogoo041oo`807k]oo`005Goo00<007ooOol027oo00=l07ooOol0?goo
00<07gooOol0^goo000EOol00`00Oomoo`08Ool00g`0Oomoo`0nOol00`0OOomoo`2lOol001Eoo`03
001oogoo00Moo`03O01oogoo03ioo`0301moogoo0;eoo`005Goo00<007ooOol01goo00=l07ooOol0
?Goo00<07gooOol0_Woo000EOol20008Ool00g`0Oomoo`0lOol00`0OOomoo`2oOol001Eoo`03001o
ogoo00Moo`03O01oogoo03]oo`0301moogoo0<1oo`005Goo00<007ooOol01Woo00=l07ooOol0>goo
00<07gooOol0`Goo000EOol00`00Oomoo`06Ool00g`0Oomoo`0jOol00`0OOomoo`32Ool001Eoo`03
001oogoo00Ioo`03O01oogoo03Uoo`0301moogoo0<=oo`005Goo00<007ooOol01Woo00=l07ooOol0
=goo0P0OaWoo000EOol00`00Oomoo`06Ool00g`0Oomoo`0fOol00`0OOomoo`36Ool001Eoo`8000Mo
o`03O01oogoo03Eoo`0301moogoo0<Moo`005Goo00<007ooOol01Goo00=l07ooOol0=Goo00<07goo
Ool0b7oo000EOol00`00Oomoo`05Ool00g`0Oomoo`0dOol00`0OOomoo`39Ool001Eoo`03001oogoo
00Eoo`03O01oogoo03=oo`0301moogoo0<Yoo`005Goo00<007ooOol01Goo00=l07ooOol0<Woo00<0
7gooOol0bgoo000EOol00`00Oomoo`05Ool00g`0Oomoo`0`Ool201o>Ool001Eoo`03001oogoo00Ao
o`03O01oogoo031oo`0301moogoo0<ioo`005Goo00<007ooOol017oo00=l07ooOol0;goo00<07goo
Ool0cgoo000EOol20005Ool00g`0Oomoo`0^Ool00`0OOomoo`3@Ool001Eoo`03001oogoo00Aoo`03
O01oogoo02eoo`0301moogoo0=5oo`005Goo00<007ooOol00goo00=l07ooOol0;7oo0P0Oe7oo000E
Ool00`00Oomoo`03Ool00g`0Oomoo`0[Ool00`0OOomoo`3DOol001Eoo`03001oogoo00=oo`03O01o
ogoo02Yoo`0301moogoo0=Eoo`001goo0`0017oo0P001Goo00<007ooOol00goo00=l07ooOol0:Goo
00<07gooOol0eWoo0009Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol00Woo00=l
07ooOol0:7oo0P0OfGoo0008Ool30005Ool00`00Oomoo`02Ool30002Ool00g`0Oomoo`0WOol00`0O
Oomoo`3IOol000Moo`04001oogoo0003Ool20005Ool00`00Oomoo`02Ool00g`0Oomoo`0VOol00`0O
Oomoo`3JOol000Moo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00g`0Oomoo`0U
Ool00`0OOomoo`3KOol000Qoo`<000=oo`<000Aoo`03001oogoo009oo`03O01oogoo02=oo`807mio
o`005Goo00D007ooOomoog`002Eoo`0301moogoo0=ioo`005Goo00D007ooOomoog`002Aoo`0301mo
ogoo0=moo`005Goo00D007ooOomoog`002=oo`0301moogoo0>1oo`005Goo0P000Woo00=l07ooOol0
7goo0P0Ohgoo000EOol01@00OomoogooO00087oo00<07gooOol0hgoo000EOol01000Oomoog`087oo
00<07gooOol0i7oo000EOol01000Oomoog`07goo00<07gooOol0iGoo000EOol01000Oomoog`07Goo
0P0Oj7oo000EOol01000Oomoog`077oo00<07gooOol0j7oo000EOol01000Oomoog`06goo00<07goo
Ool0jGoo000EOol01000Oomoog`06Woo00<07gooOol0jWoo000EOol200000g`0Oomoo`0GOol201o]
Ool001Eoo`03001oog`001Qoo`0301moogoo0>eoo`005Goo00<007ooO0005goo00<07gooOol0kWoo
000EOol00`00Ooml000FOol00`0OOomoo`3_Ool001Eoo`03001oog`001Aoo`807o9oo`005Goo00<0
07ooO0004goo00<07gooOol0lWoo000EOol00`00Ooml000BOol00`0OOomoo`3cOol001Eoo`03001l
07oo011oo`807oIoo`005Goo00<007`0Ool03goo00<07gooOol0mWoo000EOol00`00O01oo`0>Ool0
0`0OOomoo`3gOol001Eoo`03001l07oo00aoo`807oYoo`005Goo00<007`0Ool02goo00<07gooOol0
nWoo000EOol00`00O01oo`0:Ool00`0OOomoo`3kOol001Eoo`03001l07oo00Uoo`0301moogoo0?ao
o`005Goo00<007`0Ool01goo0P0Oogoo000EOol00`00O01oo`06Ool00`0OOomoo`3oOol001Eoo`03
001l07oo00Eoo`0301moogoo0?moo`5oo`005Goo00=l07ooOol00goo0P0Oogoo17oo000EOol00g`0
Oomoo`02Ool00`0OOomoo`3oOol4Ool001Eoo`05O01oogooOol07`3oOol7Ool00003Ool0000000<0
009oo`8000Aoo`8000Eoo`04O01oo`0O01ooOol8Ool000=oo`05001oogooOol00002Ool01000Oomo
o`000Woo00<007ooOol00Woo00=l000OOol0ogoo2Goo0003Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`03001oogoo009oo`0301l000000?moo`Uoo`000goo00D007ooOomoo`00009oo`04001o
ogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`3oOol9Ool000=oo`05001oogooOol00002Ool01000
Oomoo`000Woo00<007ooOol00Woo00<007ooOol0ogoo2Goo0002Ool20004Ool20004Ool20005Ool0
0`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0825959, 77.0922, \
0.00385924, 0.136108}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
CellGrouping->Manual,
WindowSize->{531, 540},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 188, 4, 128, "Title"],

Cell[CellGroupData[{
Cell[1989, 61, 116, 1, 46, "Subsubtitle"],
Cell[2108, 64, 153, 2, 70, "Input"],
Cell[2264, 68, 149, 2, 50, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2450, 75, 107, 1, 48, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2582, 80, 73, 1, 30, "Input"],
Cell[2658, 83, 64, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2759, 89, 73, 1, 30, "Input"],
Cell[2835, 92, 64, 1, 29, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2948, 99, 121, 1, 48, "Subsubtitle"],
Cell[3072, 102, 310, 7, 70, "Input"],
Cell[3385, 111, 74, 1, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3496, 117, 92, 1, 48, "Subsubtitle"],
Cell[3591, 120, 54, 1, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3682, 126, 139, 2, 48, "Subsubtitle"],
Cell[3824, 130, 280, 6, 110, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4141, 141, 99, 1, 48, "Subsubtitle"],
Cell[4243, 144, 75, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[4343, 149, 216, 5, 70, "Input"],
Cell[4562, 156, 13846, 429, 186, 4520, 309, "GraphicsData", "PostScript", \
"Graphics"],
Cell[18411, 587, 130, 3, 29, "Output"]
}, Open  ]],
Cell[18556, 593, 75, 1, 30, "Input"],
Cell[18634, 596, 76, 1, 30, "Input"],
Cell[18713, 599, 76, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[18814, 604, 156, 3, 50, "Input"],
Cell[18973, 609, 12513, 412, 186, 4466, 308, "GraphicsData", "PostScript", \
"Graphics"],
Cell[31489, 1023, 130, 3, 29, "Output"]
}, Open  ]],
Cell[31634, 1029, 76, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[31735, 1034, 156, 3, 50, "Input"],
Cell[31894, 1039, 12763, 415, 186, 4489, 308, "GraphicsData", "PostScript", \
"Graphics"],
Cell[44660, 1456, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44827, 1464, 49, 1, 30, "Input"],
Cell[44879, 1467, 16156, 542, 186, 6100, 413, "GraphicsData", "PostScript", \
"Graphics"],
Cell[61038, 2011, 130, 3, 29, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

