(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     86540,       3117]*)
(*NotebookOutlinePosition[     87184,       3139]*)
(*  CellTagsIndexPosition[     87140,       3135]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Wei-Prater mechanism (3-reactant triangle network)\nA1=A2=A3=A1 \
with rate constants k12, k21, k23, k32, k31, k13. \nNot all rate constants \
are independent : ",
    FontFamily->"Arial",
    FontSize->20,
    FontWeight->"Bold"],
  StyleBox["k32=k23 (k12/k21) (k31/k13)",
    FontSize->20]
}], "Title",
  TextAlignment->Center,
  Background->RGBColor[0.623529, 1, 0.811765]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[A1, A2, A3, sequil];\)\), "\[IndentingNewLine]", 
    \(k12 =  .5; k21 = 0.7; k13 =  .1; k31 =  .2; k23 =  .9; 
    k32 = k23\ \((k12/k21)\)\ \((k31/k13)\)\), "\[IndentingNewLine]", 
    \(A1o =  .7; A2o = 0; A3o =  .3; tf = 10;\), "\[IndentingNewLine]", 
    \(sequil = \(\(Solve[{0 \[Equal] \(-\((k12\  + k13)\)\)\ A1 + k21\ \ A2 + 
                k31\ \ A3\ , 
            0 \[Equal] k12\ \ A1\  - \((k21\  + k23)\) A2 + k32\ \ A3, 
            A3 \[Equal] A1o + A2o + A3o - A1 - A2}, \[IndentingNewLine]{A1, 
            A2, A3}]\)\(//\)\(Simplify\)\(\ \)\( (*next\ \(CHECK!\)*) \)\)\), \
"\[IndentingNewLine]", 
    \({A1 + A2 + A3, A2/A1, k12/k21, A3/A1, k13/k31, A3/A2, k23/k32} /. 
      sequil\), "\[IndentingNewLine]", 
    \(\(Clear[A1, A2, A3, solWP];\)\), "\[IndentingNewLine]", 
    \(\(solWP = 
        NDSolve[{\[IndentingNewLine]\(A1'\)[
                t] \[Equal] \(-\((k12\  + k13)\)\)\ A1[t] + k21\ \ A2[t] + 
                k31\ \ \((A1o + A2o + A3o - A1[t] - A2[t])\)\ , \(A2'\)[
                t] \[Equal] 
              k12\ \ A1[t]\  - \((k21\  + k23)\) A2[t] + 
                k32\ \ \((A1o + A2o + A3o - A1[t] - 
                      A2[t])\), \[IndentingNewLine]A1[0] \[Equal] A1o, 
            A2[0] \[Equal] A2o}, \[IndentingNewLine]{A1[t], A2[t]}, {t, 0, 
            tf}];\)\), "\[IndentingNewLine]", 
    \(\(\(({A1[t], A2[t], A1o + A2o + A3o - A1[t] - A2[t]})\) /. solWP\) /. 
      t \[Rule] tf\), "\[IndentingNewLine]", 
    \(Plot[
      Evaluate[Table[{A1[t], A2[t], A1o + A2o + A3o - A1[t] - A2[t]} /. 
            solWP]], {t, 0, tf}, Frame \[Rule] True, 
      DefaultFont \[Rule] {"\<Symbol-Bold\>", 14}, 
      FrameLabel \[Rule] {"\<t\>", "\<A1, A2, A3\>"}, 
      PlotRange \[Rule] {{0, tf}, {0, 1}}, 
      PlotStyle \[Rule] {RGBColor[1, 0, 0], RGBColor[0, 1, 0], 
          RGBColor[0, 0, 1]}]; 
    ParametricPlot[Evaluate[Table[{A2[t], A1[t]} /. solWP]], {t, 0, tf}, 
      Frame \[Rule] True, DefaultFont \[Rule] {"\<Symbol-Bold\>", 14}, 
      FrameLabel \[Rule] {"\<A2\>", "\<A1\>"}, 
      PlotRange \[Rule] {{0, 1}, {0, 1}}];\), "\[IndentingNewLine]", 
    \(\(ParametricPlot[
        Evaluate[
          Table[{A1o + A2o + A3o - A1[t] - A2[t], A1[t]} /. solWP]], {t, 0, 
          tf}, Frame \[Rule] True, 
        DefaultFont \[Rule] {"\<Symbol-Bold\>", 14}, 
        FrameLabel \[Rule] {"\<A3\>", "\<A1\>"}, 
        PlotRange \[Rule] {{0, 1}, {0, 1}}];\)\)}], "Input"],

Cell[BoxData[
    \(1.2857142857142858`\)], "Output"],

Cell[BoxData[
    \({{A1 \[Rule] 0.4516129032258064`, A2 \[Rule] 0.3225806451612903`, 
        A3 \[Rule] 0.22580645161290325`}}\)], "Output"],

Cell[BoxData[
    \({{1.`, 0.7142857142857143`, 0.7142857142857143`, 0.5000000000000001`, 
        0.5`, 0.7000000000000001`, 0.7`}}\)], "Output"],

Cell[BoxData[
    \({{0.45162046090966584`, 0.3225774807807319`, 
        0.22580205830960226`}}\)], "Output"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14  scalefont  setfont
% Scaling calculations
-2.77556e-017 0.1 0 0.618034 [
[.2 -0.0125 -5.53125 -19.3125 ]
[.2 -0.0125 5.53125 0 ]
[.4 -0.0125 -5.53125 -19.3125 ]
[.4 -0.0125 5.53125 0 ]
[.6 -0.0125 -5.53125 -19.3125 ]
[.6 -0.0125 5.53125 0 ]
[.8 -0.0125 -5.53125 -19.3125 ]
[.8 -0.0125 5.53125 0 ]
[1 -0.0125 -9.0625 -19.3125 ]
[1 -0.0125 9.0625 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -3.96875 -38.625 ]
[.5 -0.0125 3.96875 -19.3125 ]
[-0.0125 .12361 -21.5625 -9.65625 ]
[-0.0125 .12361 0 9.65625 ]
[-0.0125 .24721 -21.5625 -9.65625 ]
[-0.0125 .24721 0 9.65625 ]
[-0.0125 .37082 -21.5625 -9.65625 ]
[-0.0125 .37082 0 9.65625 ]
[-0.0125 .49443 -21.5625 -9.65625 ]
[-0.0125 .49443 0 9.65625 ]
[-0.0125 .61803 -11.0625 -9.65625 ]
[-0.0125 .61803 0 9.65625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -40.875 -34.8125 ]
[-0.01875 .30902 -21.5625 34.8125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
gsave
.2 -0.0125 -66.5313 -23.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.4 0 m
.4 .00625 L
s
gsave
.4 -0.0125 -66.5313 -23.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.6 0 m
.6 .00625 L
s
gsave
.6 -0.0125 -66.5313 -23.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.8 0 m
.8 .00625 L
s
gsave
.8 -0.0125 -66.5313 -23.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -70.0625 -23.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -64.9688 -42.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
66.938 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
gsave
-0.0125 .12361 -82.5625 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .24721 m
.00625 .24721 L
s
gsave
-0.0125 .24721 -82.5625 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .37082 m
.00625 .37082 L
s
gsave
-0.0125 .37082 -82.5625 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .49443 m
.00625 .49443 L
s
gsave
-0.0125 .49443 -82.5625 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -72.0625 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -127.031 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
95.8125 13.6563 translate
90 rotate
-95.8125 -13.6563 translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.125 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.250 19.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
104.375 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.500 19.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
128.625 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
0 .43262 m
.01975 .39557 L
.04057 .36782 L
.06168 .34751 L
.08481 .3313 L
.10536 .32054 L
.12734 .3117 L
.14971 .30478 L
.17086 .29967 L
.2112 .29266 L
.23202 .29006 L
.25411 .28785 L
.29383 .28495 L
.31421 .28386 L
.33613 .28292 L
.35683 .2822 L
.37942 .28157 L
.42111 .28072 L
.44177 .28042 L
.46379 .28016 L
.48477 .27996 L
.50745 .27979 L
.54952 .27955 L
.57046 .27947 L
.59258 .2794 L
.63245 .2793 L
.65293 .27927 L
.67489 .27924 L
.69569 .27921 L
.71832 .27919 L
.76016 .27916 L
.78092 .27915 L
.80298 .27915 L
.84262 .27913 L
.86293 .27913 L
.88483 .27913 L
.90546 .27912 L
.92803 .27912 L
.94814 .27912 L
.96963 .27912 L
1 .27912 L
s
0 1 0 r
0 0 m
.00942 .03819 L
.01975 .07097 L
.03053 .09743 L
.04057 .11661 L
.05176 .13325 L
.06194 .14507 L
.0737 .15572 L
.08481 .16355 L
.09499 .16926 L
.10578 .17414 L
.12514 .18065 L
.13503 .18316 L
.14565 .18541 L
.16487 .18856 L
.18706 .19119 L
.20816 .193 L
.22895 .19434 L
.24826 .19531 L
.26981 .19615 L
.28934 .19675 L
.31126 .19728 L
.33141 .19768 L
.37189 .19825 L
.39166 .19845 L
.41335 .19863 L
.43556 .19878 L
.4558 .19889 L
.49665 .19905 L
.51669 .19911 L
.53849 .19916 L
.55885 .1992 L
.58131 .19923 L
.62254 .19928 L
.64286 .19929 L
.66476 .19931 L
.68539 .19932 L
.70795 .19933 L
.74956 .19934 L
.77015 .19935 L
.79215 .19935 L
.81305 .19935 L
.83572 .19936 L
.8777 .19936 L
.89857 .19936 L
.92067 .19936 L
.93984 .19936 L
.96045 .19936 L
1 .19936 L
s
0 0 1 r
0 .18541 m
.00942 .1665 L
.01975 .15149 L
.02496 .14569 L
.03053 .14056 L
.04057 .13361 L
.04628 .13071 L
.05248 .12827 L
.05833 .12652 L
.06373 .1253 L
.0686 .12448 L
.07396 .12383 L
.07666 .1236 L
.07956 .1234 L
.08097 .12332 L
.0823 .12326 L
.08361 .12321 L
.08481 .12318 L
.08611 .12315 L
.0868 .12314 L
.08753 .12313 L
.08875 .12311 L
.09009 .12311 L
.09128 .12311 L
.09256 .12312 L
.09377 .12313 L
.09487 .12315 L
.09751 .12321 L
.10038 .12331 L
.1056 .12354 L
.11563 .12416 L
.12491 .12488 L
.16614 .12859 L
.20578 .13178 L
.2278 .13322 L
.24799 .13433 L
.28861 .13604 L
.30848 .13667 L
.33022 .13723 L
.35253 .13769 L
.37281 .13804 L
.41381 .13855 L
.43395 .13873 L
.45579 .1389 L
.47625 .13902 L
.49875 .13913 L
.54013 .13927 L
.56054 .13933 L
.58248 .13937 L
.60322 .13941 L
Mistroke
.62582 .13944 L
.66757 .13948 L
.68827 .13949 L
.7103 .13951 L
.73132 .13952 L
.75402 .13952 L
.79614 .13953 L
.81712 .13954 L
.83925 .13954 L
.87918 .13955 L
.8997 .13955 L
.92168 .13955 L
.94252 .13955 L
.96516 .13955 L
1 .13955 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00:1oo`8007ioo`00X7oo00<007oo0000OGoo002POol0
0`00Oomoo`1mOol00:1oo`03001oogoo07eoo`00X7oo00<007ooOol0OGoo002POol00`00Oomoo`1m
Ool009moo`<007ioo`00X7oo00<007ooOol0OGoo002POol00`00Oomoo`1mOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00H7oo1P009goo0P0097oo1@009Goo10008Goo100017oo0`004goo001QOol20002Ool2
000VOol2000SOol20003Ool2000SOol20002Ool2000QOol20004Ool200000goo0000000BOol0065o
o`8002Ioo`L0029oo`8000=oo`8002=oo`80009oo`80025oo`8000=oo`8000=oo`80015oo`00HWoo
0P009Goo0P000Woo0P008goo0P000goo0P008goo0P000Woo0P008Goo0P000goo0P000goo0P004Goo
001SOol2000UOol200000goo0000000SOol30002Ool2000TOol4000ROol20003Ool20003Ool2000A
Ool006Aoo`8002Eoo`@002=oo`H002Eoo`@0029oo`8000=oo`8000=oo`80015oo`00I7oo0P009Goo
100097oo0P009goo0P000Woo0P008Goo0P000goo0P000goo0P004Goo001TOol2000VOol3000TOol2
000WOol20002Ool2000QOol20003Ool20003Ool2000AOol0061oo`800004Ool00000000VOol3000U
Ool3000UOol20002Ool2000POol30004Ool200000goo0000000BOol0065oo`@002Qoo`8002Ioo`@0
02Aoo`@0029oo`8000Eoo`<001=oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo000kOoo=000HOol003]oo`030n1oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo01Ioo`00>goo00<000?POol0
bGoo00<007ooOol05Woo000kOol00`000n1oo`39Ool00`00Oomoo`0FOol003]oo`030003h7oo0<Uo
o`03001oogoo01Ioo`00>goo00<000?POol0bGoo00<007ooOol05Woo000kOol200000`?POomoo`36
Ool2000HOol003]oo`03001oo`?P0<Uoo`03001oogoo01Ioo`00>goo00<007oo0n00bGoo00<007oo
Ool05Woo000kOol00`00Ool3h039Ool00`00Oomoo`0FOol003]oo`04001oogoo0n38Ool00`00Oomo
o`0FOol003]oo`04001oogoo0n38Ool00`00Oomoo`0FOol003]oo`800003Ool3h7oo0<Ioo`8001Qo
o`00>goo00D007ooOomoo`?P0<Moo`03001oogoo01Ioo`00>goo00D007ooOomoo`?P0<Moo`03001o
ogoo01Ioo`00>goo00D007ooOomoo`?P0<Moo`03001oogoo01Ioo`00>goo00<007ooOol00Woo00<3
h7ooOol0a7oo00<007ooOol05Woo000kOol00`00Oomoo`02Ool00`?POomoo`34Ool00`00Oomoo`0F
Ool003]oo`03001oogoo009oo`030n1oogoo0<Aoo`03001oogoo01Ioo`00>goo0P0017oo00<3h7oo
Ool0`Woo0P0067oo000WOol30004Ool20002Ool60003Ool00`00Oomoo`03Ool00`?POomoo`33Ool0
0`00Oomoo`0FOol002Ioo`800003Ool0000000Qoo`80009oo`80009oo`03001oogoo00Aoo`030n1o
ogoo0<9oo`03001oogoo01Ioo`009Goo0P000goo0P001goo0P001Woo00<007ooOol017oo00<3h7oo
Ool0`Woo00<007ooOol05Woo000UOol20003Ool20008Ool20005Ool00`00Oomoo`05Ool00`?POomo
o`31Ool00`00Oomoo`0FOol002Eoo`8000=oo`8000Uoo`8000Aoo`03001oogoo00Eoo`030n1oogoo
0<5oo`03001oogoo01Ioo`009Goo0P000goo0P002Woo0P000goo0P001goo00@3h7ooOomooa407jeo
o`8001Qoo`009Goo0P000goo0P002Woo0P000goo00<007ooOol01Woo100O4Goo200OYWoo00<007oo
Ool05Woo000UOol20003Ool2000:Ool20003Ool00`00Oomoo`05Ool00`0OOol3h00KOolG01n?Ool0
0`00Oomoo`0FOol002Ioo`800003Ool0000000Moo`800004Ool000000003Ool00`00Oomoo`03Ool2
01l3Ool00`?POomoo`0_Oon?01l00`00Oomoo`0FOol002Moo`<000Uoo`@000Aoo`03001oogoo009o
o`0301moogoo00Aoo`030n1oogoo0;eoo`03001oogoo01Ioo`00>goo00D007ooOomoo`0O00Qoo`03
0n1oogoo0;aoo`03001oogoo01Ioo`0077oo00<007ooOol077oo0P000Woo00<07gooOol01goo00<3
h7ooOol0^Woo0P0067oo000JOol3000NOol01000Oomoo`0O2goo00<3h7ooOol0^Woo00<007ooOol0
5Woo000GOol30002Ool00`00Oomoo`0LOol01000Oomoo`0O37oo0P?P^Woo00<007ooOol05Woo000E
Ool20002Ool00`00Oomoo`0OOol00`00Ool07`0?Ool20n2hOol00`00Oomoo`0FOol001=oo`8000Ao
o`03001oogoo01moo`0300007goo015oo`83h;Ioo`03001oogoo01Ioo`005Goo0P000Woo00<007oo
Ool07goo00<0000OOol04goo0P?P]7oo00<007ooOol05Woo000GOol30002Ool00`00Oomoo`0LOol0
0`0OOomoo`0EOol50n2_Ool00`00Oomoo`0FOol001Yoo`<001ioo`0301l007oo01Yoo`L3h:Moo`80
01Qoo`0077oo00<007ooOol077oo00<007ooOol08Goo3@?PVgoo00<007ooOol05Woo000kOol00`00
Oomoo`0^OonK0n000`00Oomoo`0FOol003]oo`03001oogoo0<Uoo`03001oogoo01Ioo`0057oo0P00
1Woo0P007Goo00<007ooOol0bGoo00<007ooOol05Woo000COol;000MOol00`00Oomoo`39Ool00`00
Oomoo`0FOol001aoo`8001eoo`800<Uoo`8001Qoo`00>goo00<007ooOol0bGoo00<007ooOol05Woo
000WOol30004Ool20006Ool20003Ool00`00Oomoo`39Ool00`00Oomoo`0FOol002Ioo`800003Ool0
000000]oo`8000=oo`03001oogoo0<Uoo`03001oogoo01Ioo`009Goo0P000goo0P001Woo1`000Woo
00<007ooOol0bGoo00<007ooOol05Woo000LOol40005Ool20003Ool20006Ool20002Ool20003Ool0
0`00Oomoo`39Ool00`00Oomoo`0FOol001aoo`<000Ioo`8000=oo`8000Moo`800003Ool0000000=o
o`800<Uoo`8001Qoo`009Goo0P000goo0P0027oo10000goo00<007ooOol0bGoo00<007ooOol05Woo
000UOol20003Ool20008Ool40003Ool00`00Oomoo`39Ool00`00Oomoo`0FOol002Eoo`8000=oo`80
00Uoo`<000=oo`03001oogoo0<Uoo`03001oogoo01Ioo`009Woo0P0000=oo`0000002Woo0`000goo
00<007ooOol0bGoo00<007ooOol05Woo000LOol00`00Oomoo`08Ool3000<Ool20003Ool00`00Oomo
o`39Ool00`00Oomoo`0FOol001Yoo`<001ioo`800<Uoo`8001Qoo`005goo0`000Woo00<007ooOol0
77oo00<007ooOol0@7ooRG`000<007ooOol05Woo000EOol20002Ool00`00Oomoo`0OOol00`00Oomo
o`0_OolAO029Ool00`00Oomoo`0FOol001=oo`8000Aoo`03001oogoo01moo`03001oogoo02Moo`Ql
09Yoo`03001oogoo01Ioo`005Goo0P000Woo00<007ooOol07goo00<007ooOol08goo17`0XWoo00<0
07ooOol05Woo000GOol30002Ool00`00Oomoo`0LOol00`00Oomoo`0NOol5O02VOol00`00Oomoo`0F
Ool001Yoo`<001ioo`03001oogoo01Yoo`Al0:]oo`03001oogoo01Ioo`0077oo00<007ooOol077oo
0P005goo17`0[Woo0P0067oo000DOol20006Ool2000MOol00`00Oomoo`0DOol2O02cOol00`00Oomo
o`0FOol001=oo`8000Eoo`@001eoo`03001oogoo019oo`9l0;Eoo`03001oogoo01Ioo`004goo0P00
17oo0P0000=oo`0000007Goo00<007ooOol047oo0W`0]goo00<007ooOol05Woo000COol30002Ool2
0002Ool2000MOol00`00Oomoo`0>Ool2O02iOol00`00Oomoo`0FOol001Aoo`D000=oo`8001eoo`03
001oogoo00eoo`03O01oogoo0;Uoo`03001oogoo01Ioo`006goo0P007Woo0P0037oo0W`0^goo0P00
67oo000kOol00`00Oomoo`0:Ool00g`0Oomoo`2lOol00`00Oomoo`0FOol002Moo`<000Aoo`8000=o
o`D000=oo`03001oogoo00Uoo`03O01oogoo0;eoo`03001oogoo01Ioo`009Woo0P0000=oo`000000
1goo0P000goo0P000Woo00<007ooOol027oo00=l07ooOol0_Woo00<007ooOol05Woo000LOol40005
Ool20003Ool20006Ool20003Ool20002Ool00`00Oomoo`07Ool00g`0Oomoo`2oOol00`00Oomoo`0F
Ool001aoo`<000Ioo`8000=oo`8000Ioo`8000=oo`80009oo`03001oogoo00Ioo`03O01oogoo0<1o
o`03001oogoo01Ioo`009Goo0P000goo0P001Woo0`000Woo0P000Woo0P001Woo00=l07ooOol0`7oo
0P0067oo000UOol20003Ool20006Ool60003Ool00`00Oomoo`04Ool00g`0Oomoo`32Ool00`00Oomo
o`0FOol002Eoo`8000=oo`8000Moo`8000Ioo`03001oogoo00=oo`03O01oogoo0<=oo`03001oogoo
01Ioo`009Goo0P000goo0P001goo0P001Woo00<007ooOol00goo00=l07ooOol0`goo00<007ooOol0
5Woo000VOol200000goo00000009Ool30004Ool00`00Oomoo`02Ool00g`0Oomoo`34Ool00`00Oomo
o`0FOol001aoo`03001oogoo00Qoo`<000]oo`@0009oo`05001oogooOoml0037Ool00`00Oomoo`0F
Ool001Yoo`<001ioo`04001oogooO038Ool00`00Oomoo`0FOol001Moo`<0009oo`03001oogoo01ao
o`800003Ooml07oo0<Ioo`8001Qoo`005Goo0P000Woo00<007ooOol07goo00<007ooO000bGoo00<0
07ooOol05Woo000COol20004Ool00`00Oomoo`0OOol00`00Ooml0039Ool00`00Oomoo`0FOol001Eo
o`80009oo`03001oogoo01moo`03001l07oo0<Uoo`03001oogoo01Ioo`005goo0`000Woo00<007oo
Ool077oo00<007`0Ool0bGoo00<007ooOol05Woo000JOol3000NOol00g`0Oomoo`39Ool00`00Oomo
o`0FOol001aoo`03001oogoo01aoo`03O00007oo0<Qoo`8001Qoo`00>goo00<007ooOol0bGoo00<0
07ooOol05Woo000DOol20006Ool2000MOol00`00Oomoo`39Ool00`00Oomoo`0FOol001=oo`8000Mo
o`8001eoo`03001oogoo0<Uoo`03001oogoo01Ioo`004goo0P0000Aoo`00000000=oo`8001eoo`03
001oogoo0<Uoo`03001oogoo01Ioo`0057oo1P0000=oo`0000007Woo00<007ooOol0bGoo00<007oo
Ool05Woo000HOol4000OOol20039Ool2000HOol003]oo`03001oogoo0<Uoo`03001oogoo01Ioo`00
9goo0`0017oo0P0017oo10000goo00<007ooOol0bGoo00<007ooOol05Woo000VOol200000goo0000
0008Ool20002Ool20002Ool00`00Oomoo`39Ool00`00Oomoo`0FOol002Eoo`8000=oo`8000Moo`80
009oo`80009oo`03001oogoo0<Uoo`03001oogoo01Ioo`009Goo0P000goo0P001goo0P000Woo0P00
0Woo00<007ooOol0bGoo00<007ooOol05Woo000UOol20003Ool20008Ool40003Ool00`00Oomoo`39
Ool00`00Oomoo`0FOol002Eoo`8000=oo`8000Qoo`@000=oo`800<Uoo`8001Qoo`009Goo0P000goo
0P001goo0P000Woo0P000Woo00<007ooOol0bGoo00<007ooOol05Woo000UOol20003Ool20007Ool2
0002Ool20002Ool00`00Oomoo`39Ool00`00Oomoo`0FOol002Ioo`800003Ool0000000Qoo`80009o
o`80009oo`03001oogoo0<Uoo`03001oogoo01Ioo`009goo0`002Woo10000goo00<007ooOol0bGoo
00<007ooOol05Woo000kOol00`00Oomoo`39Ool00`00Oomoo`0FOol003]oo`800<Uoo`8001Qoo`00
>goo00<007ooOol0bGoo00<007ooOol05Woo000kOol00`00Oomoo`39Ool00`00Oomoo`0FOol003]o
o`03001oogoo0<Uoo`03001oogoo01Ioo`00>goo00<007ooOol0bGoo00<007ooOol05Woo000kOol0
0`00Oomoo`39Ool00`00Oomoo`0FOol003]oo`800<Uoo`8001Qoo`00>goo00<007ooOol0bGoo00<0
07ooOol05Woo000kOol00`00Oomoo`39Ool00`00Oomoo`0FOol003]oo`03001oogoo0<Uoo`03001o
ogoo01Ioo`00>goo00<007ooOol0bGoo00<007ooOol05Woo000kOol00`00Oomoo`39Ool00`00Oomo
o`0FOol003]oo`03001oogoo0<Uoo`03001oogoo01Ioo`00>goo0P00bGoo0P0067oo000aOol40006
Ool00`00Oomoo`39Ool00`00Oomoo`0FOol0039oo`8000Moo`03001oogoo0<Uoo`03001oogoo01Io
o`00<Woo0P001goo00<007ooOol0bGoo00<007ooOol05Woo000bOol20007Ool00`00Oomoo`39Ool0
0`00Oomoo`0FOol0039oo`8000Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Qoo`03001oogoo00Moo`03001oogoo01Ioo`00<Woo0P001gooc@0067oo000bOol2003/
Ool0039oo`800>aoo`00<Goo0`00k7oo000bOol2003/Ool00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.90615, -0.326522, \
0.0490094, 0.00792988}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -10.7813 -19.3125 ]
[.2 -0.0125 10.7813 0 ]
[.4 -0.0125 -10.7813 -19.3125 ]
[.4 -0.0125 10.7813 0 ]
[.6 -0.0125 -10.7813 -19.3125 ]
[.6 -0.0125 10.7813 0 ]
[.8 -0.0125 -10.7813 -19.3125 ]
[.8 -0.0125 10.7813 0 ]
[1 -0.0125 -5.53125 -19.3125 ]
[1 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -10.5625 -38.625 ]
[.5 -0.0125 10.5625 -19.3125 ]
[-0.0125 .12361 -21.5625 -9.65625 ]
[-0.0125 .12361 0 9.65625 ]
[-0.0125 .24721 -21.5625 -9.65625 ]
[-0.0125 .24721 0 9.65625 ]
[-0.0125 .37082 -21.5625 -9.65625 ]
[-0.0125 .37082 0 9.65625 ]
[-0.0125 .49443 -21.5625 -9.65625 ]
[-0.0125 .49443 0 9.65625 ]
[-0.0125 .61803 -11.0625 -9.65625 ]
[-0.0125 .61803 0 9.65625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -40.875 -10.5625 ]
[-0.01875 .30902 -21.5625 10.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
gsave
.2 -0.0125 -71.7813 -23.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.4 0 m
.4 .00625 L
s
gsave
.4 -0.0125 -71.7813 -23.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.6 0 m
.6 .00625 L
s
gsave
.6 -0.0125 -71.7813 -23.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.8 0 m
.8 .00625 L
s
gsave
.8 -0.0125 -71.7813 -23.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -66.5313 -23.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -71.5625 -42.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
80.125 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
gsave
-0.0125 .12361 -82.5625 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .24721 m
.00625 .24721 L
s
gsave
-0.0125 .24721 -82.5625 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .37082 m
.00625 .37082 L
s
gsave
-0.0125 .37082 -82.5625 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .49443 m
.00625 .49443 L
s
gsave
-0.0125 .49443 -82.5625 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -72.0625 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -102.781 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
71.5625 13.6563 translate
90 rotate
-71.5625 -13.6563 translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.125 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .43262 m
.18867 .36782 L
.26463 .3313 L
.29284 .31205 L
.30542 .30067 L
.31236 .29299 L
.31612 .28824 L
.31852 .28498 L
.31995 .28295 L
.32084 .28166 L
.32146 .28077 L
.32184 .2802 L
.32209 .27984 L
.32226 .27959 L
.32237 .27943 L
.32244 .27932 L
.32249 .27925 L
.32252 .2792 L
.32254 .27917 L
.32255 .27915 L
.32256 .27914 L
.32257 .27913 L
.32257 .27912 L
.32258 .27912 L
.32258 .27912 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol009Yoo`<000=oo`T007Moo`00Vgoo00<007ooOol00goo
00<007ooOol00P000Woo0P00MWoo002KOol00`00Oomoo`03Ool00`00Oomoo`02001jOol009aoo`D0
00Aoo`8007Uoo`00W7oo00D007ooOomoo`0000Eoo`8007Qoo`00W7oo00D007ooOomoo`0000Ioo`80
07Moo`00WGoo00<007oo00001goo0P00Mgoo002MOol00`00Ool00007Ool2001gOol009ioo`03001o
ogoo009oo`800004Ool00000001gOol009ioo`03001oogoo00=oo`@007Qoo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
Ggoo0`0017oo0P000Woo1P005goo0`0017oo0P001Woo0P0067oo0`0017oo0P000goo1@0067oo0`00
17oo0P0017oo10007Goo10005Goo001NOol200000goo00000008Ool20002Ool2000EOol200000goo
0000000;Ool2000GOol200000goo00000007Ool20003Ool2000FOol200000goo00000008Ool20002
Ool2000MOol2000FOol005eoo`8000=oo`8000Moo`8001Qoo`8000=oo`8000Ioo`L001Eoo`8000=o
o`8000Ioo`8000=oo`8001Eoo`8000=oo`8000Moo`80009oo`8001eoo`8001Ioo`00GGoo0P000goo
0P0027oo0P005goo0P000goo0P001Woo0P000Woo0P005Woo0P000goo0P001Woo0P000goo0P005Goo
0P000goo0P001goo0P000Woo0P007Goo0P005Woo001MOol20003Ool20009Ool2000FOol20003Ool2
0007Ool200000goo0000000FOol20003Ool20006Ool30002Ool2000EOol20003Ool20008Ool4000N
Ool2000FOol005eoo`8000=oo`8000Yoo`8001Eoo`8000=oo`8000Qoo`@001Ioo`8000=oo`8000Io
o`H001Ioo`8000=oo`8000Qoo`@001ioo`8001Ioo`00GGoo0P000goo0P002Woo0P005Goo0P000goo
0P0027oo10005Woo0P000goo0P001goo0P006Goo0P000goo0P001goo0P000Woo0P007Goo0P005Woo
001MOol20003Ool2000:Ool2000EOol20003Ool20009Ool3000FOol20003Ool20007Ool2000IOol2
0003Ool20007Ool20002Ool2000MOol2000FOol005ioo`800003Ool0000000Moo`800004Ool00000
000FOol200000goo0000000:Ool3000GOol200000goo00000009Ool3000HOol200000goo00000008
Ool20002Ool2000LOol3000FOol005moo`<000Uoo`@001Qoo`<000aoo`8001Qoo`<000]oo`@001Mo
o`<000Yoo`@001ioo`8001Ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo000mOoo=000FOol003eoo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo01Aoo`00?Goo00<007ooOol0bGoo
00<007ooOol057oo000mOol00`00Oomoo`39Ool00`00Oomoo`0DOol003eoo`03001oogoo0<Uoo`03
001oogoo01Aoo`00?Goo00<007ooOol0bGoo00<007ooOol057oo000mOol00`00Oomoo`38Ool2000F
Ool003eoo`03001oogoo0<Uoo`03001oogoo01Aoo`00?Goo00<007ooOol0bGoo00<007ooOol057oo
000mOol00`00Oomoo`39Ool00`00Oomoo`0DOol003eoo`03001oogoo0<Uoo`03001oogoo01Aoo`00
?Goo00<007ooOol0bGoo00<007ooOol057oo000mOol00`00Oomoo`38Ool2000FOol003eoo`03001o
ogoo0<Uoo`03001oogoo01Aoo`00?Goo00<007ooOol0bGoo00<007ooOol057oo000mOol00`00Oomo
o`39Ool00`00Oomoo`0DOol003eoo`03001oogoo0<Uoo`03001oogoo01Aoo`00?Goo00<007ooOol0
bGoo00<007ooOol057oo000mOol00`00Oomoo`39Ool00`00Oomoo`0DOol003eoo`03001oogoo0<Qo
o`8001Ioo`00:Goo0`0017oo0P000Woo1P000goo00<007ooOol0bGoo00<007ooOol057oo000XOol2
00000goo00000008Ool20002Ool20002Ool00`00Oomoo`39Ool00`00Oomoo`0DOol002Moo`8000=o
o`8000Moo`8000Ioo`03001oogoo0<Uoo`03001oogoo01Aoo`009goo0P000goo0P0027oo0P001Goo
00<007ooOol0bGoo00<007ooOol057oo000WOol20003Ool20009Ool20004Ool00`00Oomoo`39Ool0
0`00Oomoo`0DOol002Moo`8000=oo`8000Yoo`8000=oo`800<Qoo`<001Ioo`009goo0P000goo0P00
2Woo0P000goo00<007ooOol0bGoo00<007ooOol057oo000WOol20003Ool2000:Ool20003Ool00`00
Oomoo`39Ool00`00Oomoo`0DOol002Qoo`800003Ool0000000Moo`800004Ool000000003Ool00`00
Oomoo`39Ool00`00Oomoo`0DOol002Uoo`<000Uoo`@000Aoo`03001oogoo0<Uoo`03001oogoo01Ao
o`00?Goo00<007ooOol0bGoo00<007ooOol057oo000mOol00`00Oomoo`38Ool2000FOol003eoo`03
001oogoo0<Uoo`03001oogoo01Aoo`00?Goo00<007ooOol0bGoo00<007ooOol057oo000mOol00`00
Oomoo`39Ool00`00Oomoo`0DOol003eoo`03001oogoo0<Uoo`03001oogoo01Aoo`00?Goo00<007oo
Ool0bGoo00<007ooOol057oo000mOol00`00Oomoo`39Ool00`00Oomoo`0DOol003eoo`03001oogoo
0<Qoo`8001Ioo`00?Goo00<007ooOol0bGoo00<007ooOol057oo000mOol00`00Oomoo`39Ool00`00
Oomoo`0DOol003eoo`03001oogoo0<Uoo`03001oogoo01Aoo`00?Goo00<007ooOol0bGoo00<007oo
Ool057oo000mOol00`00Oomoo`39Ool00`00Oomoo`0DOol003eoo`03001oogoo0<Qoo`8001Ioo`00
?Goo00<007ooOol0bGoo00<007ooOol057oo000YOol30004Ool20006Ool20003Ool00`00Oomoo`39
Ool00`00Oomoo`0DOol002Qoo`800003Ool0000000]oo`8000=oo`03001oogoo0<Uoo`03001oogoo
01Aoo`009goo0P000goo0P001Woo1`000Woo00<007ooOol0bGoo00<007ooOol057oo000WOol20003
Ool20006Ool20002Ool20003Ool00`00Oomoo`39Ool00`00Oomoo`0DOol002Moo`8000=oo`8000Mo
o`800003Ool0000000=oo`800<Qoo`<001Ioo`009goo0P000goo0P0027oo10000goo00<007ooOol0
bGoo00<007ooOol057oo000WOol20003Ool20008Ool40003Ool00`00Oomoo`39Ool00`00Oomoo`0D
Ool002Moo`8000=oo`8000Uoo`<000=oo`03001oogoo0<Uoo`03001oogoo01Aoo`00:7oo0P0000=o
o`0000002Woo0`000goo00<007ooOol0bGoo00<007ooOol057oo000NOol00`00Oomoo`08Ool3000<
Ool20003Ool00`00Oomoo`39Ool00`00Oomoo`0DOol001aoo`<001ioo`03001oogoo03moo`03001o
ogoo08Ioo`8001Ioo`006Goo0`000Woo00<007ooOol077oo00<007ooOol0?Woo0P00RGoo00<007oo
Ool057oo000GOol20002Ool00`00Oomoo`0OOol00`00Oomoo`0nOol00`00Oomoo`28Ool00`00Oomo
o`0DOol001Eoo`8000Aoo`03001oogoo01moo`03001oogoo03eoo`03001oogoo08Uoo`03001oogoo
01Aoo`005goo0P000Woo00<007ooOol07goo00<007ooOol0?7oo00<007ooOol0RWoo00<007ooOol0
57oo000IOol30002Ool00`00Oomoo`0LOol00`00Oomoo`0kOol00`00Oomoo`2;Ool00`00Oomoo`0D
Ool001aoo`<001ioo`03001oogoo03Uoo`8008ioo`03001oogoo01Aoo`007Woo00<007ooOol077oo
00<007ooOol0>7oo00<007ooOol0SGoo0P005Woo000mOol00`00Oomoo`0gOol00`00Oomoo`2?Ool0
0`00Oomoo`0DOol003eoo`03001oogoo03Eoo`80099oo`03001oogoo01Aoo`005Woo0P001Woo0P00
7Goo00<007ooOol0=7oo00<007ooOol0TWoo00<007ooOol057oo000EOol;000MOol00`00Oomoo`0c
Ool00`00Oomoo`2COol00`00Oomoo`0DOol001ioo`8001eoo`03001oogoo035oo`8009Ioo`03001o
ogoo01Aoo`00?Goo00<007ooOol0;goo0P00Ugoo0P005Woo000mOol00`00Oomoo`0]Ool2002JOol0
0`00Oomoo`0DOol002Uoo`<000Aoo`8000=oo`D000=oo`03001oogoo02]oo`8009aoo`03001oogoo
01Aoo`00:7oo0P0000=oo`0000001goo0P000goo0P000Woo00<007ooOol0:Goo0P00WWoo00<007oo
Ool057oo000WOol20003Ool20006Ool20003Ool20002Ool00`00Oomoo`0WOol2002POol00`00Oomo
o`0DOol002Moo`8000=oo`8000Ioo`8000=oo`80009oo`03001oogoo02Eoo`800:9oo`03001oogoo
01Aoo`009goo0P000goo0P001Woo0`000Woo0P000Woo0P008goo0`00XWoo0`005Woo000WOol20003
Ool20006Ool60003Ool00`00Oomoo`0OOol3002WOol00`00Oomoo`0DOol002Moo`8000=oo`8000Mo
o`8000Ioo`03001oogoo01aoo`<00:Yoo`03001oogoo01Aoo`009goo0P000goo0P001goo0P001Woo
00<007ooOol06Goo0`00[Goo00<007ooOol057oo000XOol200000goo00000009Ool30004Ool00`00
Oomoo`0FOol3002`Ool00`00Oomoo`0DOol002Uoo`<000]oo`@0009oo`03001oogoo01=oo`<00;=o
o`03001oogoo01Aoo`00?Goo00<007ooOol04Goo0P00]Woo00<007ooOol057oo000mOol00`00Oomo
o`0>Ool3002gOol2000FOol003eoo`03001oogoo00]oo`<00;]oo`03001oogoo01Aoo`00?Goo00<0
07ooOol027oo0`00_Woo00<007ooOol057oo000mOol00`00Oomoo`05Ool30031Ool00`00Oomoo`0D
Ool003eoo`03001oogoo009oo`<00<Aoo`03001oogoo01Aoo`00?Goo00<007oo00000P00agoo00<0
07ooOol057oo000mOol20039Ool2000FOol003eoo`03001oogoo0<Uoo`03001oogoo01Aoo`00?Goo
00<007ooOol0bGoo00<007ooOol057oo000mOol00`00Oomoo`39Ool00`00Oomoo`0DOol003eoo`03
001oogoo0<Uoo`03001oogoo01Aoo`00?Goo00<007ooOol0bGoo00<007ooOol057oo000mOol00`00
Oomoo`38Ool2000FOol003eoo`03001oogoo0<Uoo`03001oogoo01Aoo`00:Goo0`0017oo0P0017oo
10000goo00<007ooOol0bGoo00<007ooOol057oo000XOol200000goo00000008Ool20002Ool20002
Ool00`00Oomoo`39Ool00`00Oomoo`0DOol002Moo`8000=oo`8000Moo`80009oo`80009oo`03001o
ogoo0<Uoo`03001oogoo01Aoo`009goo0P000goo0P001goo0P000Woo0P000Woo00<007ooOol0bGoo
00<007ooOol057oo000WOol20003Ool20008Ool40003Ool00`00Oomoo`39Ool00`00Oomoo`0DOol0
02Moo`8000=oo`8000Qoo`@000=oo`800<Qoo`<001Ioo`009goo0P000goo0P001goo0P000Woo0P00
0Woo00<007ooOol0bGoo00<007ooOol057oo000WOol20003Ool20007Ool20002Ool20002Ool00`00
Oomoo`39Ool00`00Oomoo`0DOol002Qoo`800003Ool0000000Qoo`80009oo`80009oo`03001oogoo
0<Uoo`03001oogoo01Aoo`00:Goo0`002Woo10000goo00<007ooOol0bGoo00<007ooOol057oo000m
Ool00`00Oomoo`39Ool00`00Oomoo`0DOol003eoo`03001oogoo0<Qoo`8001Ioo`00?Goo00<007oo
Ool0bGoo00<007ooOol057oo000mOol00`00Oomoo`39Ool00`00Oomoo`0DOol003eoo`03001oogoo
0<Uoo`03001oogoo01Aoo`00?Goo00<007ooOol0bGoo00<007ooOol057oo000mOol00`00Oomoo`39
Ool00`00Oomoo`0DOol003eoo`03001oogoo0<Qoo`8001Ioo`00?Goo00<007ooOol0bGoo00<007oo
Ool057oo000mOol00`00Oomoo`39Ool00`00Oomoo`0DOol003eoo`03001oogoo0<Uoo`03001oogoo
01Aoo`00?Goo00<007ooOol0bGoo00<007ooOol057oo000mOol00`00Oomoo`39Ool00`00Oomoo`0D
Ool003eoo`03001oogoo0<Uoo`03001oogoo01Aoo`00?Goo00<007ooOol0b7oo0P005Woo000cOol4
0006Ool00`00Oomoo`39Ool00`00Oomoo`0DOol003Aoo`8000Moo`03001oogoo0<Uoo`03001oogoo
01Aoo`00=7oo0P001goo00<007ooOol0bGoo00<007ooOol057oo000dOol20007Ool00`00Oomoo`39
Ool00`00Oomoo`0DOol003Aoo`8000Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo01Aoo`00=7oo0P001gooc@005Woo000dOol2
003ZOol003Aoo`800>Yoo`00<goo0`00jWoo000dOol2003ZOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.299268, -0.326522, \
0.00490094, 0.00792988}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -10.7813 -19.3125 ]
[.2 -0.0125 10.7813 0 ]
[.4 -0.0125 -10.7813 -19.3125 ]
[.4 -0.0125 10.7813 0 ]
[.6 -0.0125 -10.7813 -19.3125 ]
[.6 -0.0125 10.7813 0 ]
[.8 -0.0125 -10.7813 -19.3125 ]
[.8 -0.0125 10.7813 0 ]
[1 -0.0125 -5.53125 -19.3125 ]
[1 -0.0125 5.53125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -10.5625 -38.625 ]
[.5 -0.0125 10.5625 -19.3125 ]
[-0.0125 .12361 -21.5625 -9.65625 ]
[-0.0125 .12361 0 9.65625 ]
[-0.0125 .24721 -21.5625 -9.65625 ]
[-0.0125 .24721 0 9.65625 ]
[-0.0125 .37082 -21.5625 -9.65625 ]
[-0.0125 .37082 0 9.65625 ]
[-0.0125 .49443 -21.5625 -9.65625 ]
[-0.0125 .49443 0 9.65625 ]
[-0.0125 .61803 -11.0625 -9.65625 ]
[-0.0125 .61803 0 9.65625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -40.875 -10.5625 ]
[-0.01875 .30902 -21.5625 10.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
gsave
.2 -0.0125 -71.7813 -23.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.4 0 m
.4 .00625 L
s
gsave
.4 -0.0125 -71.7813 -23.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.6 0 m
.6 .00625 L
s
gsave
.6 -0.0125 -71.7813 -23.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.8 0 m
.8 .00625 L
s
gsave
.8 -0.0125 -71.7813 -23.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -66.5313 -23.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -71.5625 -42.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
80.125 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
gsave
-0.0125 .12361 -82.5625 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .24721 m
.00625 .24721 L
s
gsave
-0.0125 .24721 -82.5625 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .37082 m
.00625 .37082 L
s
gsave
-0.0125 .37082 -82.5625 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .49443 m
.00625 .49443 L
s
gsave
-0.0125 .49443 -82.5625 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -72.0625 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -102.781 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
71.5625 13.6563 translate
90 rotate
-71.5625 -13.6563 translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.125 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.3 .43262 m
.24512 .39557 L
.22842 .38099 L
.21618 .36782 L
.20809 .35651 L
.20342 .34751 L
.20158 .34263 L
.2009 .34038 L
.20039 .33839 L
.20003 .33668 L
.19971 .33486 L
.19947 .3331 L
.19938 .33216 L
.19931 .3313 L
.19926 .33053 L
.19924 .33011 L
.19922 .32972 L
.1992 .32897 L
.19919 .3283 L
.19919 .32792 L
.1992 .32751 L
.19921 .3268 L
.19923 .32641 L
.19924 .32605 L
.19929 .32524 L
.19935 .32455 L
.1994 .32391 L
.19954 .32274 L
.19993 .32022 L
.20039 .31808 L
.20087 .31622 L
.20214 .31235 L
.20496 .30606 L
.20814 .30057 L
.21358 .29297 L
.21748 .28826 L
.22034 .28501 L
.22219 .28298 L
.22339 .2817 L
.22423 .28079 L
.22476 .28022 L
.22513 .27983 L
.22537 .27958 L
.22551 .27942 L
.22562 .27931 L
.22568 .27925 L
.22572 .2792 L
.22575 .27917 L
.22577 .27915 L
.22578 .27914 L
Mistroke
.22579 .27913 L
.2258 .27912 L
.2258 .27912 L
.2258 .27912 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol009Yoo`<000=oo`<00003Ool00000008007Qoo`00Vgoo
00<007ooOol00goo00<007ooOol00goo0P00Mgoo002KOol00`00Oomoo`03Ool00`00Oomoo`04Ool2
001fOol009aoo`D000Moo`8007Ioo`00W7oo00D007ooOomoo`0000Ioo`<007Ioo`00W7oo00D007oo
Oomoo`0000Eoo`<007Moo`00WGoo00<007oo00001Woo0P00N7oo002MOol00`00Ool00007Ool2001g
Ool009ioo`03001oogoo00=oo`800003Ool0000007Moo`00WWoo00<007ooOol017oo0`00N7oo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo001OOol30004Ool20002Ool6000GOol30004Ool20006Ool2000HOol30004Ool20003
Ool5000HOol30004Ool20004Ool4000MOol4000EOol005ioo`800003Ool0000000Qoo`80009oo`80
01Eoo`800003Ool0000000]oo`8001Moo`800003Ool0000000Moo`8000=oo`8001Ioo`800003Ool0
000000Qoo`80009oo`8001eoo`8001Ioo`00GGoo0P000goo0P001goo0P0067oo0P000goo0P001Woo
1`005Goo0P000goo0P001Woo0P000goo0P005Goo0P000goo0P001goo0P000Woo0P007Goo0P005Woo
001MOol20003Ool20008Ool2000GOol20003Ool20006Ool20002Ool2000FOol20003Ool20006Ool2
0003Ool2000EOol20003Ool20007Ool20002Ool2000MOol2000FOol005eoo`8000=oo`8000Uoo`80
01Ioo`8000=oo`8000Moo`800003Ool0000001Ioo`8000=oo`8000Ioo`<0009oo`8001Eoo`8000=o
o`8000Qoo`@001ioo`8001Ioo`00GGoo0P000goo0P002Woo0P005Goo0P000goo0P0027oo10005Woo
0P000goo0P001Woo1P005Woo0P000goo0P0027oo10007Woo0P005Woo001MOol20003Ool2000:Ool2
000EOol20003Ool20008Ool4000FOol20003Ool20007Ool2000IOol20003Ool20007Ool20002Ool2
000MOol2000FOol005eoo`8000=oo`8000Yoo`8001Eoo`8000=oo`8000Uoo`<001Ioo`8000=oo`80
00Moo`8001Uoo`8000=oo`8000Moo`80009oo`8001eoo`8001Ioo`00GWoo0P0000=oo`0000001goo
0P0000Aoo`00000001Ioo`800003Ool0000000Yoo`<001Moo`800003Ool0000000Uoo`<001Qoo`80
0003Ool0000000Qoo`80009oo`8001aoo`<001Ioo`00Ggoo0`002Goo100067oo0`0037oo0P0067oo
0`002goo10005goo0`002Woo10007Woo0P005Woo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol003eoold001Ioo`00?Goo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol057oo000mOol0
0`00Oomoo`39Ool00`00Oomoo`0DOol003eoo`03001oogoo0<Uoo`03001oogoo01Aoo`00?Goo00<0
07ooOol0bGoo00<007ooOol057oo000mOol00`00Oomoo`39Ool00`00Oomoo`0DOol003eoo`03001o
ogoo0<Qoo`8001Ioo`00?Goo00<007ooOol0bGoo00<007ooOol057oo000mOol00`00Oomoo`39Ool0
0`00Oomoo`0DOol003eoo`03001oogoo0<Uoo`03001oogoo01Aoo`00?Goo00<007ooOol0bGoo00<0
07ooOol057oo000mOol00`00Oomoo`39Ool00`00Oomoo`0DOol003eoo`03001oogoo0<Qoo`8001Io
o`00?Goo00<007ooOol0bGoo00<007ooOol057oo000mOol00`00Oomoo`39Ool00`00Oomoo`0DOol0
03eoo`03001oogoo0<Uoo`03001oogoo01Aoo`00?Goo00<007ooOol0bGoo00<007ooOol057oo000m
Ool00`00Oomoo`39Ool00`00Oomoo`0DOol003eoo`03001oogoo0<Uoo`03001oogoo01Aoo`00?Goo
00<007ooOol0b7oo0P005Woo000YOol30004Ool20002Ool60003Ool00`00Oomoo`39Ool00`00Oomo
o`0DOol002Qoo`800003Ool0000000Qoo`80009oo`80009oo`03001oogoo0<Uoo`03001oogoo01Ao
o`009goo0P000goo0P001goo0P001Woo00<007ooOol0bGoo00<007ooOol057oo000WOol20003Ool2
0008Ool20005Ool00`00Oomoo`39Ool00`00Oomoo`0DOol002Moo`8000=oo`8000Uoo`8000Aoo`03
001oogoo0<Uoo`03001oogoo01Aoo`009goo0P000goo0P002Woo0P000goo0P00b7oo0`005Woo000W
Ool20003Ool2000:Ool20003Ool00`00Oomoo`39Ool00`00Oomoo`0DOol002Moo`8000=oo`8000Yo
o`8000=oo`03001oogoo0<Uoo`03001oogoo01Aoo`00:7oo0P0000=oo`0000001goo0P0000Aoo`00
000000=oo`03001oogoo0<Uoo`03001oogoo01Aoo`00:Goo0`002Goo100017oo00<007ooOol0bGoo
00<007ooOol057oo000mOol00`00Oomoo`39Ool00`00Oomoo`0DOol003eoo`03001oogoo0<Qoo`80
01Ioo`00?Goo00<007ooOol0bGoo00<007ooOol057oo000mOol00`00Oomoo`39Ool00`00Oomoo`0D
Ool003eoo`03001oogoo0<Uoo`03001oogoo01Aoo`00?Goo00<007ooOol0bGoo00<007ooOol057oo
000mOol00`00Oomoo`39Ool00`00Oomoo`0DOol003eoo`03001oogoo0<Uoo`03001oogoo01Aoo`00
?Goo00<007ooOol0b7oo0P005Woo000mOol00`00Oomoo`39Ool00`00Oomoo`0DOol003eoo`03001o
ogoo0<Uoo`03001oogoo01Aoo`00?Goo00<007ooOol0bGoo00<007ooOol057oo000mOol00`00Oomo
o`39Ool00`00Oomoo`0DOol003eoo`03001oogoo0<Uoo`03001oogoo01Aoo`00?Goo00<007ooOol0
b7oo0P005Woo000mOol00`00Oomoo`39Ool00`00Oomoo`0DOol002Uoo`<000Aoo`8000Ioo`8000=o
o`03001oogoo0<Uoo`03001oogoo01Aoo`00:7oo0P0000=oo`0000002goo0P000goo00<007ooOol0
bGoo00<007ooOol057oo000WOol20003Ool20006Ool70002Ool00`00Oomoo`39Ool00`00Oomoo`0D
Ool002Moo`8000=oo`8000Ioo`80009oo`8000=oo`03001oogoo0<Uoo`03001oogoo01Aoo`009goo
0P000goo0P001goo0P0000=oo`0000000goo0P00b7oo0`005Woo000WOol20003Ool20008Ool40003
Ool00`00Oomoo`39Ool00`00Oomoo`0DOol002Moo`8000=oo`8000Qoo`@000=oo`03001oogoo0<Uo
o`03001oogoo01Aoo`009goo0P000goo0P002Goo0`000goo00<007ooOol0bGoo00<007ooOol057oo
000XOol200000goo0000000:Ool30003Ool00`00Oomoo`39Ool00`00Oomoo`0DOol001ioo`03001o
ogoo00Qoo`<000aoo`8000=oo`03001oogoo0<Uoo`03001oogoo01Aoo`0077oo0`007Woo00<007oo
Ool0:goo00<007ooOol0VWoo0P005Woo000IOol30002Ool00`00Oomoo`0LOol00`00Oomoo`0ZOol2
002MOol00`00Oomoo`0DOol001Moo`80009oo`03001oogoo01moo`03001oogoo02Yoo`03001oogoo
09aoo`03001oogoo01Aoo`005Goo0P0017oo00<007ooOol07goo00<007ooOol0:Goo00<007ooOol0
WGoo00<007ooOol057oo000GOol20002Ool00`00Oomoo`0OOol00`00Oomoo`0XOol00`00Oomoo`2N
Ool00`00Oomoo`0DOol001Uoo`<0009oo`03001oogoo01aoo`03001oogoo02Moo`03001oogoo09mo
o`03001oogoo01Aoo`0077oo0`007Woo00<007ooOol09Woo00<007ooOol0X7oo00<007ooOol057oo
000NOol00`00Oomoo`0LOol00`00Oomoo`0VOol00`00Oomoo`2OOol2000FOol003eoo`03001oogoo
02Ioo`03001oogoo0:1oo`03001oogoo01Aoo`00?Goo00<007ooOol09Goo00<007ooOol0XGoo00<0
07ooOol057oo000FOol20006Ool2000MOol00`00Oomoo`0UOol00`00Oomoo`2QOol00`00Oomoo`0D
Ool001Eoo`/001eoo`03001oogoo02Eoo`03001oogoo0:5oo`03001oogoo01Aoo`007Woo0P007Goo
00<007ooOol09Goo00<007ooOol0XGoo00<007ooOol057oo000mOol00`00Oomoo`0UOol2002QOol2
000FOol003eoo`03001oogoo02Ioo`03001oogoo0:1oo`03001oogoo01Aoo`00:Goo0`0017oo0P00
0goo1@000goo00<007ooOol09Woo00<007ooOol0X7oo00<007ooOol057oo000XOol200000goo0000
0007Ool20003Ool20002Ool00`00Oomoo`0WOol00`00Oomoo`2OOol00`00Oomoo`0DOol002Moo`80
00=oo`8000Ioo`8000=oo`80009oo`03001oogoo02Qoo`03001oogoo09ioo`03001oogoo01Aoo`00
9goo0P000goo0P001Woo0P000goo0P000Woo00<007ooOol0:7oo00<007ooOol0WWoo00<007ooOol0
57oo000WOol20003Ool20006Ool30002Ool20002Ool2000ZOol00`00Oomoo`2KOol3000FOol002Mo
o`8000=oo`8000Ioo`H000=oo`03001oogoo02Yoo`03001oogoo09aoo`03001oogoo01Aoo`009goo
0P000goo0P001goo0P001Woo00<007ooOol0:goo00<007ooOol0Vgoo00<007ooOol057oo000WOol2
0003Ool20007Ool20006Ool00`00Oomoo`0/Ool00`00Oomoo`2JOol00`00Oomoo`0DOol002Qoo`80
0003Ool0000000Uoo`<000Aoo`03001oogoo02eoo`8009Yoo`03001oogoo01Aoo`00:Goo0`002goo
10000Woo00<007ooOol0;goo00<007ooOol0Ugoo00<007ooOol057oo000mOol00`00Oomoo`0`Ool2
002GOol00`00Oomoo`0DOol003eoo`03001oogoo039oo`03001oogoo09=oo`8001Ioo`00?Goo00<0
07ooOol0<goo00<007ooOol0Tgoo00<007ooOol057oo000mOol00`00Oomoo`0dOol2002COol00`00
Oomoo`0DOol003eoo`03001oogoo03Ioo`03001oogoo091oo`03001oogoo01Aoo`00?Goo00<007oo
Ool0=goo00<007ooOol0Sgoo00<007ooOol057oo000mOol00`00Oomoo`0hOol2002?Ool00`00Oomo
o`0DOol003eoo`03001oogoo03Yoo`03001oogoo08]oo`8001Ioo`00?Goo00<007ooOol0bGoo00<0
07ooOol057oo000mOol00`00Oomoo`39Ool00`00Oomoo`0DOol003eoo`03001oogoo0<Uoo`03001o
ogoo01Aoo`00?Goo00<007ooOol0bGoo00<007ooOol057oo000mOol00`00Oomoo`39Ool00`00Oomo
o`0DOol003eoo`03001oogoo0<Qoo`8001Ioo`00?Goo00<007ooOol0bGoo00<007ooOol057oo000Y
Ool30004Ool20004Ool40003Ool00`00Oomoo`39Ool00`00Oomoo`0DOol002Qoo`800003Ool00000
00Qoo`80009oo`80009oo`03001oogoo0<Uoo`03001oogoo01Aoo`009goo0P000goo0P001goo0P00
0Woo0P000Woo00<007ooOol0bGoo00<007ooOol057oo000WOol20003Ool20007Ool20002Ool20002
Ool00`00Oomoo`39Ool00`00Oomoo`0DOol002Moo`8000=oo`8000Qoo`@000=oo`03001oogoo0<Uo
o`03001oogoo01Aoo`009goo0P000goo0P0027oo10000goo0P00b7oo0`005Woo000WOol20003Ool2
0007Ool20002Ool20002Ool00`00Oomoo`39Ool00`00Oomoo`0DOol002Moo`8000=oo`8000Moo`80
009oo`80009oo`03001oogoo0<Uoo`03001oogoo01Aoo`00:7oo0P0000=oo`00000027oo0P000Woo
0P000Woo00<007ooOol0bGoo00<007ooOol057oo000YOol3000:Ool40003Ool00`00Oomoo`39Ool0
0`00Oomoo`0DOol003eoo`03001oogoo0<Uoo`03001oogoo01Aoo`00?Goo00<007ooOol0b7oo0P00
5Woo000mOol00`00Oomoo`39Ool00`00Oomoo`0DOol003eoo`03001oogoo0<Uoo`03001oogoo01Ao
o`00?Goo00<007ooOol0bGoo00<007ooOol057oo000mOol00`00Oomoo`39Ool00`00Oomoo`0DOol0
03eoo`03001oogoo0<Uoo`03001oogoo01Aoo`00?Goo00<007ooOol0b7oo0P005Woo000mOol00`00
Oomoo`39Ool00`00Oomoo`0DOol003eoo`03001oogoo0<Uoo`03001oogoo01Aoo`00?Goo00<007oo
Ool0bGoo00<007ooOol057oo000mOol00`00Oomoo`39Ool00`00Oomoo`0DOol003eoo`03001oogoo
0<Uoo`03001oogoo01Aoo`00?Goo00<007ooOol0bGoo00<007ooOol057oo000mOol00`00Oomoo`38
Ool2000FOol003=oo`@000Ioo`03001oogoo0<Uoo`03001oogoo01Aoo`00=7oo0P001goo00<007oo
Ool0bGoo00<007ooOol057oo000dOol20007Ool00`00Oomoo`39Ool00`00Oomoo`0DOol003Aoo`80
00Moo`03001oogoo0<Uoo`03001oogoo01Aoo`00=7oo0P001goo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol057oo000dOol20007
Ooo=000FOol003Aoo`800>Yoo`00=7oo0P00jWoo000cOol3003ZOol003Aoo`800>Yoo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.299268, -0.326522, \
0.00490094, 0.00792988}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowSize->{721, 582},
WindowMargins->{{73, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 404, 11, 200, "Title"],

Cell[CellGroupData[{
Cell[2205, 68, 2461, 44, 510, "Input"],
Cell[4669, 114, 53, 1, 29, "Output"],
Cell[4725, 117, 142, 2, 29, "Output"],
Cell[4870, 121, 146, 2, 29, "Output"],
Cell[5019, 125, 110, 2, 29, "Output"],

Cell[CellGroupData[{
Cell[5154, 131, 29077, 1097, 186, 19575, 975, "GraphicsData", "PostScript", \
"Graphics"],
Cell[34234, 1230, 25805, 924, 186, 16540, 805, "GraphicsData", "PostScript", \
"Graphics"],
Cell[60042, 2156, 26458, 956, 186, 17011, 835, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

