(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     50385,       1719]*)
(*NotebookOutlinePosition[     51091,       1743]*)
(*  CellTagsIndexPosition[     51047,       1739]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Consecutive reactions:\nA1=A2=A3=A4=A5 with rate \
constants k12, k21, k23, k32, k31, k13... \nNote: the rate equations are not \
independent, so a mass balance provides  \nA5=A1o-(A1+A2+A3+A4). ",
  FontFamily->"Arial",
  FontSize->16,
  FontWeight->"Bold"]], "Title",
  TextAlignment->Center,
  Background->RGBColor[0.776471, 1, 0.776471]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Clear[A1, A2, A3, A4, A5, sol5]; k12 = \(k23 = \(k34 = \(k45 = 1\)\)\); 
    k21 = \(k32 = \(k43 = \(k54 =  .1\)\)\); A1o = 1; 
    tf = 10;\), "\[IndentingNewLine]", 
    \(\(sol5 = 
        NDSolve[{\[IndentingNewLine]\(A1'\)[t] \[Equal] \(-k12\)\ \ A1[t] + 
                k21\ \ A2[t], \[IndentingNewLine]\(A2'\)[t] \[Equal] 
              k12\ \ A1[t]\  - \((k21\  + k23)\) A2[t] + 
                k32\ \ A3[t], \[IndentingNewLine]\(A3'\)[t] \[Equal] 
              k23\ \ A2[t]\  - \((k32\  + k34)\) A3[t] + 
                k43\ \ A4[t], \[IndentingNewLine]\(A4'\)[t] \[Equal] 
              k34\ \ A3[t]\  - \((k43\  + k45)\) A4[t] + 
                k54\ \ \((A1o - A1[t] - A2[t] - A3[t] - 
                      A4[t])\), \[IndentingNewLine]A1[0] \[Equal] A1o, 
            A2[0] \[Equal] 0, A3[0] \[Equal] 0, 
            A4[0] \[Equal] 0}, \[IndentingNewLine]{A1[t], A2[t], A3[t], 
            A4[t]}, {t, 0, tf}];\)\), "\[IndentingNewLine]", 
    \(\(Plot[
        Evaluate[
          Table[{A1[t], A2[t], A3[t], A4[t], 
                A1o - A1[t] - A2[t] - A3[t] - A4[t]} /. sol5]], {t, 0, tf}, 
        Frame \[Rule] True, DefaultFont \[Rule] {"\<Symbol-Bold\>", 14}, 
        FrameLabel \[Rule] {"\<t\>", "\<A1, A2, A3, A4, A5\>"}, 
        PlotRange \[Rule] {{0, tf}, {0, 1}}, 
        PlotStyle \[Rule] {RGBColor[1, 0, 0], RGBColor[0, 1, 0], 
            RGBColor[0, 0, 1], RGBColor[1, 1, 0], 
            RGBColor[0, 1, 1]}];\)\), "\[IndentingNewLine]", 
    \(\(Clear[A1, A2, A3, A4, A5, soleq];\)\), "\[IndentingNewLine]", 
    \(soleq = 
      Solve[{0 \[Equal] \(-k12\)\ \ A1 + 
              k21\ \ A2, \[IndentingNewLine]0 \[Equal] 
            k12\ \ A1 - \((k21\  + k23)\) A2 + 
              k32\ \ A3, \[IndentingNewLine]0 \[Equal] 
            k23\ \ A2\  - \((k32\  + k34)\) A3 + 
              k43\ \ A4, \[IndentingNewLine]0 \[Equal] 
            k34\ \ A3\  - \((k43\  + k45)\) A4 + 
              k54\ \ \((A1o - A1 - A2 - A3 - A4)\)}, {A1, A2, A3, 
          A4}]\), "\[IndentingNewLine]", 
    \(A5 = \((A1o - A1 - A2 - A3 - A4)\) /. soleq\), "\[IndentingNewLine]", 
    \(ListPlot[
      Flatten[{A1, A2, A3, A4, \((A1o - A1 - A2 - A3 - A4)\)} /. soleq], 
      PlotStyle \[Rule] {PointSize[0.015], RGBColor[1, 0, 0]}]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14  scalefont  setfont
% Scaling calculations
-2.77556e-017 0.1 0 0.618034 [
[.2 -0.0125 -5.53125 -19.3125 ]
[.2 -0.0125 5.53125 0 ]
[.4 -0.0125 -5.53125 -19.3125 ]
[.4 -0.0125 5.53125 0 ]
[.6 -0.0125 -5.53125 -19.3125 ]
[.6 -0.0125 5.53125 0 ]
[.8 -0.0125 -5.53125 -19.3125 ]
[.8 -0.0125 5.53125 0 ]
[1 -0.0125 -9.0625 -19.3125 ]
[1 -0.0125 9.0625 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -3.96875 -38.625 ]
[.5 -0.0125 3.96875 -19.3125 ]
[-0.0125 .12361 -21.5625 -9.65625 ]
[-0.0125 .12361 0 9.65625 ]
[-0.0125 .24721 -21.5625 -9.65625 ]
[-0.0125 .24721 0 9.65625 ]
[-0.0125 .37082 -21.5625 -9.65625 ]
[-0.0125 .37082 0 9.65625 ]
[-0.0125 .49443 -21.5625 -9.65625 ]
[-0.0125 .49443 0 9.65625 ]
[-0.0125 .61803 -11.0625 -9.65625 ]
[-0.0125 .61803 0 9.65625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -40.875 -59.0625 ]
[-0.01875 .30902 -21.5625 59.0625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
gsave
.2 -0.0125 -66.5313 -23.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.4 0 m
.4 .00625 L
s
gsave
.4 -0.0125 -66.5313 -23.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.6 0 m
.6 .00625 L
s
gsave
.6 -0.0125 -66.5313 -23.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.8 0 m
.8 .00625 L
s
gsave
.8 -0.0125 -66.5313 -23.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -70.0625 -23.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -64.9688 -42.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
66.938 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
gsave
-0.0125 .12361 -82.5625 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .24721 m
.00625 .24721 L
s
gsave
-0.0125 .24721 -82.5625 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .37082 m
.00625 .37082 L
s
gsave
-0.0125 .37082 -82.5625 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .49443 m
.00625 .49443 L
s
gsave
-0.0125 .49443 -82.5625 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -72.0625 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -151.281 -13.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
120.063 13.6563 translate
90 rotate
-120.063 -13.6563 translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.125 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.250 19.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
104.375 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.500 19.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
128.625 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
135.750 19.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
152.875 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
160.000 19.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
177.125 19.188 moveto
%%IncludeResource: font Symbol-Bold
%%IncludeFont: Symbol-Bold
/Symbol-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
0 .61803 m
.01975 .50826 L
.04057 .41529 L
.06347 .33412 L
.08481 .27403 L
.12477 .19108 L
.14621 .15834 L
.16571 .13387 L
.18751 .11135 L
.20764 .09422 L
.24797 .06797 L
.26763 .05818 L
.28929 .04915 L
.33159 .03561 L
.3723 .02634 L
.41559 .01926 L
.45728 .01435 L
.49738 .01088 L
.54006 .00814 L
.58115 .00619 L
.62481 .00466 L
.66688 .00355 L
.70736 .00275 L
.75041 .0021 L
.79187 .00163 L
.83174 .00128 L
.87419 .001 L
.91504 .00079 L
.95847 .00062 L
1 .00049 L
s
0 1 0 r
0 0 m
.00942 .05278 L
.01975 .09932 L
.03053 .13735 L
.04057 .16466 L
.05176 .18744 L
.06194 .20235 L
.06758 .20859 L
.0737 .21393 L
.07947 .21776 L
.08226 .21922 L
.08481 .22035 L
.0897 .22202 L
.0924 .22267 L
.09364 .22291 L
.09496 .22312 L
.0962 .22329 L
.09732 .2234 L
.09845 .22349 L
.09951 .22355 L
.10075 .22359 L
.10189 .2236 L
.10315 .22358 L
.10447 .22353 L
.10582 .22344 L
.10705 .22333 L
.10981 .22298 L
.11237 .22254 L
.11479 .22202 L
.12022 .22056 L
.12613 .21851 L
.14689 .20843 L
.16895 .19447 L
.20859 .16605 L
.2508 .13613 L
.29142 .11041 L
.33462 .08729 L
.37622 .06909 L
.41624 .05493 L
.45883 .04292 L
.49982 .03381 L
.5434 .02622 L
.58538 .02054 L
.62577 .01626 L
.66873 .01271 L
.71011 .01005 L
.74989 .00804 L
.79224 .00637 L
.83301 .00512 L
.87635 .00408 L
Mistroke
.9181 .00331 L
.95826 .00272 L
1 .00225 L
Mfstroke
0 0 1 r
0 0 m
.00123 5e-005 L
.00236 .00017 L
.00365 .0004 L
.00488 .0007 L
.00706 .00143 L
.00942 .00248 L
.01479 .00578 L
.01975 .00977 L
.04057 .03313 L
.08481 .09159 L
.10614 .11543 L
.12613 .13322 L
.14527 .14595 L
.15602 .15132 L
.16585 .15517 L
.17086 .15677 L
.17619 .1582 L
.1808 .15924 L
.18579 .16015 L
.18885 .1606 L
.19166 .16096 L
.1943 .16123 L
.1972 .16147 L
.19846 .16155 L
.1998 .16162 L
.20097 .16168 L
.20223 .16173 L
.20297 .16175 L
.20366 .16177 L
.20501 .16179 L
.20624 .16181 L
.20755 .16181 L
.20874 .1618 L
.21005 .16178 L
.21141 .16175 L
.21268 .16171 L
.21496 .16161 L
.21739 .16146 L
.22294 .161 L
.22799 .16044 L
.23787 .15894 L
.24719 .1571 L
.2682 .15172 L
.28758 .14558 L
.32895 .1302 L
.36873 .11429 L
.41109 .09773 L
.45185 .08302 L
.49519 .06915 L
Mistroke
.53694 .05764 L
.5771 .04824 L
.61983 .03988 L
.66097 .03324 L
.70469 .02749 L
.74681 .02302 L
.78735 .01955 L
.83045 .01658 L
.87197 .0143 L
.9119 .01254 L
.9544 .01105 L
.99531 .00991 L
1 .0098 L
Mfstroke
1 1 0 r
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 1e-005 L
.00601 2e-005 L
.00706 3e-005 L
.00821 5e-005 L
.00942 8e-005 L
.01065 .00011 L
.01196 .00016 L
.01434 .00026 L
.01716 .00043 L
.01975 .00064 L
.02485 .00121 L
.03042 .0021 L
.03568 .0032 L
.04057 .00446 L
.0518 .00825 L
.06198 .0127 L
.08481 .02563 L
.12688 .05566 L
.16736 .08488 L
.18788 .09792 L
.21041 .11022 L
.2321 .11984 L
.25187 .12669 L
.27236 .13192 L
.28363 .13404 L
.29432 .13558 L
.30445 .13666 L
.30957 .13706 L
.31522 .1374 L
.32002 .13761 L
.32272 .1377 L
.3252 .13776 L
.32738 .1378 L
.32861 .13781 L
.32976 .13782 L
.33098 .13783 L
.33208 .13783 L
.33336 .13783 L
.33456 .13783 L
.33577 .13782 L
.33707 .1378 L
.3383 .13778 L
.33942 .13776 L
.34217 .1377 L
.34477 .13762 L
.34994 .13742 L
Mistroke
.35558 .13713 L
.36563 .13642 L
.37495 .13559 L
.39654 .13308 L
.41609 .13024 L
.45822 .12293 L
.49875 .11513 L
.54186 .10678 L
.58338 .09914 L
.6233 .09244 L
.6658 .08611 L
.70671 .08082 L
.75019 .07605 L
.79209 .0722 L
.83239 .06912 L
.87526 .06642 L
.91655 .06429 L
.95624 .06263 L
.99851 .06119 L
1 .06114 L
Mfstroke
0 1 1 r
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 1e-005 L
.01434 1e-005 L
.01566 1e-005 L
.01711 2e-005 L
.01975 3e-005 L
.02116 4e-005 L
.02249 5e-005 L
.02497 8e-005 L
.02765 .00012 L
.03054 .00017 L
.03308 .00023 L
.03576 .00031 L
.04057 .00049 L
.04583 .00076 L
.05147 .00116 L
.0568 .00164 L
.06166 .00219 L
.07355 .004 L
.08481 .00644 L
.09495 .00929 L
.10571 .01307 L
.12505 .02184 L
.1455 .03394 L
.16469 .04781 L
.20531 .08412 L
.24851 .13022 L
.29012 .17829 L
.33013 .22499 L
.37272 .2728 L
.41372 .31542 L
.45729 .3561 L
.49927 .39041 L
.53966 .41892 L
.58263 .44469 L
.624 .46546 L
.66378 .48212 L
.70614 .49678 L
.7469 .50831 L
.79024 .51826 L
Mistroke
.83199 .52598 L
.87215 .53197 L
.91488 .53709 L
.95602 .54102 L
.99974 .54434 L
1 .54436 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00:1oo`8007ioo`00X7oo00<007oo0000OGoo002POol0
0`00Oomoo`1mOol00:1oo`03001oogoo07eoo`00X7oo00<007ooOol0OGoo002POol00`00Oomoo`1m
Ool009moo`<007ioo`00X7oo00<007ooOol0OGoo002POol00`00Oomoo`1mOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00H7oo1P009goo0P0097oo1@009Goo10008Goo100017oo0`004goo001QOol20002Ool2
000VOol2000SOol20003Ool2000SOol20002Ool2000QOol20004Ool200000goo0000000BOol0065o
o`8002Ioo`L0029oo`8000=oo`8002=oo`80009oo`80025oo`8000=oo`8000=oo`80015oo`00HWoo
0P009Goo0P000Woo0P008goo0P000goo0P008goo0P000Woo0P008Goo0P000goo0P000goo0P004Goo
001SOol2000UOol200000goo0000000SOol30002Ool2000TOol4000ROol20003Ool20003Ool2000A
Ool006Aoo`8002Eoo`@002=oo`H002Eoo`@0029oo`8000=oo`8000=oo`80015oo`00I7oo0P009Goo
100097oo0P009goo0P000Woo0P008Goo0P000goo0P000goo0P004Goo001TOol2000VOol3000TOol2
000WOol20002Ool2000QOol20003Ool20003Ool2000AOol0061oo`800004Ool00000000VOol3000U
Ool3000UOol20002Ool2000POol30004Ool200000goo0000000BOol0065oo`@002Qoo`8002Ioo`@0
02Aoo`@0029oo`8000Eoo`<001=oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo000kOoo=000HOol003]oo`040n1oogoo01l4Ool3On03Ool40ol2Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool01000Oomoogoo6W`000<007ooOol027oo
00<007ooOol017oo8P?P2Woo00<007ooOol01goo00<007ooOol05Woo000kOol01@?POomoogoo01l0
1Woo0WoP1Goo10?oC7oo27`06Woo4P?P8Goo5@0O00<007ooOol05Woo000kOol00`000n1oo`02Ool0
0`0OOomoo`05Ool2On07Ool20om2Ool8O00JOol80n0QOolB01lEOol00`00Oomoo`0FOol003]oo`03
0003h7oo00=oo`0301moogoo00Ioo`9oh0Moo`83ocMoo`Ul01Yoo`P3h1Uooa007bMoo`03001oogoo
01Ioo`00>goo00<000?POol017oo00<07gooOol01goo00=oh7ooOol01Woo00<3ogooOol0;Goo1g`0
77oo1`?P6Woo1`0O=goo00<007ooOol05Woo000kOol00`000n1oo`05Ool00`0OOomoo`07Ool2On07
Ool20olYOol4O00OOol40n0MOol401lmOol2000HOol001aoo`03001oogoo01aoo`030003h7oo00Io
o`0301moogoo00Qoo`03On1oogoo00Ioo`030omoogoo029oo`Al01aoo`L3h1Yoo`L07d9oo`03001o
ogoo01Ioo`006Woo0`007Woo00<000?POol01goo00<07gooOol027oo0WoP1goo0P?o87oo0W`06Woo
1P?P6goo1P0OBGoo00<007ooOol05Woo000GOol30002Ool00`00Oomoo`0LOol00`00Ool3h007Ool0
0`0OOomoo`0:Ool00goPOomoo`06Ool20olKOol3O00JOol20n0MOol401m?Ool00`00Oomoo`0FOol0
01Eoo`80009oo`03001oogoo01moo`03001oo`?P00Qoo`0301moogoo00Yoo`9oh0Qoo`030omoogoo
01Eoo`=l01Yoo`<3h1Qoo`L07e=oo`03001oogoo01Ioo`004goo0P0017oo00<007ooOol07goo00<0
07oo0n002Goo00<07gooOol02goo00=oh7ooOol01Woo00<3ogooOol04Woo0W`06Woo0`?P5Goo1P0O
FWoo00<007ooOol05Woo000EOol20002Ool00`00Oomoo`0OOol200000`?POomoo`08Ool00`0OOomo
o`0;Ool00goPOomoo`06Ool00`?oOomoo`0?Ool2O00JOol20n0FOol201mLOol4On000`00Oomoo`0F
Ool001Moo`<0009oo`03001oogoo01aoo`03001oo`?P00Yoo`0301moogoo00aoo`9oh0Moo`83o`eo
o`9l01Uoo`<3h1Eoo`<07dEooaUoh0Aoo`03001oogoo01Ioo`006Woo0`007Woo00@007ooOol3h0Yo
o`0301moogoo00eoo`03On1oogoo00Ioo`030omoogoo00Qoo`9l01Qoo`<3h1Eoo`<07cMooa5oh1eo
o`03001oogoo01Ioo`0077oo00<007ooOol077oo00@007ooOol3h0]oo`0301moogoo00eoo`03On1o
ogoo00Ioo`030omoogoo00Eoo`9l01Qoo`83h1Eoo`<07c5oo`Uoh2ioo`03001oogoo01Ioo`00>goo
00@007ooOol3h0aoo`0301moogoo00eoo`9oh0Moo`030omoogoo00=oo`03O01oogoo01Ioo`83h1Ao
o`<07baoo`Qoh3Moo`03001oogoo01Ioo`00>goo00@007ooOol3h0aoo`0301moogoo00moo`03On1o
ogoo00Eoo`030omoogoo009l01Moo`83h1=oo`<07bQoo`Moh3moo`03001oogoo01Ioo`0057oo0P00
1Woo0P007Goo00D007ooOomoo`?P00aoo`0301moogoo00moo`03On1oogoo00Eoo`030oml07oo01Eo
o`<3h1=oo`807bMoo`Aoh4Ioo`03001oogoo01Ioo`004goo2`007Goo0P000Woo00<3h7ooOol02goo
00<07gooOol03goo0WoP17oo00=l07oo0ol057oo0P?P4goo0`0O8goo1WoPBGoo0P0067oo000LOol2
0009Ool30004Ool20002Ool60003Ool01@00Oomoogoo0n003Woo00<07gooOol047oo0WoP00=oog`0
Ool00Woo00<3ogooOol03goo0P?P4Woo0`0O7goo1goPD7oo00<007ooOol05Woo000VOol200000goo
00000008Ool20002Ool20002Ool01@00Oomoogoo0n003Woo00<07gooOol04Goo00=l07oPOn0017oo
00<3ogooOol037oo0P?P4Goo0`0O7Woo17oPEgoo00<007ooOol05Woo000UOol20003Ool20007Ool2
0006Ool00`00Oomoo`02Ool00`?POomoo`0<Ool00`0OOomoo`0?Ool017`0Oomoogoo0WoP0goo00<3
ogooOol02Goo0P?P47oo0`0O6goo1WoPFgoo00<007ooOol05Woo000UOol20003Ool20008Ool20005
Ool00`00Oomoo`02Ool00`?POomoo`0=Ool00`0OOomoo`0=Ool00g`0Oomoo`04Ool2On02Ool00`?o
Oomoo`07Ool00`?POomoo`0=Ool301lGOol7On1QOol00`00Oomoo`0FOol002Eoo`8000=oo`8000Uo
o`8000Aoo`03001oogoo009oo`030n1oogoo00ioo`0301moogoo00]oo`03O01oogoo00Moo`9oh003
Ool3ogoo00Eoo`83h0ioo`807aIoo`Aoh6Qoo`03001oogoo01Ioo`0077oo10001Goo0P000goo0P00
2Woo0P000goo0P000goo00<3h7ooOol03goo0P0O2goo00=l07ooOol02Goo0WoP00<3ogooOol00Woo
00<3h7ooOol02goo0`0O4Woo1WoPJgoo0P0067oo000LOol30006Ool20003Ool2000:Ool20003Ool0
0`00Oomoo`03Ool00`?POomoo`0@Ool00`0OOomoo`07Ool00g`0Oomoo`0<Ool01GoP0omoh7oo0n00
2goo0`0O3goo1WoPLWoo00<007ooOol05Woo000UOol20003Ool2000:Ool20003Ool00`00Oomoo`03
Ool00`?POomoo`0AOol00`0OOomoo`05Ool00g`0Oomoo`0?Ool00`?oOn1oh006On02Ool301l:Ool8
On1hOol00`00Oomoo`0FOol002Ioo`800003Ool0000000Moo`800004Ool000000003Ool00`00Oomo
o`03Ool00`?POomoo`0BOol00`0OOomoo`03Ool00g`0Oomoo`0?Ool00`?POol3o`06Ool00`0OOn1o
h00=On20Ool00`00Oomoo`0FOol002Moo`<000Uoo`@000Aoo`03001oogoo00=oo`030n1oogoo01=o
o`0501moogooOoml000@Ool20n02Ool00`?oOomoo`02Ool201n@Ool00`00Oomoo`0FOol003]oo`03
001oogoo00Aoo`030n1oogoo01=oo`807`03Ooml07oo00ioo`030n1oogoo00=oo`040omoo`0O01nB
Ool00`00Oomoo`0FOol001aoo`03001oogoo01aoo`8000Eoo`030n1oogoo01Eoo`@07`]oo`83h0Eo
o`807`030omoogoo095oo`8001Qoo`006Woo0`007Woo00<007ooOol01Goo00<3h7ooOol04goo00=l
07ooOol00Woo100O1Woo00<3h00O01l01@0O0goo00<3ogooOol0TGoo00<007ooOol05Woo000GOol3
0002Ool00`00Oomoo`0LOol00`00Oomoo`05Ool00`?POomoo`0BOol00g`0Oomoo`06Ool801l;Ool0
0`?oOomoo`2@Ool00`00Oomoo`0FOol001Eoo`80009oo`03001oogoo01moo`03001oogoo00Eoo`03
0n1oogoo019oo`03O01oogoo00Yoo`030n1oogoo00aoo`030omoogoo091oo`03001oogoo01Ioo`00
4goo0P0017oo00<007ooOol07goo00<007ooOol01Woo00<3h7ooOol047oo00=l07ooOol02Goo0P?P
47oo00<3ogooOol0Sgoo00<007ooOol05Woo000EOol20002Ool00`00Oomoo`0OOol00`00Oomoo`06
Ool00`?POomoo`0?Ool00g`0Oomoo`09Ool00`?POomoo`0AOol00`?oOomoo`2>Ool00`00Oomoo`0F
Ool001Moo`<0009oo`03001oogoo01aoo`03001oogoo00Moo`030n1oogoo00eoo`03O01oogoo00Qo
o`83h1Eoo`030omoogoo08eoo`03001oogoo01Ioo`006Woo0`007Woo0P0027oo00<3h7ooOol03Goo
00=l07ooOol01Woo0P?P67oo00<3ogooOol0Rgoo0P0067oo000LOol00`00Oomoo`0LOol00`00Oomo
o`08Ool00`?POomoo`0;Ool00g`0Oomoo`06Ool00`?POomoo`0HOol00`?oOomoo`2<Ool00`00Oomo
o`0FOol001Aoo`8000Ioo`8001eoo`03001oogoo00Qoo`030n1oogoo00]oo`03O01oogoo00Eoo`03
0n1oogoo01Yoo`030omoogoo08]oo`03001oogoo01Ioo`004goo0P001Goo10007Goo00<007ooOol0
2Goo00<3h7ooOol02Goo00=l07ooOol017oo0P?P7Woo00<3ogooOol0RWoo00<007ooOol05Woo000C
Ool20004Ool200000goo0000000MOol00`00Oomoo`0:Ool20n09Ool00g`0Oomoo`03Ool00`?POomo
o`0OOol00`?oOomoo`29Ool00`00Oomoo`0FOol001=oo`<0009oo`80009oo`8001eoo`03001oogoo
00aoo`030n1oogoo00Eoo`03O01oogoo009oo`83h2=oo`030omoogoo08Qoo`03001oogoo01Ioo`00
57oo1@000goo0P007Goo0P003Woo0P?P1Goo00=l07ooOol00P?P9Goo00<3ogooOol0Qgoo0P0067oo
000KOol2000NOol00`00Oomoo`0>Ool90n0XOol00`?oOomoo`27Ool00`00Oomoo`0FOol002Moo`<0
00Aoo`8000Ioo`8000=oo`03001oogoo01=oo`03O01oogoo02Yoo`030omoogoo08Ioo`03001oogoo
01Ioo`009Woo0P0000=oo`0000002goo0P000goo00<007ooOol04Woo00=l07ooOol0;7oo00<3ogoo
Ool0QGoo00<007ooOol05Woo000UOol20003Ool20006Ool70002Ool00`00Oomoo`0BOol00g`0Oomo
o`0]Ool00`?oOomoo`24Ool00`00Oomoo`0FOol001aoo`@000Eoo`8000=oo`8000Ioo`80009oo`80
00=oo`03001oogoo015oo`03O01oogoo02moo`030omoogoo08=oo`03001oogoo01Ioo`0077oo0`00
1Woo0P000goo0P001goo0P0000=oo`0000000goo0P004Woo00=l07ooOol0<7oo00<3ogooOol0PGoo
0P0067oo000UOol20003Ool20008Ool40003Ool00`00Oomoo`0@Ool00g`0Oomoo`0bOol00`?oOomo
o`21Ool00`00Oomoo`0FOol002Eoo`8000=oo`8000Qoo`@000=oo`03001oogoo011oo`03O01oogoo
03=oo`030omoogoo081oo`03001oogoo01Ioo`009Goo0P000goo0P002Goo0`000goo00<007ooOol0
3goo00=l07ooOol0=Goo00<3ogooOol0Ogoo00<007ooOol05Woo000VOol200000goo0000000:Ool3
0003Ool00`00Oomoo`0?Ool00g`0Oomoo`0fOol00`?oOomoo`1nOol00`00Oomoo`0FOol001aoo`03
001oogoo00Qoo`<000aoo`8000=oo`03001oogoo00ioo`03O01oogoo03Qoo`030omoogoo07eoo`03
001oogoo01Ioo`006Woo0`007Woo0P003goo00=l07ooOol0>Goo00<3ogooOol0Ngoo0P0067oo000G
Ool30002Ool00`00Oomoo`0LOol00`00Oomoo`0>Ool00g`0Oomoo`0jOol00`?oOomoo`1kOol00`00
Oomoo`0FOol001Eoo`80009oo`03001oogoo01moo`03001oogoo00eoo`03O01oogoo03aoo`030omo
ogoo07Yoo`03001oogoo01Ioo`004goo0P0017oo00<007ooOol07goo00<007ooOol03Goo00=l07oo
Ool0?Goo00<3ogooOol0NGoo00<007ooOol05Woo000EOol20002Ool00`00Oomoo`0OOol00`00Oomo
o`0=Ool00g`0Oomoo`0mOol00`?oOomoo`1iOol00`00Oomoo`0FOol001Moo`<0009oo`03001oogoo
01aoo`03001oogoo00aoo`03O01oogoo03moo`030omoogoo07Qoo`03001oogoo01Ioo`006Woo0`00
7Woo00<007ooOol037oo00=l07ooOol0@7oo00<3ogooOol0Mgoo00<007ooOol05Woo000LOol00`00
Oomoo`0LOol2000=Ool00g`0Oomoo`11Ool00`?oOomoo`1eOol2000HOol003]oo`03001oogoo00]o
o`03O01oogoo04=oo`030omoogoo07Eoo`03001oogoo01Ioo`0057oo0P001Woo0P007Goo00<007oo
Ool02goo00=l07ooOol0A7oo00<3ogooOol0M7oo00<007ooOol05Woo000COol20007Ool2000MOol0
0`00Oomoo`0;Ool00g`0Oomoo`15Ool00`?oOomoo`1cOol00`00Oomoo`0FOol001=oo`800004Ool0
00000003Ool2000MOol00`00Oomoo`0:Ool00g`0Oomoo`17Ool00`?oOomoo`1bOol00`00Oomoo`0F
Ool001Aoo`H00003Ool0000001ioo`03001oogoo00Yoo`03O01oogoo04Qoo`83og9oo`03001oogoo
01Ioo`0067oo10007goo0P002goo00=l07ooOol0BWoo00<3ogooOol0KWoo0P0067oo000kOol00`00
Oomoo`09Ool00g`0Oomoo`1<Ool00`?oOomoo`1^Ool00`00Oomoo`0FOol002Moo`<000Aoo`8000=o
o`D000=oo`03001oogoo00Uoo`03O01oogoo04eoo`030omoogoo06eoo`03001oogoo01Ioo`009Woo
0P0000=oo`0000001goo0P000goo0P000Woo00<007ooOol02Goo00=l07ooOol0CWoo00<3ogooOol0
K7oo00<007ooOol05Woo000LOol40005Ool20003Ool20006Ool20003Ool20002Ool00`00Oomoo`08
Ool00g`0Oomoo`1@Ool00`?oOomoo`1[Ool00`00Oomoo`0FOol001aoo`<000Ioo`8000=oo`8000Io
o`8000=oo`80009oo`03001oogoo00Qoo`03O01oogoo055oo`83of]oo`03001oogoo01Ioo`009Goo
0P000goo0P001Woo0`000Woo0P000Woo0P002Goo00=l07ooOol0Dgoo00<3ogooOol0Igoo0P0067oo
000UOol20003Ool20006Ool60003Ool00`00Oomoo`07Ool00g`0Oomoo`1EOol00`?oOomoo`1WOol0
0`00Oomoo`0FOol002Eoo`8000=oo`8000Moo`8000Ioo`03001oogoo00Moo`03O01oogoo05Ioo`83
ofMoo`03001oogoo01Ioo`009Goo0P000goo0P001goo0P001Woo00<007ooOol01goo00=l07ooOol0
F7oo00<3ogooOol0I7oo00<007ooOol05Woo000VOol200000goo00000009Ool30004Ool00`00Oomo
o`07Ool00g`0Oomoo`1IOol00`?oOomoo`1SOol00`00Oomoo`0FOol001aoo`03001oogoo00Qoo`<0
00]oo`@0009oo`03001oogoo00Ioo`03O01oogoo05]oo`030omoogoo069oo`03001oogoo01Ioo`00
6Woo0`007Woo00<007ooOol01Woo00=l07ooOol0G7oo0P?oHWoo00<007ooOol05Woo000GOol30002
Ool00`00Oomoo`0LOol20007Ool00g`0Oomoo`1NOol00`?oOomoo`1NOol2000HOol001Eoo`80009o
o`03001oogoo01moo`03001oogoo00Eoo`03O01oogoo061oo`030omoogoo05ioo`03001oogoo01Io
o`004goo0P0017oo00<007ooOol07goo00<007ooOol01Goo00=l07ooOol0HGoo0P?oGWoo00<007oo
Ool05Woo000EOol20002Ool00`00Oomoo`0OOol00`00Oomoo`05Ool00g`0Oomoo`1SOol00`?oOomo
o`1KOol00`00Oomoo`0FOol001Moo`<0009oo`03001oogoo01aoo`03001oogoo00Eoo`03O01oogoo
06Aoo`83oe]oo`03001oogoo01Ioo`006Woo0`007Woo00<007ooOol017oo00=l07ooOol0Igoo0P?o
FGoo00<007ooOol05Woo000LOol00`00Oomoo`0LOol20005Ool00g`0Oomoo`1YOol20omFOol2000H
Ool001Uoo`<001moo`03001oogoo00Aoo`03O01oogoo06]oo`83oeEoo`03001oogoo01Ioo`0067oo
10007goo00<007ooOol017oo00=l07ooOol0KGoo00<3ogooOol0DWoo00<007ooOol05Woo000FOol3
00000goo0000000OOol00`00Oomoo`04Ool00g`0Oomoo`1^Ool20omBOol00`00Oomoo`0FOol001Ao
o`<000=oo`8001moo`03001oogoo00=oo`03O01oogoo075oo`030omoogoo04moo`03001oogoo01Io
o`004goo2`007Goo00<007ooOol00goo00=l07ooOol0LWoo0P?oCgoo00<007ooOol05Woo000JOol2
000OOol20004Ool00g`0Oomoo`1dOol20om<Ool2000HOol003]oo`03001oogoo00=oo`03O01oogoo
07Ioo`83od]oo`03001oogoo01Ioo`009goo0`0017oo0P0017oo10000goo00<007ooOol00Woo00=l
07ooOol0NGoo0P?oBGoo00<007ooOol05Woo000VOol200000goo00000008Ool20002Ool20002Ool0
0`00Oomoo`02Ool00g`0Oomoo`1kOol30om6Ool00`00Oomoo`0FOol001aoo`@000Eoo`8000=oo`80
00Moo`80009oo`80009oo`03001oogoo009oo`03O01oogoo07ioo`<3od=oo`03001oogoo01Ioo`00
77oo0`001Woo0P000goo0P001goo0P000Woo0P000Woo00<007ooOol00Woo00=l07ooOol0PGoo0`?o
@7oo00<007ooOol05Woo000UOol20003Ool20008Ool40003Ool00`00Oomoo`02Ool00g`0Oomoo`24
Ool30olmOol00`00Oomoo`0FOol002Eoo`8000=oo`8000Qoo`@000=oo`80009oo`03O01oogoo08Qo
o`<3ocUoo`8001Qoo`009Goo0P000goo0P001goo0P000Woo0P000Woo00D007ooOomoog`008eoo`@3
ocIoo`03001oogoo01Ioo`009Goo0P000goo0P001goo0P000Woo0P000Woo00D007ooOomoog`0095o
o`D3oc5oo`03001oogoo01Ioo`0077oo00<007ooOol01goo0P0000=oo`00000027oo0P000Woo0P00
0Woo00D007ooOomoog`009Ioo`@3obeoo`03001oogoo01Ioo`006Woo0`002Woo0`002Woo10000goo
00D007ooOomoog`009Yoo`D3obQoo`03001oogoo01Ioo`005goo0`000Woo00<007ooOol077oo00@0
07ooOoml0:1oo`@3obAoo`03001oogoo01Ioo`005Goo0P000Woo00<007ooOol07goo0P0000=oog`0
Ool0Xgoo1P?o7Goo0P0067oo000COol20004Ool00`00Oomoo`0OOol01000Oomoog`0ZWoo20?o5Woo
00<007ooOol05Woo000EOol20002Ool00`00Oomoo`0OOol01000Oomoog`0/Woo2@?o3Goo00<007oo
Ool05Woo000GOol30002Ool00`00Oomoo`0LOol01000Oomoog`0^goo2@?o17oo00<007ooOol05Woo
000JOol3000NOol01000Oomoog`0a7oo10?o00<007ooOol05Woo000LOol00`00Oomoo`0LOol00`00
Ooml0039Ool00`00Oomoo`0FOol001aoo`8001eoo`800003O01oogoo0<Ioo`8001Qoo`005Goo0`00
17oo0P007Goo00<007ooO000bGoo00<007ooOol05Woo000COol50004Ool2000MOol00`00Ooml0039
Ool00`00Oomoo`0FOol001=oo`800004Ool000000003Ool2000MOol00`00Ooml0039Ool00`00Oomo
o`0FOol001=oo`80009oo`<00003Ool0000001ioo`03001oog`00<Uoo`03001oogoo01Ioo`004goo
0P000goo10007goo00<007`0Ool0bGoo00<007ooOol05Woo000kOol00`00O01oo`39Ool00`00Oomo
o`0FOol003]oo`03001l07oo0<Qoo`8001Qoo`00<Goo10001Woo00<007`0Ool0bGoo00<007ooOol0
5Woo000bOol20007Ool00`00O01oo`39Ool00`00Oomoo`0FOol0039oo`8000Moo`03001l07oo0<Uo
o`03001oogoo01Ioo`00<Woo0P001goo00=l07ooOol0bGoo00<007ooOol05Woo000bOol20007Ool0
0g`0Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`0FOol0039oo`8000Moo`03O00000000<X001Qoo`00<Woo0P00k7oo000bOol2003/Ool0
035oo`<00>aoo`00<Woo0P00k7oo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.90615, -0.326522, \
0.0490094, 0.00792988}}],

Cell[BoxData[
    \({{A1 \[Rule] 0.0000900009000090001`, A2 \[Rule] 0.000900009000090001`, 
        A3 \[Rule] 0.009000090000900008`, 
        A4 \[Rule] 0.09000090000900007`}}\)], "Output"],

Cell[BoxData[
    \({0.900009000090001`}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 0.0146562 0.654063 [
[.2619 .00216 -3 -9 ]
[.2619 .00216 3 0 ]
[.5 .00216 -3 -9 ]
[.5 .00216 3 0 ]
[.7381 .00216 -3 -9 ]
[.7381 .00216 3 0 ]
[.97619 .00216 -3 -9 ]
[.97619 .00216 3 0 ]
[.01131 .14547 -18 -4.5 ]
[.01131 .14547 0 4.5 ]
[.01131 .27628 -18 -4.5 ]
[.01131 .27628 0 4.5 ]
[.01131 .40709 -18 -4.5 ]
[.01131 .40709 0 4.5 ]
[.01131 .53791 -18 -4.5 ]
[.01131 .53791 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01466 m
.2619 .02091 L
s
[(2)] .2619 .00216 0 1 Mshowa
.5 .01466 m
.5 .02091 L
s
[(3)] .5 .00216 0 1 Mshowa
.7381 .01466 m
.7381 .02091 L
s
[(4)] .7381 .00216 0 1 Mshowa
.97619 .01466 m
.97619 .02091 L
s
[(5)] .97619 .00216 0 1 Mshowa
.125 Mabswid
.07143 .01466 m
.07143 .01841 L
s
.11905 .01466 m
.11905 .01841 L
s
.16667 .01466 m
.16667 .01841 L
s
.21429 .01466 m
.21429 .01841 L
s
.30952 .01466 m
.30952 .01841 L
s
.35714 .01466 m
.35714 .01841 L
s
.40476 .01466 m
.40476 .01841 L
s
.45238 .01466 m
.45238 .01841 L
s
.54762 .01466 m
.54762 .01841 L
s
.59524 .01466 m
.59524 .01841 L
s
.64286 .01466 m
.64286 .01841 L
s
.69048 .01466 m
.69048 .01841 L
s
.78571 .01466 m
.78571 .01841 L
s
.83333 .01466 m
.83333 .01841 L
s
.88095 .01466 m
.88095 .01841 L
s
.92857 .01466 m
.92857 .01841 L
s
.25 Mabswid
0 .01466 m
1 .01466 L
s
.02381 .14547 m
.03006 .14547 L
s
[(0.2)] .01131 .14547 1 0 Mshowa
.02381 .27628 m
.03006 .27628 L
s
[(0.4)] .01131 .27628 1 0 Mshowa
.02381 .40709 m
.03006 .40709 L
s
[(0.6)] .01131 .40709 1 0 Mshowa
.02381 .53791 m
.03006 .53791 L
s
[(0.8)] .01131 .53791 1 0 Mshowa
.125 Mabswid
.02381 .04736 m
.02756 .04736 L
s
.02381 .08006 m
.02756 .08006 L
s
.02381 .11277 m
.02756 .11277 L
s
.02381 .17817 m
.02756 .17817 L
s
.02381 .21088 m
.02756 .21088 L
s
.02381 .24358 m
.02756 .24358 L
s
.02381 .30898 m
.02756 .30898 L
s
.02381 .34169 m
.02756 .34169 L
s
.02381 .37439 m
.02756 .37439 L
s
.02381 .4398 m
.02756 .4398 L
s
.02381 .4725 m
.02756 .4725 L
s
.02381 .5052 m
.02756 .5052 L
s
.02381 .57061 m
.02756 .57061 L
s
.02381 .60331 m
.02756 .60331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.015 w
.02381 .01472 Mdot
.2619 .01524 Mdot
.5 .02054 Mdot
.7381 .07352 Mdot
.97619 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo001DOol4
000mOol20010Ool3000mOol20007Ool005Aoo`03001oogoo03eoo`04001oogoo0010Ool00`00Oomo
o`0kOol01000Oomoo`001Woo001EOol00`00Oomoo`0nOol00`00Oomoo`0lOol5000oOol00`00Oomo
o`04Ool005Ioo`03001oogoo03ioo`03001oogoo03]oo`04001oogoo000nOol20007Ool005Aoo`04
001oogoo000lOol01000Oomoo`00?Woo00<007oo0000?Woo00<007ooOol01Woo001EOol2000nOol2
0010Ool2000nOol30006Ool00?moob5oo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3o
Ool9Ool001Eoo`03001oogoo0?moo`Uoo`0057oo0W`0?goo0W`0bGoo000>Ool50004O00m0004O00n
0002O028000001=oo`Al00]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Qoo`Al00]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Qo
o`Al00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Eoo`0057oo0W`0?goo0W`0?Woo17`0?Woo00<007ooOol0?Woo00<007ooOol01Goo000EOol0
0`00Oomoo`1nOol2O028Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000E
Ool00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000E
Ool2003oOol:Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00
Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00
Oomoo`2oOol2O017Ool001Eoo`03001oogoo0;ioo`Al04Ioo`005Goo00<007ooOol0_Woo17`0AWoo
000EOol20030Ool2O017Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000E
Ool00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000E
Ool00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000E
Ool2003oOol:Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00
Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00
Oomoo`3oOol9Ool0009oo`8000Aoo`8000=oo`@000Aoo`03001oogoo0?moo`Uoo`0000Eoo`00Oomo
o`0000Qoo`03001oogoo00Eoo`03001oogoo0?moo`Uoo`0000Eoo`00Oomoo`0000Uoo`03001oogoo
00Aoo`<00?moo`Uoo`0000Eoo`00Oomoo`0000Yoo`03001oogoo00=oo`03001oogoo0?moo`Uoo`00
00Eoo`00Oomoo`0000Qoo`04001oogoo0004Ool00`00Oomoo`3oOol9Ool0009oo`8000Yoo`8000Eo
o`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eo
o`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eo
o`800?moo`Yoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001o
ogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001o
ogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`800?mo
o`Yoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?mo
o`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?mo
o`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol2003oOol:Ool001Eoo`03001oogoo0?moo`Uoo`00
5Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`00
5Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool0009oo`8000Aoo`8000Eoo`<000=o
o`03001oogoo0?moo`Uoo`0000Eoo`00Oomoo`0000]oo`03001oogoo009oo`03001oogoo0?moo`Uo
o`0000Eoo`00Oomoo`0000Qoo`D000=oo`<00?moo`Uoo`0000Eoo`00Oomoo`0000Qoo`04001oogoo
0004Ool00`00Oomoo`3oOol9Ool00005Ool007ooOol00009Ool00`00Ool00004Ool00`00Oomoo`3o
Ool9Ool0009oo`8000]oo`8000Aoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000E
Ool00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000E
Ool00`00Oomoo`3oOol9Ool001Eoo`800?moo`Yoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00
Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00
Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00
Oomoo`3oOol9Ool001Eoo`800?moo`Yoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3o
Ool9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3o
Ool9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3o
Ool9Ool001Eoo`800?moo`Yoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool0
01Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool0
01Eoo`03001oogoo0?moo`Uoo`000Woo0P0017oo0P000goo0`001Goo00<007ooOol0ogoo2Goo0000
1Goo001oogoo000027oo00@007ooOol000Aoo`03001oogoo0?moo`Uoo`0000Eoo`00Oomoo`0000Qo
o`04001oogoo0004Ool3003oOol9Ool00005Ool007ooOol00008Ool30005Ool00`00Oomoo`3oOol9
Ool00005Ool007ooOol00009Ool00`00Oomoo`04Ool00`00Oomoo`3oOol9Ool0009oo`8000Yoo`<0
00Aoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool0
01Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool0
01Eoo`800?moo`Yoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03
001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03
001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`80
0?moo`Yoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo
0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo
0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`800?moo`Yo
o`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uo
o`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uo
o`000Woo0P0017oo0P0017oo0P001Goo00<007ooOol0ogoo2Goo00001Goo001oogoo000027oo00@0
07ooOol000Aoo`03001oogoo0?moo`Uoo`0000Eoo`00Oomoo`0000Qoo`04001oogoo0004Ool3003o
Ool9Ool00005Ool007ooOol00009Ool20005Ool00`00Oomoo`3oOol9Ool00005Ool007ooOol00008
Ool01000Oomoo`0017oo00<007ooOol0ogoo2Goo0002Ool2000:Ool20005Ool00`00Oomoo`3oOol9
Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9
Ool001Eoo`03001oogoo0?moo`Uoo`005Goo0P00ogoo2Woo000EOol00`00Oomoo`3oOol9Ool001Eo
o`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eo
o`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eo
o`03001oogoo0?moo`5oo`9l00Ioo`005Goo0P00ogoo0Goo17`01Goo000EOol00`00Oomoo`3oOol4
O005Ool001Eoo`03001oogoo0?moo`5oo`9l00Ioo`005Goo00<007ooOol0ogoo2Goo000EOol00`00
Oomoo`3oOol9Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.669618, -0.070734, \
0.015437, 0.00561943}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowSize->{785, 538},
WindowMargins->{{73, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 365, 7, 180, "Title"],

Cell[CellGroupData[{
Cell[2166, 64, 2294, 41, 450, "Input"],
Cell[4463, 107, 36613, 1318, 186, 22514, 1139, "GraphicsData", "PostScript", \
"Graphics"],
Cell[41079, 1427, 190, 3, 29, "Output"],
Cell[41272, 1432, 54, 1, 29, "Output"],
Cell[41329, 1435, 8895, 275, 186, 2719, 194, "GraphicsData", "PostScript", \
"Graphics"],
Cell[50227, 1712, 130, 3, 29, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

