(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    118343,       3513]*)
(*NotebookOutlinePosition[    119028,       3537]*)
(*  CellTagsIndexPosition[    118984,       3533]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Isotherm VLE Calculations \nCase of Ethanol-Ethyl \
acetate System",
  FontSize->20]], "Title",
  TextAlignment->Center,
  Background->RGBColor[0.623529, 1, 0.811765]],

Cell[CellGroupData[{

Cell["Vapor pressure using Antoine's equation", "Subsubtitle",
  Background->RGBColor[0.929702, 0.996109, 0.566415]],

Cell[BoxData[{
    \(A1 = 7.10179; B1 = 1244.951; C1 = 217.881;\), "\[IndentingNewLine]", 
    \(A2 = 8.11220; B2 = 1592.864; C2 = 226.184;\)}], "Input"],

Cell[BoxData[{
    \(\(PS1 = 10^\((A1 - B1/\((C1 + T)\))\);\)\), "\[IndentingNewLine]", 
    \(\(PS2 = 10^\((A2 - B2/\((C2 + T)\))\);\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Boiling temperatures at 1 atm ", "Subsubtitle",
  Background->RGBColor[0.929702, 0.996109, 0.566415]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindRoot[PS1 \[Equal] \ 760, \ {T, 40}]\)], "Input"],

Cell[BoxData[
    \({T \[Rule] 77.06284231176154`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindRoot[PS2 \[Equal] \ 760, \ {T, 50}]\)], "Input"],

Cell[BoxData[
    \({T \[Rule] 78.29819188122649`}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Temperature is 70\[Degree]C", "Subsubtitle",
  Background->RGBColor[0.929702, 0.996109, 0.566415]],

Cell[BoxData[
    \(\(T = 70;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Partial pressures using Raoult's law ", "Subsubtitle",
  Background->RGBColor[0.929702, 0.996109, 0.566415]],

Cell[BoxData[
    \(P1[x_] := PS1\ x; P2[x_] := PS2\ \((1 - x)\);\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(plt3 = 
      Plot[{P1[x], P2[x]}, {x, 0, 1}, 
        PlotStyle \[Rule] {RGBColor[1, 0, 1], RGBColor[0, 1, 0]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.000983029 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .11302 -18 -4.5 ]
[.01131 .11302 0 4.5 ]
[.01131 .21132 -18 -4.5 ]
[.01131 .21132 0 4.5 ]
[.01131 .30962 -18 -4.5 ]
[.01131 .30962 0 4.5 ]
[.01131 .40793 -18 -4.5 ]
[.01131 .40793 0 4.5 ]
[.01131 .50623 -18 -4.5 ]
[.01131 .50623 0 4.5 ]
[.01131 .60453 -18 -4.5 ]
[.01131 .60453 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11302 m
.03006 .11302 L
s
[(100)] .01131 .11302 1 0 Mshowa
.02381 .21132 m
.03006 .21132 L
s
[(200)] .01131 .21132 1 0 Mshowa
.02381 .30962 m
.03006 .30962 L
s
[(300)] .01131 .30962 1 0 Mshowa
.02381 .40793 m
.03006 .40793 L
s
[(400)] .01131 .40793 1 0 Mshowa
.02381 .50623 m
.03006 .50623 L
s
[(500)] .01131 .50623 1 0 Mshowa
.02381 .60453 m
.03006 .60453 L
s
[(600)] .01131 .60453 1 0 Mshowa
.125 Mabswid
.02381 .03438 m
.02756 .03438 L
s
.02381 .05404 m
.02756 .05404 L
s
.02381 .0737 m
.02756 .0737 L
s
.02381 .09336 m
.02756 .09336 L
s
.02381 .13268 m
.02756 .13268 L
s
.02381 .15234 m
.02756 .15234 L
s
.02381 .172 m
.02756 .172 L
s
.02381 .19166 m
.02756 .19166 L
s
.02381 .23098 m
.02756 .23098 L
s
.02381 .25064 m
.02756 .25064 L
s
.02381 .2703 m
.02756 .2703 L
s
.02381 .28996 m
.02756 .28996 L
s
.02381 .32928 m
.02756 .32928 L
s
.02381 .34895 m
.02756 .34895 L
s
.02381 .36861 m
.02756 .36861 L
s
.02381 .38827 m
.02756 .38827 L
s
.02381 .42759 m
.02756 .42759 L
s
.02381 .44725 m
.02756 .44725 L
s
.02381 .46691 m
.02756 .46691 L
s
.02381 .48657 m
.02756 .48657 L
s
.02381 .52589 m
.02756 .52589 L
s
.02381 .54555 m
.02756 .54555 L
s
.02381 .56521 m
.02756 .56521 L
s
.02381 .58487 m
.02756 .58487 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
.02381 .01472 m
.06244 .03859 L
.10458 .06463 L
.14415 .08909 L
.18221 .11261 L
.22272 .13765 L
.26171 .16175 L
.30316 .18736 L
.34309 .21204 L
.3815 .23578 L
.42237 .26104 L
.46172 .28536 L
.49955 .30874 L
.53984 .33364 L
.57861 .3576 L
.61984 .38308 L
.65954 .40762 L
.69774 .43123 L
.73838 .45635 L
.77751 .48053 L
.81909 .50623 L
.85916 .53099 L
.89771 .55482 L
.93871 .58016 L
.97619 .60332 L
s
0 1 0 r
.02381 .54782 m
.06244 .52619 L
.10458 .50261 L
.14415 .48046 L
.18221 .45915 L
.22272 .43648 L
.26171 .41465 L
.30316 .39145 L
.34309 .3691 L
.3815 .3476 L
.42237 .32472 L
.46172 .3027 L
.49955 .28152 L
.53984 .25897 L
.57861 .23726 L
.61984 .21419 L
.65954 .19196 L
.69774 .17058 L
.73838 .14783 L
.77751 .12593 L
.81909 .10265 L
.85916 .08022 L
.89771 .05864 L
.93871 .03569 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0012Ool2
0004Ool20003Ool4000UOol20004Ool20005Ool3000SOol20004Ool20003Ool3000VOol20004Ool2
0004Ool2000[Ool50005Ool0045oo`04001oogoo0008Ool00`00Oomoo`0UOol01000Oomoo`002goo
00<007ooOol08Goo00@007ooOol000Qoo`04001oogoo000TOol01000Oomoo`0027oo00@007ooOol0
02aoo`03001oogoo00Eoo`00@Goo00@007ooOol000Uoo`03001oogoo02Aoo`04001oogoo0008Ool5
000ROol01000Oomoo`0027oo00@007ooOol002Aoo`04001oogoo0008Ool01000Oomoo`00;7oo00<0
07ooOol01Goo0011Ool01000Oomoo`002Woo00<007ooOol08goo00@007ooOol000Qoo`04001oogoo
000SOol01000Oomoo`0027oo0`009Goo00@007ooOol000Uoo`8002eoo`03001oogoo00Eoo`00@Goo
00@007ooOol000Qoo`04001oogoo000TOol01000Oomoo`002Goo00<007oo00008goo00@007ooOol0
00Uoo`03001oogoo02Aoo`04001oogoo0008Ool01000Oomoo`00;7oo00<007ooOol01Goo0012Ool2
000:Ool2000VOol2000;Ool2000TOol2000:Ool3000UOol2000:Ool2000/Ool20007Ool00?moob5o
o`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uo
o`005Goo00<007ooOol0ogoo2Goo000?Ool600000g`O0000003o000100000`?P000000040001Ool0
01Eoo`03001l7g`O00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Qoo`83h003001oogoo00Eoo`005Goo00<007ooOol00W`O;goo00<007ooOol0<Goo00<007ooOol0
<7oo00<007ooOol0<Goo00<007ooOol0;Goo0P?P0Woo00<007ooOol01Goo000EOol00`00Oomoo`02
Ool2O1ogOol00`?POomoo`0:Ool001Eoo`03001oogoo00Aoo`9l7o=oo`83h0eoo`005Goo0P001goo
0W`Okgoo0P?P3goo000EOol00`00Oomoo`08Ool00g`OOomoo`3[Ool00`?POomoo`0?Ool001Eoo`03
001oogoo00Uoo`9l7nUoo`83h19oo`005Goo00<007ooOol02goo00=l7gooOol0i7oo0P?P57oo000E
Ool00`00Oomoo`0<Ool2O1oROol20n0FOol001Eoo`03001oogoo00ioo`9l7mioo`83h1Qoo`005Goo
0P004Goo00=l7gooOol0fGoo0P?P6Woo000EOol00`00Oomoo`0AOol2O1oGOol20n0LOol001Eoo`03
001oogoo01=oo`03O1moogoo0=9oo`83h1ioo`005Goo00<007ooOol057oo0W`Od7oo0P?P87oo000E
Ool00`00Oomoo`0FOol00g`OOomoo`3<Ool00`?POomoo`0POol001Eoo`8001Qoo`9l7lYoo`83h2=o
o`005Goo00<007ooOol06Goo0W`OaWoo0P?P9Goo000EOol00`00Oomoo`0KOol00g`OOomoo`32Ool0
0`?POomoo`0UOol001Eoo`03001oogoo01aoo`9l7l1oo`83h2Qoo`005Goo00<007ooOol07Woo00=l
7gooOol0^goo0P?P:Woo000EOol2000POol2O1niOol20n0/Ool001Eoo`03001oogoo025oo`03O1mo
ogoo0;Aoo`83h2ioo`005Goo00<007ooOol08Woo00=l7gooOol0/Goo0P?P<7oo000EOol00`00Oomo
o`0SOol2O1n`Ool00`?POomoo`0`Ool00003Ool0000000<0009oo`8000Aoo`8000Eoo`03001oogoo
02Eoo`03O1moogoo0:]oo`83h3=oo`000goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00
Oomoo`02Ool00`00Oomoo`0VOol2O1nYOol20n0eOol000=oo`05001oogooOol00002Ool01000Oomo
o`000Woo00<007ooOol00Woo0`00:7oo00=l7gooOol0Y7oo0P?P=goo0003Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`03001oogoo009oo`03001oogoo02Uoo`9l7j9oo`83h3Uoo`000goo00D0
07ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`0[Ool2O1nNOol20n0k
Ool0009oo`8000Aoo`8000Aoo`8000Eoo`03001oogoo02eoo`9l7i]oo`030n1oogoo03]oo`005Goo
00<007ooOol0;goo0W`OUgoo0P?P?Woo000EOol2000bOol2O1nCOol20n10Ool001Eoo`03001oogoo
03=oo`03O1moogoo08ioo`83h49oo`005Goo00<007ooOol0=7oo0W`OS7oo0P?PA7oo000EOol00`00
Oomoo`0fOol00g`OOomoo`27Ool20n16Ool001Eoo`03001oogoo03Moo`9l7hIoo`030n1oogoo04Io
o`005Goo0P00>Woo0W`OPWoo0P?PBGoo000EOol00`00Oomoo`0kOol00g`OOomoo`1mOol20n1;Ool0
01Eoo`03001oogoo03aoo`9l7g]oo`83h4eoo`005Goo00<007ooOol0?Woo00=l7gooOol0MWoo0P?P
Cgoo000EOol00`00Oomoo`0oOol2O1mdOol20n1AOol001Eoo`03001oogoo045oo`03O1moogoo071o
o`030n1oogoo055oo`005Goo0P00@goo0W`OKWoo0P?PE7oo000EOol00`00Oomoo`14Ool2O1mZOol2
0n1FOol001Eoo`03001oogoo04Ioo`03O1moogoo06Ioo`030n1oogoo05Ioo`005Goo00<007ooOol0
Agoo0W`OI7oo0P?PFGoo000EOol00`00Oomoo`19Ool00g`OOomoo`1OOol20n1KOol001Eoo`8004]o
o`9l7eioo`030n1oogoo05]oo`005Goo00<007ooOol0C7oo0W`OFWoo0P?PGWoo000EOol00`00Oomo
o`1>Ool2O1mFOol20n1POol00003Ool00000008000=oo`8000Aoo`8000Eoo`03001oogoo051oo`9l
7e9oo`83h69oo`0000=oo`00Ool017oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`1B
Ool2O1m>Ool20n1TOol0009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo0`00
E7oo00=l7gooOol0BGoo0P?PIWoo0003Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001o
ogoo009oo`03001oogoo05Eoo`9l7dQoo`030n1oogoo06Ioo`0000Eoo`00Oomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00<007ooOol0Egoo00=l7gooOol0@goo0P?PJGoo0002Ool20004
Ool20004Ool20005Ool00`00Oomoo`1HOol00g`OOomoo`10Ool20n1[Ool001Eoo`03001oogoo05Uo
o`9l7cioo`83h6eoo`005Goo00<007ooOol0Fgoo00=l7gooOol0>Goo0P?PKgoo000EOol2001MOol2
O1lgOol20n1aOol001Eoo`03001oogoo05ioo`03O1moogoo03=oo`030n1oogoo075oo`005Goo00<0
07ooOol0Ggoo0W`O<Goo0P?PM7oo000EOol00`00Oomoo`1QOol00g`OOomoo`0/Ool20n1fOol001Eo
o`03001oogoo069oo`9l7bYoo`83h7Qoo`005Goo0P00IGoo0W`O9Woo0P?PNWoo000EOol00`00Oomo
o`1VOol00g`OOomoo`0QOol20n1lOol001Eoo`03001oogoo06Moo`9l7b1oo`030n1oogoo07aoo`00
5Goo00<007ooOol0JGoo00=l7gooOol06goo0P?POgoo000EOol00`00Oomoo`1ZOol2O1lIOol20n21
Ool001Eoo`8006eoo`9l7aEoo`83h8=oo`005Goo00<007ooOol0KWoo0W`O4Goo0P?PQGoo000EOol0
0`00Oomoo`1`Ool2O1l=Ool20n27Ool001Eoo`03001oogoo079oo`9l7`Yoo`030n1oogoo08Moo`00
5Goo00<007ooOol0M7oo00=l7gooOol01Goo0P?PRWoo000EOol00`00Oomoo`1eOol2O1l3Ool20n2<
Ool001Eoo`8007Qoo`03O1moo`?P08ioo`005Goo00<007ooOol0Mgoo0P?PSgoo000EOol00`00Oomo
o`1eOol20n02Ool2O1n=Ool0009oo`8000Aoo`8000Aoo`8000Eoo`03001oogoo07Aoo`030n1oogoo
00Aoo`03O1moogoo08Yoo`0000Eoo`00Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo
00<007ooOol0LWoo0P?P27oo0W`ORWoo0003Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03
001oogoo009oo`<0071oo`83h0aoo`03O1moogoo08Moo`0017oo00@007ooOol0009oo`04001oogoo
0002Ool00`00Oomoo`02Ool00`00Oomoo`1^Ool20n0?Ool2O1n7Ool00005Ool007ooOol00002Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo06aoo`83h1=oo`9l7hEoo`000Woo0P0017oo
0P0017oo0P001Goo00<007ooOol0JWoo0P?P5goo0W`OPgoo000EOol00`00Oomoo`1YOol00`?POomo
o`0IOol2O1n1Ool001Eoo`8006Qoo`83h1ioo`9l7gmoo`005Goo00<007ooOol0IGoo0P?P8Woo00=l
7gooOol0O7oo000EOol00`00Oomoo`1SOol20n0UOol2O1mlOol001Eoo`03001oogoo065oo`83h2Uo
o`03O1moogoo07Uoo`005Goo00<007ooOol0Ggoo0P?P;7oo0W`ONGoo000EOol00`00Oomoo`1NOol0
0`?POomoo`0^Ool2O1mgOol001Eoo`8005eoo`83h3=oo`03O1moogoo07Aoo`005Goo00<007ooOol0
FWoo0P?P=Woo0W`OM7oo000EOol00`00Oomoo`1IOol00`?POomoo`0hOol00g`OOomoo`1aOol001Eo
o`03001oogoo05Moo`83h3aoo`9l7g5oo`005Goo00<007ooOol0EGoo0P?P@7oo00=l7gooOol0KWoo
000EOol2001EOol00`?POomoo`11Ool2O1m^Ool001Eoo`03001oogoo059oo`83h4Ioo`9l7faoo`00
5Goo00<007ooOol0D7oo0P?PBWoo00=l7gooOol0JGoo000EOol00`00Oomoo`1>Ool20n1=Ool2O1mY
Ool001Eoo`03001oogoo04aoo`83h55oo`03O1moogoo06Ioo`005Goo0P00Bgoo0P?PE7oo0W`OIWoo
000EOol00`00Oomoo`19Ool00`?POomoo`1FOol00g`OOomoo`1SOol001Eoo`03001oogoo04Moo`83
h5Yoo`9l7f=oo`005Goo00<007ooOol0AGoo0P?PGWoo0W`OHGoo0003Ool30002Ool20004Ool20005
Ool00`00Oomoo`13Ool20n1ROol00g`OOomoo`1NOol000Aoo`04001oogoo0002Ool01000Oomoo`00
0Woo00<007ooOol00Woo00<007ooOol0@Goo0P?PIGoo0W`OGWoo00000goo0000000300001Goo001o
ogoo00000Woo00@007ooOol000Aoo`<003moo`83h6Uoo`03O1moogoo05]oo`0000Eoo`00Oomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0?Woo00<3h7ooOol0JWoo0W`OFgoo
0002Ool00`00Ool00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo03aoo`83h6mo
o`9l7eUoo`000goo0P000goo0P0017oo0P001Goo00<007ooOol0>Woo0P?PLgoo00=l7gooOol0EWoo
000EOol00`00Oomoo`0hOol20n1fOol2O1mFOol001Eoo`8003Moo`83h7Yoo`9l7eAoo`005Goo00<0
07ooOol0=7oo0P?POWoo00=l7gooOol0DGoo000EOol00`00Oomoo`0cOol00`?POomoo`1oOol2O1mA
Ool001Eoo`03001oogoo035oo`83h8Aoo`03O1moogoo04ioo`005Goo00<007ooOol0<7oo00<3h7oo
Ool0QGoo0W`OCWoo000EOol2000_Ool20n2:Ool2O1m<Ool001Eoo`03001oogoo02aoo`83h8ioo`03
O1moogoo04Uoo`005Goo00<007ooOol0:goo00<3h7ooOol0Sgoo0W`OBGoo000EOol00`00Oomoo`0Y
Ool20n2DOol00g`OOomoo`16Ool001Eoo`03001oogoo02Qoo`030n1oogoo09Eoo`9l7dIoo`005Goo
00<007ooOol09Woo0P?PVWoo0W`OA7oo000EOol2000UOol20n2NOol2O1m2Ool001Eoo`03001oogoo
029oo`83h:9oo`9l7d1oo`005Goo00<007ooOol087oo0P?PYWoo0W`O?Woo000EOol00`00Oomoo`0N
Ool20n2ZOol00g`OOomoo`0kOol001Eoo`03001oogoo01aoo`83h:eoo`9l7c]oo`005Goo0P006goo
0P?P/Goo00=l7gooOol0>7oo000EOol00`00Oomoo`0HOol20n2dOol2O1lhOol001Eoo`03001oogoo
01Ioo`83h;Qoo`9l7cIoo`000Woo0P0017oo0P0017oo0P001Goo00<007ooOol057oo0P?P_7oo00=l
7gooOol0<goo00001Goo001oogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomo
o`0COol00`?POomoo`2mOol2O1lcOol000Aoo`04001oogoo0002Ool01000Oomoo`000Woo00<007oo
Ool00Woo0`004Goo0P?P`Woo00=l7gooOol0<7oo0002Ool20003Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`03001oogoo011oo`030n1oogoo0<=oo`9l7c1oo`000Woo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0004Ool00`00Oomoo`0>Ool20n38Ool00g`OOomoo`0]Ool0009oo`<000=o
o`8000Aoo`8000Eoo`03001oogoo00aoo`83h<]oo`9l7beoo`005Goo00<007ooOol02goo00<3h7oo
Ool0cGoo0W`O:goo000EOol00`00Oomoo`09Ool20n3BOol00g`OOomoo`0XOol001Eoo`8000Uoo`03
0n1oogoo0==oo`9l7bQoo`005Goo00<007ooOol01Woo0P?Pf7oo00=l7gooOol09Goo000EOol00`00
Oomoo`04Ool20n3KOol2O1lUOol001Eoo`03001oogoo009oo`83h=moo`03O1moogoo029oo`005Goo
00<007ooOol00P?PhWoo00=l7gooOol08Goo000EOol00`000n03h03UOol2O1lQOol001Eoo`030n1o
ogoo0>Moo`03O1moogoo01ioo`005Goo00<007ooOol0j7oo0W`O7Woo000EOol00`00Oomoo`3ZOol0
0g`OOomoo`0KOol001Eoo`03001oogoo0>]oo`9l7a]oo`005Goo0P00kWoo0W`O6Goo000EOol00`00
Oomoo`3_Ool2O1lGOol001Eoo`03001oogoo0?5oo`9l7aEoo`005Goo00<007ooOol0lgoo0W`O4goo
000EOol00`00Oomoo`3eOol2O1lAOol001Eoo`03001oogoo0?Moo`9l7`moo`005Goo0P00nWoo00=l
7gooOol037oo000EOol00`00Oomoo`3jOol00g`OOomoo`0;Ool001Eoo`03001oogoo0?]oo`9l7`]o
o`0000Aoo`00000000Aoo`8000Aoo`8000Eoo`03001oogoo0?eoo`03O1moogoo00Qoo`0000Eoo`00
Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0oWoo0W`O27oo00001Goo
001oogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool3003oOol1Ool00g`OOomoo`05Ool0
0004Ool000000003Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo0?moo`Uoo`000Woo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`3oOol9Ool0009oo`<0
00=oo`8000Aoo`8000Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0841707, -46.4542, \
0.00386956, 3.74892}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Activity coefficients using Margules model", "Subsubtitle",
  Background->RGBColor[0.929702, 0.996109, 0.566415]],

Cell[BoxData[
    \(A12 = 0.8557; A21 = 0.7476;\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(G3 = Exp[\((A12 + 2\ \((A21 - A12)\)\ x)\)\ \((1 - x)\)^2]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\((1 - x)\)\^2\ \
\((\(\(0.8557`\)\(\[InvisibleSpace]\)\) - 0.21619999999999995`\ x)\)\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(G4 = Exp[\((A21 + 2\ \((A12 - A21)\)\ \((1 - x)\))\)\ x^2]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\((\(\(0.7476`\)\(\[InvisibleSpace]\)\) + \
0.21619999999999995`\ \((1 - x)\))\)\ x\^2\)\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Partial pressures using Modified Raoult's law ", "Subsubtitle",
  Background->RGBColor[0.929702, 0.996109, 0.566415]],

Cell[BoxData[
    \(P1[x_] := G3\ PS1\ x; P2[x_] := G4\ PS2\ \((1 - x)\);\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(plt5 = 
      Plot[{P1[x], P2[x]}, {x, 0, 1}, 
        PlotStyle \[Rule] {RGBColor[0, 0, 1], RGBColor[0, 0, 1]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.000983029 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .11302 -18 -4.5 ]
[.01131 .11302 0 4.5 ]
[.01131 .21132 -18 -4.5 ]
[.01131 .21132 0 4.5 ]
[.01131 .30962 -18 -4.5 ]
[.01131 .30962 0 4.5 ]
[.01131 .40793 -18 -4.5 ]
[.01131 .40793 0 4.5 ]
[.01131 .50623 -18 -4.5 ]
[.01131 .50623 0 4.5 ]
[.01131 .60453 -18 -4.5 ]
[.01131 .60453 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11302 m
.03006 .11302 L
s
[(100)] .01131 .11302 1 0 Mshowa
.02381 .21132 m
.03006 .21132 L
s
[(200)] .01131 .21132 1 0 Mshowa
.02381 .30962 m
.03006 .30962 L
s
[(300)] .01131 .30962 1 0 Mshowa
.02381 .40793 m
.03006 .40793 L
s
[(400)] .01131 .40793 1 0 Mshowa
.02381 .50623 m
.03006 .50623 L
s
[(500)] .01131 .50623 1 0 Mshowa
.02381 .60453 m
.03006 .60453 L
s
[(600)] .01131 .60453 1 0 Mshowa
.125 Mabswid
.02381 .03438 m
.02756 .03438 L
s
.02381 .05404 m
.02756 .05404 L
s
.02381 .0737 m
.02756 .0737 L
s
.02381 .09336 m
.02756 .09336 L
s
.02381 .13268 m
.02756 .13268 L
s
.02381 .15234 m
.02756 .15234 L
s
.02381 .172 m
.02756 .172 L
s
.02381 .19166 m
.02756 .19166 L
s
.02381 .23098 m
.02756 .23098 L
s
.02381 .25064 m
.02756 .25064 L
s
.02381 .2703 m
.02756 .2703 L
s
.02381 .28996 m
.02756 .28996 L
s
.02381 .32928 m
.02756 .32928 L
s
.02381 .34895 m
.02756 .34895 L
s
.02381 .36861 m
.02756 .36861 L
s
.02381 .38827 m
.02756 .38827 L
s
.02381 .42759 m
.02756 .42759 L
s
.02381 .44725 m
.02756 .44725 L
s
.02381 .46691 m
.02756 .46691 L
s
.02381 .48657 m
.02756 .48657 L
s
.02381 .52589 m
.02756 .52589 L
s
.02381 .54555 m
.02756 .54555 L
s
.02381 .56521 m
.02756 .56521 L
s
.02381 .58487 m
.02756 .58487 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .01472 m
.06244 .06678 L
.10458 .11538 L
.14415 .15468 L
.18221 .18778 L
.22272 .21889 L
.26171 .24558 L
.30316 .27116 L
.34309 .29364 L
.3815 .31371 L
.42237 .33378 L
.46172 .35219 L
.49955 .3693 L
.53984 .38712 L
.57861 .4041 L
.61984 .42217 L
.65954 .43977 L
.69774 .45701 L
.73838 .47586 L
.77751 .49462 L
.81909 .51534 L
.85916 .53621 L
.89771 .55723 L
.93871 .58073 L
.97619 .60332 L
s
.02381 .54782 m
.06244 .527 L
.10458 .50594 L
.14415 .48747 L
.18221 .47071 L
.22272 .45372 L
.26171 .43801 L
.30316 .4218 L
.34309 .40644 L
.3815 .39173 L
.42237 .37596 L
.46172 .36044 L
.49955 .34503 L
.53984 .32789 L
.57861 .31045 L
.61984 .29065 L
.65954 .27008 L
.69774 .24864 L
.73838 .22374 L
.77751 .19743 L
.81909 .16655 L
.85916 .13355 L
.89771 .0984 L
.93871 .05686 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0012Ool2
0004Ool20003Ool4000UOol20004Ool20005Ool3000SOol20004Ool20003Ool3000VOol20004Ool2
0004Ool2000[Ool50005Ool0045oo`04001oogoo0008Ool00`00Oomoo`0UOol01000Oomoo`002goo
00<007ooOol08Goo00@007ooOol000Qoo`04001oogoo000TOol01000Oomoo`0027oo00@007ooOol0
02aoo`03001oogoo00Eoo`00@Goo00@007ooOol000Uoo`03001oogoo02Aoo`04001oogoo0008Ool5
000ROol01000Oomoo`0027oo00@007ooOol002Aoo`04001oogoo0008Ool01000Oomoo`00;7oo00<0
07ooOol01Goo0011Ool01000Oomoo`002Woo00<007ooOol08goo00@007ooOol000Qoo`04001oogoo
000SOol01000Oomoo`0027oo0`009Goo00@007ooOol000Uoo`8002eoo`03001oogoo00Eoo`00@Goo
00@007ooOol000Qoo`04001oogoo000TOol01000Oomoo`002Goo00<007oo00008goo00@007ooOol0
00Uoo`03001oogoo02Aoo`04001oogoo0008Ool01000Oomoo`00;7oo00<007ooOol01Goo0012Ool2
000:Ool2000VOol2000;Ool2000TOol2000:Ool3000UOol2000:Ool2000/Ool20007Ool00?moob5o
o`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uo
o`005Goo00<007ooOol0ogoo2Goo000?Ool600000`0O0000003o000100000`0O000000040001Ool0
01Eoo`0300007goo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Uoo`0301l007oo00Ioo`005Goo00<007oo01l0<Goo00<007ooOol0<Goo00<007ooOol0<7oo00<0
07ooOol0<Goo00<007ooOol0;goo00<07goo00001goo000EOol00`00Ool07`3mOol00`0OOomoo`08
Ool001Eoo`04001oogoo01okOol00`0OOomoo`09Ool001Eoo`80009oo`0301moogoo0?Moo`0301mo
ogoo00Yoo`005Goo00<007ooOol00Woo00<07gooOol0mWoo00<07gooOol02Woo000EOol00`00Oomo
o`03Ool00`0OOomoo`3dOol00`0OOomoo`0;Ool001Eoo`03001oogoo00=oo`0301moogoo0?=oo`03
01moogoo00aoo`005Goo00<007ooOol017oo00<07gooOol0lGoo00<07gooOol03Goo000EOol00`00
Oomoo`05Ool00`0OOomoo`3_Ool00`0OOomoo`0>Ool001Eoo`8000Moo`0301moogoo0>eoo`0301mo
ogoo00moo`005Goo00<007ooOol01Woo00<07gooOol0k7oo00<07gooOol047oo000EOol00`00Oomo
o`07Ool00`0OOomoo`3ZOol00`0OOomoo`0AOol001Eoo`03001oogoo00Qoo`0301moogoo0>Qoo`03
01moogoo019oo`005Goo00<007ooOol02Goo00<07gooOol0iWoo00<07gooOol04goo000EOol2000;
Ool00`0OOomoo`3TOol00`0OOomoo`0DOol001Eoo`03001oogoo00]oo`0301moogoo0>9oo`0301mo
ogoo01Eoo`005Goo00<007ooOol02goo00<07gooOol0hGoo00<07gooOol05Woo000EOol00`00Oomo
o`0<Ool00`0OOomoo`3OOol00`0OOomoo`0GOol001Eoo`03001oogoo00eoo`0301moogoo0=eoo`03
01moogoo01Qoo`005Goo0P003goo00<07gooOol0fgoo00<07gooOol06Goo000EOol00`00Oomoo`0?
Ool00`0OOomoo`3IOol00`0OOomoo`0JOol001Eoo`03001oogoo011oo`0301moogoo0=Moo`0301mo
ogoo01]oo`005Goo00<007ooOol047oo00<07gooOol0eWoo00<07gooOol077oo00000goo00000003
0002Ool20004Ool20005Ool00`00Oomoo`0AOol00`0OOomoo`3DOol00`0OOomoo`0MOol000=oo`05
001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol04Woo00<07gooOol0
dWoo00<07gooOol07Woo0003Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo009o
o`<001=oo`0301moogoo0=1oo`0301moogoo01moo`000goo00D007ooOomoo`00009oo`04001oogoo
0002Ool00`00Oomoo`02Ool00`00Oomoo`0DOol00`0OOomoo`3=Ool201lROol000=oo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol05Goo00<07gooOol0bgoo00<0
7gooOol08Woo0002Ool20004Ool20004Ool20005Ool00`00Oomoo`0FOol00`0OOomoo`39Ool00`0O
Oomoo`0SOol001Eoo`03001oogoo01Moo`0301moogoo0<Moo`0301moogoo02Aoo`005Goo0P006Goo
00<07gooOol0aGoo00<07gooOol09Goo000EOol00`00Oomoo`0IOol00`0OOomoo`33Ool00`0OOomo
o`0VOol001Eoo`03001oogoo01Yoo`0301moogoo0<1oo`807bUoo`005Goo00<007ooOol06goo00<0
7gooOol0_Woo00<07gooOol0:Goo000EOol00`00Oomoo`0LOol00`0OOomoo`2lOol00`0OOomoo`0Z
Ool001Eoo`8001ioo`0301moogoo0;Yoo`0301moogoo02]oo`005Goo00<007ooOol07Woo00<07goo
Ool0^7oo00<07gooOol0;7oo000EOol00`00Oomoo`0OOol00`0OOomoo`2eOol201l_Ool001Eoo`03
001oogoo021oo`0301moogoo0;=oo`0301moogoo02moo`005Goo00<007ooOol08Goo00<07gooOol0
/Goo00<07gooOol0<7oo000EOol00`00Oomoo`0ROol00`0OOomoo`2_Ool00`0OOomoo`0aOol001Eo
o`8002Aoo`807jeoo`807cAoo`005Goo00<007ooOol09Goo00<07gooOol0ZGoo00<07gooOol0=7oo
000EOol00`00Oomoo`0VOol00`0OOomoo`2WOol00`0OOomoo`0eOol001Eoo`03001oogoo02Moo`03
01moogoo0:Eoo`0301moogoo03Ioo`005Goo00<007ooOol0:7oo00<07gooOol0Xgoo00<07gooOol0
=goo000EOol2000ZOol201nQOol201ljOol001Eoo`03001oogoo02]oo`0301moogoo09eoo`0301mo
ogoo03Yoo`005Goo00<007ooOol0;7oo00<07gooOol0Vgoo00<07gooOol0>goo00000goo00000002
0003Ool20004Ool20005Ool00`00Oomoo`0]Ool201nIOol201lnOol00003Ool007oo00Aoo`04001o
ogoo0002Ool01000Oomoo`0017oo00<007ooOol0;goo00<07gooOol0UGoo00<07gooOol0?Woo0002
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Aoo`<0031oo`0301moogoo099oo`80
7d5oo`000goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`0a
Ool201n@Ool201m3Ool00005Ool007ooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`03
001oogoo03=oo`0301moogoo08aoo`0301moogoo04=oo`000Woo0P0017oo0P0017oo0P001Goo00<0
07ooOol0=7oo0P0ORWoo0P0OAWoo000EOol00`00Oomoo`0fOol00`0OOomoo`26Ool00`0OOomoo`16
Ool001Eoo`03001oogoo03Moo`0301moogoo08=oo`807dUoo`005Goo0P00>Goo0P0OPGoo0P0OBgoo
000EOol00`00Oomoo`0jOol00`0OOomoo`1lOol201m=Ool001Eoo`03001oogoo03]oo`0301moogoo
07Uoo`807dmoo`005Goo00<007ooOol0?7oo0P0OMgoo0P0ODGoo000EOol00`00Oomoo`0nOol00`0O
Oomoo`1cOol00`0OOomoo`1AOol001Eoo`80041oo`807g5oo`807eAoo`005Goo00<007ooOol0@Goo
00<07gooOol0K7oo0P0OEWoo000EOol00`00Oomoo`12Ool201m[Ool00`0OOomoo`1FOol001Eoo`03
001oogoo04Aoo`807fMoo`807eUoo`005Goo00<007ooOol0AWoo00<07gooOol0HWoo0P0OFgoo000E
Ool20018Ool201mQOol00`0OOomoo`1KOol001Eoo`03001oogoo04Uoo`0301moogoo05aoo`807eio
o`005Goo00<007ooOol0BWoo0P0OFWoo0P0OH7oo000EOol00`00Oomoo`1<Ool201mFOol201mROol0
01Eoo`03001oogoo04ioo`807e9oo`807fAoo`005Goo00<007ooOol0D7oo0P0OCWoo0P0OIWoo000E
Ool2001COol201m:Ool201mXOol001Eoo`03001oogoo05Aoo`0301moogoo04Eoo`807fYoo`005Goo
00<007ooOol0EGoo0P0O@goo0P0OK7oo0002Ool20004Ool20004Ool20005Ool00`00Oomoo`1GOol2
01loOol201m^Ool00005Ool007ooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001o
ogoo05Uoo`807c]oo`807g1oo`000goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomo
o`02Ool3001KOol201lfOol301mbOol000Aoo`04001oogoo0002Ool01000Oomoo`000Woo00<007oo
Ool00Woo00<007ooOol0GGoo0P0O<Woo0P0OMGoo00001Goo001oogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool00`00Oomoo`1OOol201l^Ool201mgOol0009oo`8000Aoo`8000Aoo`8000Eo
o`03001oogoo065oo`807bYoo`807gUoo`005Goo00<007ooOol0Hgoo0P0O9Woo0P0ONgoo000EOol2
001VOol201lQOol301mmOol001Eoo`03001oogoo06Moo`807aeoo`807h1oo`005Goo00<007ooOol0
JGoo0P0O6Goo0P0OPWoo000EOol00`00Oomoo`1[Ool201lEOol201n4Ool001Eoo`03001oogoo06eo
o`807a5oo`807hIoo`005Goo00<007ooOol0Kgoo0P0O37oo0`0OR7oo000EOol2001bOol201l8Ool2
01n;Ool001Eoo`03001oogoo07=oo`<07`9oo`<07heoo`005Goo00<007ooOol0MWoo0P0OT7oo000E
Ool00`00Oomoo`1cOol301l2Ool301n=Ool001Eoo`03001oogoo071oo`<07`Qoo`807h]oo`005Goo
0P00Kgoo0P0O3Goo0`0OR7oo000EOol00`00Oomoo`1[Ool301lBOol201n6Ool001Eoo`03001oogoo
06Qoo`<07aMoo`807hAoo`005Goo00<007ooOol0IGoo0`0O77oo0P0OPWoo000EOol00`00Oomoo`1S
Ool201lQOol201n0Ool001Eoo`80065oo`<07bEoo`<07geoo`005Goo00<007ooOol0GGoo0`0O:goo
0P0ONgoo000EOol00`00Oomoo`1KOol201l`Ool201miOol001Eoo`03001oogoo05Qoo`<07cAoo`80
7gMoo`000goo0`000Woo0P0017oo0P001Goo00<007ooOol0EWoo0P0O>Goo0P0OMGoo0004Ool01000
Oomoo`000Woo00@007ooOol0009oo`03001oogoo009oo`03001oogoo05=oo`<07ceoo`<07g9oo`00
00=oo`0000000`0000Eoo`00Oomoo`00009oo`04001oogoo0004Ool3001@Ool301m3Ool201m`Ool0
0005Ool007ooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo04ioo`807dQo
o`807fioo`000Woo00<007oo00000Woo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`1;
Ool301m<Ool201m/Ool000=oo`8000=oo`8000Aoo`8000Eoo`03001oogoo04Qoo`<07e5oo`807fYo
o`005Goo00<007ooOol0AWoo0P0OEWoo0`0OIgoo000EOol20015Ool201mKOol301mTOol001Eoo`03
001oogoo049oo`807f1oo`807f9oo`005Goo00<007ooOol0@7oo0P0OI7oo0`0OGgoo000EOol00`00
Oomoo`0mOol301mYOol201mMOol001Eoo`03001oogoo03Yoo`<07fioo`807e]oo`005Goo0P00>Goo
0P0OLgoo0P0OFGoo000EOol00`00Oomoo`0eOol301mgOol201mGOol001Eoo`03001oogoo039oo`<0
7gaoo`807eEoo`005Goo00<007ooOol0<7oo0P0OPGoo0`0ODWoo000EOol00`00Oomoo`0^Ool201n6
Ool201m@Ool001Eoo`03001oogoo02aoo`807hYoo`807dioo`005Goo0P00:goo0P0OSWoo0P0OC7oo
000EOol00`00Oomoo`0WOol301nBOol201m:Ool001Eoo`03001oogoo02Eoo`807iMoo`<07dMoo`00
5Goo00<007ooOol08Woo0`0OW7oo0P0OAGoo000EOol00`00Oomoo`0POol201nQOol201m3Ool001Eo
o`8001ioo`<07jEoo`807d5oo`005Goo00<007ooOol06goo0P0OZWoo0P0O?goo000EOol00`00Oomo
o`0IOol201n^Ool201lmOol0009oo`8000Aoo`8000Aoo`8000Eoo`03001oogoo01Moo`807k9oo`80
7c]oo`0000Eoo`00Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol05Goo
0P0O]Woo0P0O>Goo0004Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo009oo`<001=o
o`807kYoo`807cMoo`000Woo0P000goo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`0A
Ool201nnOol201leOol0009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo00<0
07ooOol03goo0P0O`Woo0P0O<goo0002Ool30003Ool20004Ool20005Ool00`00Oomoo`0=Ool201o6
Ool201laOol001Eoo`03001oogoo00]oo`807lYoo`807bmoo`005Goo00<007ooOol02Goo0P0OcWoo
0P0O;Goo000EOol20009Ool00`0OOomoo`3@Ool201l[Ool001Eoo`03001oogoo00Ioo`807mEoo`80
7bUoo`005Goo00<007ooOol017oo0P0OfGoo0P0O9goo000EOol00`00Oomoo`02Ool201oMOol201lU
Ool001Eoo`03001oogoo00807n5oo`807b=oo`005Goo00<0000O01l0iGoo00<07gooOol087oo000E
Ool00`0OOomoo`3VOol201lPOol001Eoo`03001oogoo0>Qoo`807aioo`005Goo00<007ooOol0jWoo
00<07gooOol06goo000EOol00`00Oomoo`3[Ool201lKOol001Eoo`800>ioo`807aUoo`005Goo00<0
07ooOol0kgoo00<07gooOol05Woo000EOol00`00Oomoo`3`Ool201lFOol001Eoo`03001oogoo0?9o
o`807aAoo`005Goo00<007ooOol0m7oo0P0O4Woo000EOol00`00Oomoo`3fOol00`0OOomoo`0?Ool0
01Eoo`800?Qoo`807`moo`005Goo00<007ooOol0nGoo0P0O3Goo000EOol00`00Oomoo`3kOol00`0O
Oomoo`0:Ool00004Ool000000004Ool20004Ool20005Ool00`00Oomoo`3lOol201l:Ool00005Ool0
07ooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo0?ioo`807`Qoo`0000Eo
o`00Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo0`00ogoo0Goo00<07gooOol01Goo
000017oo000000000goo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`3oOol9Ool0009o
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0ogoo2Goo0002Ool3
0003Ool20004Ool20005Ool00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0841707, -46.4542, \
0.00386956, 3.74892}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[plt3, plt5]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.000983029 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .11302 -18 -4.5 ]
[.01131 .11302 0 4.5 ]
[.01131 .21132 -18 -4.5 ]
[.01131 .21132 0 4.5 ]
[.01131 .30962 -18 -4.5 ]
[.01131 .30962 0 4.5 ]
[.01131 .40793 -18 -4.5 ]
[.01131 .40793 0 4.5 ]
[.01131 .50623 -18 -4.5 ]
[.01131 .50623 0 4.5 ]
[.01131 .60453 -18 -4.5 ]
[.01131 .60453 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11302 m
.03006 .11302 L
s
[(100)] .01131 .11302 1 0 Mshowa
.02381 .21132 m
.03006 .21132 L
s
[(200)] .01131 .21132 1 0 Mshowa
.02381 .30962 m
.03006 .30962 L
s
[(300)] .01131 .30962 1 0 Mshowa
.02381 .40793 m
.03006 .40793 L
s
[(400)] .01131 .40793 1 0 Mshowa
.02381 .50623 m
.03006 .50623 L
s
[(500)] .01131 .50623 1 0 Mshowa
.02381 .60453 m
.03006 .60453 L
s
[(600)] .01131 .60453 1 0 Mshowa
.125 Mabswid
.02381 .03438 m
.02756 .03438 L
s
.02381 .05404 m
.02756 .05404 L
s
.02381 .0737 m
.02756 .0737 L
s
.02381 .09336 m
.02756 .09336 L
s
.02381 .13268 m
.02756 .13268 L
s
.02381 .15234 m
.02756 .15234 L
s
.02381 .172 m
.02756 .172 L
s
.02381 .19166 m
.02756 .19166 L
s
.02381 .23098 m
.02756 .23098 L
s
.02381 .25064 m
.02756 .25064 L
s
.02381 .2703 m
.02756 .2703 L
s
.02381 .28996 m
.02756 .28996 L
s
.02381 .32928 m
.02756 .32928 L
s
.02381 .34895 m
.02756 .34895 L
s
.02381 .36861 m
.02756 .36861 L
s
.02381 .38827 m
.02756 .38827 L
s
.02381 .42759 m
.02756 .42759 L
s
.02381 .44725 m
.02756 .44725 L
s
.02381 .46691 m
.02756 .46691 L
s
.02381 .48657 m
.02756 .48657 L
s
.02381 .52589 m
.02756 .52589 L
s
.02381 .54555 m
.02756 .54555 L
s
.02381 .56521 m
.02756 .56521 L
s
.02381 .58487 m
.02756 .58487 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
.02381 .01472 m
.06244 .03859 L
.10458 .06463 L
.14415 .08909 L
.18221 .11261 L
.22272 .13765 L
.26171 .16175 L
.30316 .18736 L
.34309 .21204 L
.3815 .23578 L
.42237 .26104 L
.46172 .28536 L
.49955 .30874 L
.53984 .33364 L
.57861 .3576 L
.61984 .38308 L
.65954 .40762 L
.69774 .43123 L
.73838 .45635 L
.77751 .48053 L
.81909 .50623 L
.85916 .53099 L
.89771 .55482 L
.93871 .58016 L
.97619 .60332 L
s
0 1 0 r
.02381 .54782 m
.06244 .52619 L
.10458 .50261 L
.14415 .48046 L
.18221 .45915 L
.22272 .43648 L
.26171 .41465 L
.30316 .39145 L
.34309 .3691 L
.3815 .3476 L
.42237 .32472 L
.46172 .3027 L
.49955 .28152 L
.53984 .25897 L
.57861 .23726 L
.61984 .21419 L
.65954 .19196 L
.69774 .17058 L
.73838 .14783 L
.77751 .12593 L
.81909 .10265 L
.85916 .08022 L
.89771 .05864 L
.93871 .03569 L
.97619 .01472 L
s
0 0 1 r
.02381 .01472 m
.06244 .06678 L
.10458 .11538 L
.14415 .15468 L
.18221 .18778 L
.22272 .21889 L
.26171 .24558 L
.30316 .27116 L
.34309 .29364 L
.3815 .31371 L
.42237 .33378 L
.46172 .35219 L
.49955 .3693 L
.53984 .38712 L
.57861 .4041 L
.61984 .42217 L
.65954 .43977 L
.69774 .45701 L
.73838 .47586 L
.77751 .49462 L
.81909 .51534 L
.85916 .53621 L
.89771 .55723 L
.93871 .58073 L
.97619 .60332 L
s
.02381 .54782 m
.06244 .527 L
.10458 .50594 L
.14415 .48747 L
.18221 .47071 L
.22272 .45372 L
.26171 .43801 L
.30316 .4218 L
.34309 .40644 L
.3815 .39173 L
.42237 .37596 L
.46172 .36044 L
.49955 .34503 L
.53984 .32789 L
.57861 .31045 L
.61984 .29065 L
.65954 .27008 L
.69774 .24864 L
.73838 .22374 L
.77751 .19743 L
.81909 .16655 L
.85916 .13355 L
.89771 .0984 L
.93871 .05686 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0012Ool2
0004Ool20003Ool4000UOol20004Ool20005Ool3000SOol20004Ool20003Ool3000VOol20004Ool2
0004Ool2000[Ool50005Ool0045oo`04001oogoo0008Ool00`00Oomoo`0UOol01000Oomoo`002goo
00<007ooOol08Goo00@007ooOol000Qoo`04001oogoo000TOol01000Oomoo`0027oo00@007ooOol0
02aoo`03001oogoo00Eoo`00@Goo00@007ooOol000Uoo`03001oogoo02Aoo`04001oogoo0008Ool5
000ROol01000Oomoo`0027oo00@007ooOol002Aoo`04001oogoo0008Ool01000Oomoo`00;7oo00<0
07ooOol01Goo0011Ool01000Oomoo`002Woo00<007ooOol08goo00@007ooOol000Qoo`04001oogoo
000SOol01000Oomoo`0027oo0`009Goo00@007ooOol000Uoo`8002eoo`03001oogoo00Eoo`00@Goo
00@007ooOol000Qoo`04001oogoo000TOol01000Oomoo`002Goo00<007oo00008goo00@007ooOol0
00Uoo`03001oogoo02Aoo`04001oogoo0008Ool01000Oomoo`00;7oo00<007ooOol01Goo0012Ool2
000:Ool2000VOol2000;Ool2000TOol2000:Ool3000UOol2000:Ool2000/Ool20007Ool00?moob5o
o`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uo
o`005Goo00<007ooOol0ogoo2Goo000?Ool600000`0O0000003o000100000`0O000000040001Ool0
01Eoo`0300007g`O00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Qoo`030n007`0000Moo`005Goo00<007oo01l00W`O;goo00<007ooOol0<Goo00<007ooOol0<7oo
00<007ooOol0<Goo00<007ooOol0;Goo0P?P00<07goo00001goo000EOol00`00Ool07`02Ool2O1og
Ool00`?POol07`0:Ool001Eoo`04001oogoo01l3Ool2O1ocOol20n000goo01moo`0:Ool001Eoo`80
009oo`0301moogoo009oo`9l7nmoo`83h09oo`0301moogoo00Yoo`005Goo00<007ooOol00Woo00<0
7gooOol00goo00=l7gooOol0jgoo00<3h7ooOol00Woo00<07gooOol02Woo000EOol00`00Oomoo`03
Ool00`0OOomoo`03Ool2O1oYOol20n04Ool00`0OOomoo`0;Ool001Eoo`03001oogoo00=oo`0301mo
ogoo00Eoo`03O1moogoo0>Aoo`83h0Eoo`0301moogoo00aoo`005Goo00<007ooOol017oo00<07goo
Ool01Goo0W`OhWoo0P?P1Woo00<07gooOol03Goo000EOol00`00Oomoo`05Ool00`0OOomoo`06Ool2
O1oNOol20n07Ool00`0OOomoo`0>Ool001Eoo`8000Moo`0301moogoo00Moo`03O1moogoo0=Uoo`83
h0Qoo`0301moogoo00moo`005Goo00<007ooOol01Woo00<07gooOol027oo0W`Oegoo0P?P2Goo00<0
7gooOol047oo000EOol00`00Oomoo`07Ool00`0OOomoo`09Ool00g`OOomoo`3BOol20n0:Ool00`0O
Oomoo`0AOol001Eoo`03001oogoo00Qoo`0301moogoo00Uoo`9l7m1oo`83h0]oo`0301moogoo019o
o`005Goo00<007ooOol02Goo00<07gooOol02Woo00=l7gooOol0c7oo00<3h7ooOol02Woo00<07goo
Ool04goo000EOol2000;Ool00`0OOomoo`0:Ool2O1o:Ool20n0<Ool00`0OOomoo`0DOol001Eoo`03
001oogoo00]oo`0301moogoo00]oo`9l7lIoo`83h0eoo`0301moogoo01Eoo`005Goo00<007ooOol0
2goo00<07gooOol03Goo00=l7gooOol0`Woo00<3h7ooOol037oo00<07gooOol05Woo000EOol00`00
Oomoo`0<Ool00`0OOomoo`0=Ool2O1o0Ool20n0>Ool00`0OOomoo`0GOol001Eoo`03001oogoo00eo
o`0301moogoo00ioo`03O1moogoo0;]oo`83h0moo`0301moogoo01Qoo`005Goo0P003goo00<07goo
Ool03Woo0W`O^Goo0P?P47oo00<07gooOol06Goo000EOol00`00Oomoo`0?Ool00`0OOomoo`0?Ool0
0g`OOomoo`2dOol20n0AOol00`0OOomoo`0JOol001Eoo`03001oogoo011oo`0301moogoo00moo`03
O1moogoo0;5oo`83h19oo`0301moogoo01]oo`005Goo00<007ooOol047oo00<07gooOol047oo0W`O
/7oo00<3h7ooOol04Goo00<07gooOol077oo00000goo000000030002Ool20004Ool20005Ool00`00
Oomoo`0AOol00`0OOomoo`0AOol00g`OOomoo`2[Ool20n0COol00`0OOomoo`0MOol000=oo`05001o
ogooOol00002Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol04Woo00<07gooOol04Goo
0W`OZGoo0P?P57oo00<07gooOol07Woo0003Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03
001oogoo009oo`<001=oo`0301moogoo019oo`03O1moogoo0:Aoo`83h1Eoo`0301moogoo01moo`00
0goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`0DOol00`0O
Oomoo`0BOol2O1nROol20n0EOol201lROol000=oo`05001oogooOol00002Ool01000Oomoo`000Woo
00<007ooOol00Woo00<007ooOol05Goo00<07gooOol04goo0W`OWWoo0P?P5Woo00<07gooOol08Woo
0002Ool20004Ool20004Ool20005Ool00`00Oomoo`0FOol00`0OOomoo`0DOol2O1nKOol00`?POomo
o`0EOol00`0OOomoo`0SOol001Eoo`03001oogoo01Moo`0301moogoo01Eoo`9l7iMoo`83h1Moo`03
01moogoo02Aoo`005Goo0P006Goo00<07gooOol05Woo0W`OTgoo0P?P67oo00<07gooOol09Goo000E
Ool00`00Oomoo`0IOol00`0OOomoo`0GOol00g`OOomoo`2>Ool20n0IOol00`0OOomoo`0VOol001Eo
o`03001oogoo01Yoo`0301moogoo01Moo`9l7haoo`83h1Uoo`807bUoo`005Goo00<007ooOol06goo
00<07gooOol067oo00=l7gooOol0Qgoo0P?P6Woo00<07gooOol0:Goo000EOol00`00Oomoo`0LOol0
0`0OOomoo`0HOol2O1n6Ool00`?POomoo`0IOol00`0OOomoo`0ZOol001Eoo`8001ioo`0301moogoo
01Uoo`9l7h9oo`83h1]oo`0301moogoo02]oo`005Goo00<007ooOol07Woo00<07gooOol06Woo00=l
7gooOol0OGoo0P?P77oo00<07gooOol0;7oo000EOol00`00Oomoo`0OOol00`0OOomoo`0JOol2O1mk
Ool20n0LOol201l_Ool001Eoo`03001oogoo021oo`0301moogoo01]oo`03O1moogoo07Ioo`83h1eo
o`0301moogoo02moo`005Goo00<007ooOol08Goo00<07gooOol06goo0W`OM7oo0P?P7Woo00<07goo
Ool0<7oo000EOol00`00Oomoo`0ROol00`0OOomoo`0LOol00g`OOomoo`1`Ool00`?POomoo`0MOol0
0`0OOomoo`0aOol001Eoo`8002Aoo`807aeoo`9l7fioo`83h1ioo`807cAoo`005Goo00<007ooOol0
9Goo00<07gooOol077oo0W`OJWoo0P?P7goo00<07gooOol0=7oo000EOol00`00Oomoo`0VOol00`0O
Oomoo`0MOol00g`OOomoo`1VOol00`?POomoo`0NOol00`0OOomoo`0eOol001Eoo`03001oogoo02Mo
o`0301moogoo01eoo`9l7fAoo`83h21oo`0301moogoo03Ioo`005Goo00<007ooOol0:7oo00<07goo
Ool07Woo00=l7gooOol0Ggoo0P?P8Goo00<07gooOol0=goo000EOol2000ZOol201lOOol2O1mNOol0
0`?POomoo`0OOol201ljOol001Eoo`03001oogoo02]oo`0301moogoo01ioo`9l7eYoo`83h25oo`03
01moogoo03Yoo`005Goo00<007ooOol0;7oo00<07gooOol07goo0W`OEWoo0P?P8Woo00<07gooOol0
>goo00000goo000000020003Ool20004Ool20005Ool00`00Oomoo`0]Ool201lQOol2O1mBOol20n0R
Ool201lnOol00003Ool007oo00Aoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0;goo
00<07gooOol087oo0W`OCWoo0P?P8goo00<07gooOol0?Woo0002Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Aoo`<0031oo`0301moogoo025oo`03O1moogoo04Uoo`83h2=oo`807d5o
o`000goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`0aOol2
01lROol2O1m8Ool00`?POomoo`0QOol201m3Ool00005Ool007ooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`03001oogoo03=oo`0301moogoo025oo`03O1moogoo04=oo`83h2=oo`0301mo
ogoo04=oo`000Woo0P0017oo0P0017oo0P001Goo00<007ooOol0=7oo0P0O8Woo00=l7gooOol0@7oo
0P?P8goo0P0OAWoo000EOol00`00Oomoo`0fOol00`0OOomoo`0POol2O1lnOol20n0TOol00`0OOomo
o`16Ool001Eoo`03001oogoo03Moo`0301moogoo025oo`03O1moogoo03Uoo`83h2Aoo`807dUoo`00
5Goo0P00>Goo0P0O8Woo0W`O=goo0P?P97oo0P0OBgoo000EOol00`00Oomoo`0jOol00`0OOomoo`0Q
Ool00g`OOomoo`0cOol00`?POomoo`0ROol201m=Ool001Eoo`03001oogoo03]oo`0301moogoo025o
o`9l7c5oo`83h2=oo`807dmoo`005Goo00<007ooOol0?7oo0P0O8goo00=l7gooOol0;7oo0P?P8goo
0P0ODGoo000EOol00`00Oomoo`0nOol00`0OOomoo`0QOol2O1lZOol20n0TOol00`0OOomoo`1AOol0
01Eoo`80041oo`807b=oo`9l7bIoo`83h2Aoo`807eAoo`005Goo00<007ooOol0@Goo00<07gooOol0
8Woo00=l7gooOol08Goo0P?P97oo0P0OEWoo000EOol00`00Oomoo`12Ool201lSOol2O1lPOol00`?P
Oomoo`0SOol00`0OOomoo`1FOol001Eoo`03001oogoo04Aoo`807b=oo`03O1moogoo01]oo`83h2Ao
o`807eUoo`005Goo00<007ooOol0AWoo00<07gooOol08Goo0W`O6Goo0P?P97oo0P0OFgoo000EOol2
0018Ool201lSOol2O1lEOol20n0UOol00`0OOomoo`1KOol001Eoo`03001oogoo04Uoo`0301moogoo
029oo`9l7a5oo`83h2Eoo`807eioo`005Goo00<007ooOol0BWoo0P0O97oo0W`O3Goo0P?P9Goo0P0O
H7oo000EOol00`00Oomoo`1<Ool201lTOol2O1l:Ool00`?POomoo`0SOol201mROol001Eoo`03001o
ogoo04ioo`807bAoo`03O1moogoo00Eoo`83h2Aoo`807fAoo`005Goo00<007ooOol0D7oo0P0O8goo
0W`O0goo0P?P97oo0P0OIWoo000EOol2001COol201lSOol00g`OOol3h00TOol201mXOol001Eoo`03
001oogoo05Aoo`0301moogoo021oo`83h2=oo`807fYoo`005Goo00<007ooOol0EGoo0P0O7Woo0P?P
0Woo0W`O7goo0P0OK7oo0002Ool20004Ool20004Ool20005Ool00`00Oomoo`1GOol201lKOol00`?P
Oomoo`04Ool00g`OOomoo`0JOol201m^Ool00005Ool007ooOol00002Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`03001oogoo05Uoo`807aMoo`83h0Qoo`9l7aQoo`807g1oo`000goo00D007ooOomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`02Ool3001KOol201lCOol20n0<Ool00g`OOomoo`0B
Ool301mbOol000Aoo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol0
GGoo0P0O3goo0P?P3goo0W`O47oo0P0OMGoo00001Goo001oogoo00000Woo00@007ooOol0009oo`04
001oogoo0004Ool00`00Oomoo`1OOol201l;Ool20n0COol2O1l<Ool201mgOol0009oo`8000Aoo`80
00Aoo`8000Eoo`03001oogoo065oo`807`Moo`83h1Moo`9l7`Qoo`807gUoo`005Goo00<007ooOol0
Hgoo0P0O17oo00<3h7ooOol06Goo0W`O17oo0P0ONgoo000EOol2001VOol201l20n0NOol017`O01l0
7`0OOGoo000EOol00`00Oomoo`1UOol20n0201lMOol201l00gooO1moo`1mOol001Eoo`03001oogoo
06=oo`83h0Aoo`807aUoo`807`Aoo`9l7gaoo`005Goo00<007ooOol0HGoo0P?P27oo0P0O5Goo0P0O
27oo00=l7gooOol0NGoo000EOol00`00Oomoo`1OOol20n0<Ool201lAOol201l;Ool2O1miOol001Eo
o`03001oogoo05ioo`030n1oogoo00ioo`807`aoo`<07`moo`9l7gMoo`005Goo0P00GGoo0P?P4goo
0P0O27oo0P0O57oo00=l7gooOol0M7oo000EOol00`00Oomoo`1JOol20n0GOol301l2Ool301lGOol2
O1mdOol001Eoo`03001oogoo05Uoo`030n1oogoo01Yoo`807aaoo`03O1moogoo075oo`005Goo00<0
07ooOol0Egoo0P?P6Woo0`0O0Woo0`0O6Woo0W`OLGoo000EOol00`00Oomoo`1EOol20n0IOol301l8
Ool201lJOol00g`OOomoo`1^Ool001Eoo`8005Eoo`030n1oogoo01Moo`807`eoo`<07aQoo`9l7fio
o`005Goo00<007ooOol0DWoo0P?P5goo0`0O4Woo0P0O67oo0W`OK7oo000EOol00`00Oomoo`1@Ool2
0n0FOol301lGOol201lHOol00g`OOomoo`1YOol001Eoo`03001oogoo04ioo`83h1Eoo`<07aaoo`80
7aMoo`9l7fUoo`005Goo00<007ooOol0C7oo0P?P5Goo0P0O8Goo0P0O5goo00=l7gooOol0IWoo000E
Ool2001;Ool20n0DOol301lUOol301lEOol2O1mVOol001Eoo`03001oogoo04Uoo`030n1oogoo015o
o`<07b]oo`807aEoo`03O1moogoo06=oo`005Goo00<007ooOol0Agoo0P?P4Woo0P0O<7oo0P0O57oo
0W`OHgoo000EOol00`00Oomoo`15Ool20n0AOol301ldOol201lDOol2O1mQOol000=oo`<0009oo`80
00Aoo`8000Eoo`03001oogoo04=oo`83h15oo`807cUoo`807aAoo`03O1moogoo05ioo`0017oo00@0
07ooOol0009oo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`11Ool20n0@Ool301lmOol3
01lBOol2O1mNOol00003Ool0000000<00005Ool007ooOol00002Ool01000Oomoo`0017oo0`00?goo
0P?P3goo0`0O@goo0P0O4Woo00=l7gooOol0Fgoo00001Goo001oogoo00000Woo00@007ooOol0009o
o`04001oogoo0004Ool00`00Oomoo`0nOol00`?POomoo`0=Ool201m8Ool201lAOol2O1mKOol0009o
o`03001oo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0?7oo0P?P3Goo0`0O
C7oo0P0O4Goo0W`OFGoo0003Ool20003Ool20004Ool20005Ool00`00Oomoo`0jOol20n0<Ool301mA
Ool201lAOol00g`OOomoo`1FOol001Eoo`03001oogoo03Qoo`83h0aoo`807eIoo`<07`moo`9l7eIo
o`005Goo0P00=goo0P?P37oo0P0OFgoo0`0O3Woo0W`OE7oo000EOol00`00Oomoo`0dOol20n0<Ool2
01mPOol201l>Ool00g`OOomoo`1AOol001Eoo`03001oogoo03=oo`030n1oogoo00Yoo`807fAoo`<0
7`aoo`9l7e5oo`005Goo00<007ooOol0<Goo0P?P2Woo0`0OJGoo0P0O37oo00=l7gooOol0CWoo000E
Ool00`00Oomoo`0`Ool00`?POomoo`07Ool301m^Ool201l;Ool2O1m>Ool001Eoo`8002moo`83h0Qo
o`807g=oo`807`]oo`9l7daoo`005Goo00<007ooOol0;7oo0P?P1goo0`0OMgoo0P0O2goo00=l7goo
Ool0BGoo000EOol00`00Oomoo`0[Ool00`?POomoo`04Ool301mlOol201l:Ool2O1m9Ool001Eoo`03
001oogoo02Uoo`83h0Eoo`807h5oo`<07`Uoo`03O1moogoo04Ioo`005Goo00<007ooOol0:7oo00<3
h7ooOol00goo0P0OQWoo0P0O27oo0W`OAWoo000EOol00`00Oomoo`0VOol20n04Ool201n:Ool201l8
Ool2O1m4Ool001Eoo`8002Eoo`83h0Aoo`807hioo`807`Qoo`9l7d9oo`005Goo00<007ooOol08Woo
0P?P0goo0`0OTWoo0P0O27oo0W`O@7oo000EOol00`00Oomoo`0POol20n03Ool201nGOol301l7Ool2
O1lnOol001Eoo`03001oogoo01ioo`83h09oo`<07iaoo`807`Moo`03O1moogoo03]oo`005Goo00<0
07ooOol077oo0P?P0Woo0P0OXGoo0P0O1Woo0W`O>goo000EOol2000KOol20n0017oo01l07`0OYGoo
0P0O1Woo00=l7gooOol0>7oo000EOol00`00Oomoo`0HOol20n000goo01l07`2ZOol201l5Ool2O1lh
Ool001Eoo`03001oogoo01Ioo`83h003Ool07`0O0:ioo`807`Eoo`9l7cIoo`000Woo0P0017oo0P00
17oo0P001Goo00<007ooOol057oo0P?P00=oo`0O01l0/Woo0P0O1Goo00=l7gooOol0<goo00001Goo
001oogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`0COol010?POol07`0O
]Woo0P0O17oo0W`O<goo0004Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo009oo`<0
015oo`83h0807kYoo`807`Aoo`03O1moogoo031oo`000Woo0P000goo00@007ooOol0009oo`04001o
ogoo0004Ool00`00Oomoo`0@Ool00`?P01l07`2nOol201l3Ool2O1l`Ool0009oo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol03Woo00<3h00O01l0`Woo0P0O0goo00=l
7gooOol0;Goo0002Ool30003Ool20004Ool20005Ool00`00Oomoo`0<Ool00`?P01l07`36Ool201l2
Ool2O1l]Ool001Eoo`03001oogoo00]oo`807lYoo`807`9oo`9l7b]oo`005Goo00<007ooOol02Goo
0P0OcWoo0P0O0Woo00=l7gooOol0:7oo000EOol20009Ool00`0OOomoo`3@Ool201l00gooO1ml7`0X
Ool001Eoo`03001oogoo00Ioo`807mEoo`807`03Ooml7goo02Ioo`005Goo00<007ooOol017oo0P0O
fGoo0P0O0W`O9Goo000EOol00`00Oomoo`02Ool201oMOol201l00g`OOomoo`0ROol001Eoo`03001o
ogoo00807n5oo`807b=oo`005Goo00<0000O01l0iGoo00<07g`OOol087oo000EOol00`0OOomoo`3V
Ool201lPOol001Eoo`03001oogoo0>Qoo`807aioo`005Goo00<007ooOol0jWoo00<07gooOol06goo
000EOol00`00Oomoo`3[Ool201lKOol001Eoo`800>ioo`807aUoo`005Goo00<007ooOol0kgoo00<0
7g`OOol05Woo000EOol00`00Oomoo`3`Ool201l00g`OOomoo`0COol001Eoo`03001oogoo0?9oo`80
7`03O1moogoo015oo`005Goo00<007ooOol0m7oo0P0O00=l7gooOol03goo000EOol00`00Oomoo`3f
Ool00`0OO1ml7`0?Ool001Eoo`800?Qoo`807`03O1moogoo00aoo`005Goo00<007ooOol0nGoo0P0O
3Goo000EOol00`00Oomoo`3kOol00`0OO1moo`0:Ool00004Ool000000004Ool20004Ool20005Ool0
0`00Oomoo`3lOol201l:Ool00005Ool007ooOol00002Ool01000Oomoo`000Woo00@007ooOol000Ao
o`03001oogoo0?ioo`807`Qoo`0000Eoo`00Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`00
17oo0`00ogoo0Goo00<07gooOol01Goo000017oo000000000goo00@007ooOol0009oo`04001oogoo
0004Ool00`00Oomoo`3oOol9Ool0009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
17oo00<007ooOol0ogoo2Goo0002Ool30003Ool20004Ool20005Ool00`00Oomoo`3oOol9Ool001Eo
o`03001oogoo0?moo`Uoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0841707, -46.4542, \
0.00386956, 3.74892}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot of activity coefficients", "Subsubtitle",
  Background->RGBColor[0.929702, 0.996109, 0.566415]],

Cell[CellGroupData[{

Cell[BoxData[
    \(plt8 = 
      Plot[{G3, G4}, {x, 0, 1}, 
        PlotStyle \[Rule] {RGBColor[0, 0, 1], RGBColor[0, 0, 1]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.420314 0.435029 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .10172 -18 -4.5 ]
[.01131 .10172 0 4.5 ]
[.01131 .18873 -18 -4.5 ]
[.01131 .18873 0 4.5 ]
[.01131 .27573 -18 -4.5 ]
[.01131 .27573 0 4.5 ]
[.01131 .36274 -18 -4.5 ]
[.01131 .36274 0 4.5 ]
[.01131 .44974 -6 -4.5 ]
[.01131 .44974 0 4.5 ]
[.01131 .53675 -18 -4.5 ]
[.01131 .53675 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10172 m
.03006 .10172 L
s
[(1.2)] .01131 .10172 1 0 Mshowa
.02381 .18873 m
.03006 .18873 L
s
[(1.4)] .01131 .18873 1 0 Mshowa
.02381 .27573 m
.03006 .27573 L
s
[(1.6)] .01131 .27573 1 0 Mshowa
.02381 .36274 m
.03006 .36274 L
s
[(1.8)] .01131 .36274 1 0 Mshowa
.02381 .44974 m
.03006 .44974 L
s
[(2)] .01131 .44974 1 0 Mshowa
.02381 .53675 m
.03006 .53675 L
s
[(2.2)] .01131 .53675 1 0 Mshowa
.125 Mabswid
.02381 .03647 m
.02756 .03647 L
s
.02381 .05822 m
.02756 .05822 L
s
.02381 .07997 m
.02756 .07997 L
s
.02381 .12347 m
.02756 .12347 L
s
.02381 .14522 m
.02756 .14522 L
s
.02381 .16698 m
.02756 .16698 L
s
.02381 .21048 m
.02756 .21048 L
s
.02381 .23223 m
.02756 .23223 L
s
.02381 .25398 m
.02756 .25398 L
s
.02381 .29748 m
.02756 .29748 L
s
.02381 .31924 m
.02756 .31924 L
s
.02381 .34099 m
.02756 .34099 L
s
.02381 .38449 m
.02756 .38449 L
s
.02381 .40624 m
.02756 .40624 L
s
.02381 .42799 m
.02756 .42799 L
s
.02381 .4715 m
.02756 .4715 L
s
.02381 .49325 m
.02756 .49325 L
s
.02381 .515 m
.02756 .515 L
s
.02381 .5585 m
.02756 .5585 L
s
.02381 .58025 m
.02756 .58025 L
s
.02381 .602 m
.02756 .602 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .60332 m
.06244 .52832 L
.10458 .45692 L
.14415 .39835 L
.18221 .34873 L
.22272 .30221 L
.26171 .26277 L
.30316 .22587 L
.34309 .19463 L
.3815 .16808 L
.42237 .14319 L
.46172 .12214 L
.49955 .10431 L
.53984 .08767 L
.57861 .07371 L
.61984 .06088 L
.65954 .05031 L
.69774 .04165 L
.73838 .03394 L
.77751 .02787 L
.81909 .02278 L
.83996 .02072 L
.85916 .01911 L
.8791 .01772 L
.89771 .01666 L
.91654 .01583 L
.92715 .01547 L
.9372 .01519 L
.94695 .01498 L
.95246 .01489 L
.95755 .01482 L
.96183 .01478 L
.96429 .01476 L
.96655 .01474 L
.96892 .01473 L
.97014 .01473 L
.97148 .01472 L
.97265 .01472 L
.97373 .01472 L
.97488 .01472 L
.97611 .01472 L
.97619 .01472 L
s
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01475 L
.03527 .01478 L
.0379 .01481 L
.04262 .01488 L
.04749 .01497 L
.05205 .01508 L
.06244 .0154 L
.07305 .01582 L
.08274 .0163 L
.10458 .01768 L
.12357 .01923 L
.14429 .02128 L
.18493 .02641 L
.22406 .03274 L
.26565 .04097 L
.30571 .0504 L
.34426 .06089 L
.38527 .07363 L
.42475 .08749 L
.46273 .10236 L
.50315 .11992 L
.54206 .13858 L
.58342 .16043 L
.62326 .18354 L
.66159 .20779 L
.70238 .2359 L
.74164 .26534 L
.77939 .29598 L
.8196 .33128 L
.85828 .36801 L
.89942 .41023 L
.93905 .45416 L
.97619 .49844 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0012Ool2
0004Ool20003Ool4000UOol20004Ool20005Ool3000SOol20004Ool20003Ool3000VOol20004Ool2
0004Ool2000[Ool50005Ool0045oo`04001oogoo0008Ool00`00Oomoo`0UOol01000Oomoo`002goo
00<007ooOol08Goo00@007ooOol000Qoo`04001oogoo000TOol01000Oomoo`0027oo00@007ooOol0
02aoo`03001oogoo00Eoo`00@Goo00@007ooOol000Uoo`03001oogoo02Aoo`04001oogoo0008Ool5
000ROol01000Oomoo`0027oo00@007ooOol002Aoo`04001oogoo0008Ool01000Oomoo`00;7oo00<0
07ooOol01Goo0011Ool01000Oomoo`002Woo00<007ooOol08goo00@007ooOol000Qoo`04001oogoo
000SOol01000Oomoo`0027oo0`009Goo00@007ooOol000Uoo`8002eoo`03001oogoo00Eoo`00@Goo
00@007ooOol000Qoo`04001oogoo000TOol01000Oomoo`002Goo00<007oo00008goo00@007ooOol0
00Uoo`03001oogoo02Aoo`04001oogoo0008Ool01000Oomoo`00;7oo00<007ooOol01Goo0012Ool2
000:Ool2000VOol2000;Ool2000TOol2000:Ool3000UOol2000:Ool2000/Ool20007Ool00?moob5o
o`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uo
o`005Goo00<007ooOol0ogoo2Goo000>Ool7000?01oR000C01l7000001Eoo`03001oogoo00Yoo`03
001oo`0O00h07`Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yo
o`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yo
o`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yo
o`03001oogoo009ooa007`Eoo`03001oogoo00Yoo`03001oogoo00Eoo`005Goo00<007ooOol06goo
2@0O3Goo00<007ooOol0<Goo00<007ooOol0<7oo00<007ooOol0<Goo00<007ooOol017oo2`0O8Woo
00<007ooOol01Goo000EOol00`00Oomoo`0TOol801nQOol601leOol001Eoo`03001oogoo02aoo`D0
7iAoo`P07c]oo`005Goo00<007ooOol0<Goo1@0OQgoo200O@goo000EOol2000gOol601mkOol601m;
Ool001Eoo`03001oogoo03aoo`D07g9oo`@07e5oo`005Goo00<007ooOol0@Goo100OJgoo0`0OEGoo
000EOol00`00Oomoo`15Ool401mSOol401mHOol001Eoo`03001oogoo04Uoo`<07eeoo`<07eaoo`00
5Goo00<007ooOol0C7oo0`0OEWoo100OGgoo000EOol2001@Ool401m>Ool401mSOol001Eoo`03001o
ogoo05=oo`<07dQoo`<07fMoo`005Goo00<007ooOol0EWoo100O@7oo100OJWoo000EOol00`00Oomo
o`1JOol401lhOol401m^Ool001Eoo`03001oogoo05ioo`<07c9oo`<07g9oo`005Goo00<007ooOol0
HGoo0`0O;7oo0`0OMGoo000EOol2001UOol201lXOol201mhOol001Eoo`03001oogoo06Ioo`<07b9o
o`<07gYoo`005Goo00<007ooOol0JGoo0`0O77oo0`0OOGoo000EOol00`00Oomoo`1/Ool201lHOol2
01n0Ool00003Ool0000000<0009oo`8000=oo`@000Aoo`03001oogoo06ioo`<07a=oo`807h9oo`00
0goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol0LGoo0P0O3goo0P0OQ7oo0003Ool00`00
Oomoo`08Ool00`00Oomoo`04Ool3001cOol301l:Ool201n6Ool000=oo`03001oogoo00Uoo`03001o
ogoo00=oo`03001oogoo07Ioo`807`Eoo`<07hQoo`000goo00<007ooOol01goo00@007ooOol000Ao
o`03001oogoo07Qoo`807`03Ool07`0O08]oo`000Woo0P002Woo0P001Goo00<007ooOol0N7oo100O
S7oo000EOol00`00Oomoo`1fOol201l4Ool201n:Ool001Eoo`03001oogoo07Aoo`807`Qoo`<07hMo
o`005Goo0P00Lgoo0P0O3Goo0P0OQGoo000EOol00`00Oomoo`1`Ool201lAOol201n3Ool001Eoo`03
001oogoo06ioo`807aEoo`807h5oo`005Goo00<007ooOol0K7oo0P0O6Goo0P0OOgoo000EOol00`00
Oomoo`1ZOol201lMOol201mmOol001Eoo`03001oogoo06Uoo`0301moogoo01moo`807g]oo`005Goo
0P00J7oo0P0O97oo0P0ONGoo000EOol00`00Oomoo`1VOol00`0OOomoo`0VOol201mgOol001Eoo`03
001oogoo06Aoo`807b]oo`807gEoo`005Goo00<007ooOol0HWoo0P0O;goo0P0OLgoo000EOol00`00
Oomoo`1QOol00`0OOomoo`0aOol00`0OOomoo`1`Ool001Eoo`03001oogoo05moo`807cEoo`807g1o
o`005Goo0P00Ggoo00<07gooOol0=goo0P0OKWoo000EOol00`00Oomoo`1LOol201llOol201m/Ool0
01Eoo`03001oogoo05]oo`0301moogoo03ioo`807fYoo`005Goo00<007ooOol0FWoo00<07gooOol0
@Goo0P0OJ7oo00000goo000000030002Ool20005Ool30003Ool00`00Oomoo`1HOol201m6Ool00`0O
Oomoo`1UOol000=oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo05Moo`0301moogoo04Mo
o`807fEoo`000goo00<007ooOol01goo1@000goo0`00EGoo0P0OC7oo00<07gooOol0HWoo0003Ool0
0`00Oomoo`07Ool01000Oomoo`0017oo00<007ooOol0E7oo00<07gooOol0CGoo00<07gooOol0HGoo
0003Ool00`00Oomoo`08Ool00`00Ool00004Ool00`00Oomoo`1COol00`0OOomoo`1?Ool201mQOol0
009oo`8000]oo`8000Aoo`03001oogoo055oo`807eAoo`0301moogoo05ioo`005Goo00<007ooOol0
D7oo00<07gooOol0EGoo0P0OGWoo000EOol2001@Ool00`0OOomoo`1HOol00`0OOomoo`1KOol001Eo
o`03001oogoo04ioo`0301moogoo05Yoo`807e]oo`005Goo00<007ooOol0CGoo00<07gooOol0GGoo
0P0OFGoo000EOol00`00Oomoo`1;Ool201mROol00`0OOomoo`1FOol001Eoo`03001oogoo04Yoo`03
01moogoo06=oo`807eIoo`005Goo00<007ooOol0BGoo00<07gooOol0IWoo0P0OE7oo000EOol20019
Ool00`0OOomoo`1YOol201mBOol001Eoo`03001oogoo04Moo`0301moogoo06aoo`0301moogoo04mo
o`005Goo00<007ooOol0AWoo00<07gooOol0KWoo00<07gooOol0CWoo000EOol00`00Oomoo`15Ool0
0`0OOomoo`1`Ool201m>Ool001Eoo`03001oogoo04=oo`807gEoo`0301moogoo04]oo`005Goo00<0
07ooOol0@Woo00<07gooOol0MWoo00<07gooOol0BWoo000EOol20012Ool00`0OOomoo`1hOol00`0O
Oomoo`19Ool001Eoo`03001oogoo041oo`0301moogoo07Yoo`807dUoo`005Goo00<007ooOol0?goo
00<07gooOol0OGoo00<07gooOol0AWoo000EOol00`00Oomoo`0nOol00`0OOomoo`1oOol00`0OOomo
o`15Ool00003Ool0000000<0009oo`8000=oo`<000Eoo`03001oogoo03eoo`0301moogoo085oo`03
01moogoo04Aoo`000goo00<007ooOol01goo00@007ooOol000Aoo`03001oogoo03aoo`0301moogoo
08=oo`0301moogoo04=oo`000goo00<007ooOol01goo00@007ooOol000Aoo`<003]oo`0301moogoo
08Eoo`0301moogoo049oo`000goo00<007ooOol01goo0`001Goo00<007ooOol0>Woo00<07gooOol0
Qgoo00<07gooOol0@Goo0003Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`0hOol201n;
Ool201m1Ool0009oo`8000Yoo`<000Aoo`03001oogoo03Moo`0301moogoo08eoo`0301moogoo03io
o`005Goo00<007ooOol0=Woo00<07gooOol0Sgoo00<07gooOol0?Goo000EOol00`00Oomoo`0eOol0
0`0OOomoo`2AOol00`0OOomoo`0lOol001Eoo`8003Eoo`0301moogoo09=oo`0301moogoo03]oo`00
5Goo00<007ooOol0<goo00<07gooOol0UGoo00<07gooOol0>Woo000EOol00`00Oomoo`0bOol00`0O
Oomoo`2GOol201ljOol001Eoo`03001oogoo035oo`0301moogoo09Yoo`0301moogoo03Moo`005Goo
00<007ooOol0<7oo00<07gooOol0W7oo00<07gooOol0=Woo000EOol00`00Oomoo`0`Ool00`0OOomo
o`2MOol00`0OOomoo`0eOol001Eoo`80031oo`0301moogoo09moo`0301moogoo03Aoo`005Goo00<0
07ooOol0;Woo00<07gooOol0XGoo0P0O=7oo000EOol00`00Oomoo`0]Ool00`0OOomoo`2TOol00`0O
Oomoo`0aOol001Eoo`03001oogoo02aoo`0301moogoo0:Ioo`0301moogoo031oo`005Goo00<007oo
Ool0:goo00<07gooOol0Z7oo00<07gooOol0;goo000EOol00`00Oomoo`0[Ool00`0OOomoo`2YOol0
0`0OOomoo`0^Ool001Eoo`8002]oo`0301moogoo0:]oo`0301moogoo02eoo`005Goo00<007ooOol0
:Goo00<07gooOol0[Goo00<07gooOol0;7oo000EOol00`00Oomoo`0XOol00`0OOomoo`2_Ool201l/
Ool001Eoo`03001oogoo02Moo`0301moogoo0;9oo`0301moogoo02Uoo`0000=oo`0000000`000Woo
0P0017oo0P001Goo00<007ooOol09goo00<07gooOol0/goo00<07gooOol0:7oo0003Ool00`00Oomo
o`07Ool01000Oomoo`0017oo00<007ooOol09Woo00<07gooOol0]Goo00<07gooOol09goo0003Ool0
0`00Oomoo`07Ool01000Oomoo`0017oo0`009Goo00<07gooOol0]goo00<07gooOol09Woo0003Ool0
0`00Oomoo`08Ool20005Ool00`00Oomoo`0TOol00`0OOomoo`2iOol00`0OOomoo`0UOol000=oo`03
001oogoo00Moo`04001oogoo0004Ool00`00Oomoo`0TOol00`0OOomoo`2jOol00`0OOomoo`0TOol0
009oo`8000Yoo`8000Eoo`03001oogoo02=oo`0301moogoo0;aoo`0301moogoo02=oo`005Goo00<0
07ooOol08Woo00<07gooOol0_Woo00<07gooOol08Woo000EOol00`00Oomoo`0ROol00`0OOomoo`2o
Ool00`0OOomoo`0QOol001Eoo`80029oo`0301moogoo0<5oo`0301moogoo021oo`005Goo00<007oo
Ool087oo00<07gooOol0`goo00<07gooOol07goo000EOol00`00Oomoo`0OOol00`0OOomoo`34Ool0
0`0OOomoo`0OOol001Eoo`03001oogoo01moo`0301moogoo0<Eoo`0301moogoo01ioo`005Goo00<0
07ooOol07Woo00<07gooOol0agoo00<07gooOol07Goo000EOol00`00Oomoo`0MOol00`0OOomoo`39
Ool00`0OOomoo`0LOol001Eoo`8001ioo`0301moogoo0<Yoo`0301moogoo01]oo`005Goo00<007oo
Ool077oo00<07gooOol0c7oo00<07gooOol06Woo000EOol00`00Oomoo`0KOol00`0OOomoo`3>Ool0
0`0OOomoo`0IOol001Eoo`03001oogoo01Yoo`0301moogoo0=1oo`0301moogoo01Qoo`005Goo00<0
07ooOol06Woo00<07gooOol0dGoo00<07gooOol05goo000EOol00`00Oomoo`0IOol00`0OOomoo`3C
Ool00`0OOomoo`0FOol001Eoo`8001Uoo`0301moogoo0=Eoo`0301moogoo01Eoo`005Goo00<007oo
Ool05goo00<07gooOol0egoo00<07gooOol057oo000EOol00`00Oomoo`0GOol00`0OOomoo`3GOol0
0`0OOomoo`0DOol001Eoo`03001oogoo01Ioo`0301moogoo0=Uoo`0301moogoo01=oo`003Goo1000
17oo00<007ooOol05Goo00<07gooOol0fgoo00<07gooOol04Woo000=Ool00`00Oomoo`05Ool00`00
Oomoo`0DOol00`0OOomoo`3MOol00`0OOomoo`0AOol000ioo`03001oogoo00Aoo`<001Aoo`0301mo
ogoo0=ioo`0301moogoo011oo`003goo00<007ooOol00goo00<007ooOol04goo00<07gooOol0h7oo
00<07gooOol03goo000=Ool01000Oomoo`0017oo00<007ooOol04Woo00<07gooOol0hWoo00<07goo
Ool03Woo000>Ool20005Ool00`00Oomoo`0BOol00`0OOomoo`3SOol00`0OOomoo`0=Ool001Eoo`03
001oogoo015oo`0301moogoo0>Eoo`0301moogoo00aoo`005Goo0P004Woo00<07gooOol0iGoo00<0
7gooOol037oo000EOol00`00Oomoo`0@Ool00`0OOomoo`3WOol00`0OOomoo`0;Ool001Eoo`03001o
ogoo00moo`0301moogoo0>Uoo`0301moogoo00Yoo`005Goo00<007ooOol03goo00<07gooOol0jWoo
00<07gooOol02Goo000EOol00`00Oomoo`0>Ool00`0OOomoo`3/Ool00`0OOomoo`08Ool001Eoo`03
001oogoo00ioo`0301moogoo0>eoo`0301moogoo00Moo`005Goo0P003Woo00<07gooOol0kWoo00<0
7gooOol01goo000EOol00`00Oomoo`0<Ool00`0OOomoo`3`Ool00`0OOomoo`06Ool001Eoo`03001o
ogoo00aoo`0301moogoo0?5oo`0301moogoo00Eoo`005Goo00<007ooOol02goo00<07gooOol0nWoo
000EOol00`00Oomoo`0;Ool00`0OOomoo`3jOol001Eoo`03001oogoo00Yoo`0301moogoo0?]oo`00
5Goo0P002Woo00<07gooOol0o7oo000EOol00`00Oomoo`09Ool00`0OOomoo`3lOol001Eoo`03001o
ogoo00Qoo`0301moogoo0?eoo`005Goo00<007ooOol027oo00<07gooOol0oGoo00000goo00000002
0003Ool20003Ool40004Ool00`00Oomoo`07Ool00`0OOomoo`3nOol00003Ool007oo00Yoo`03001o
ogoo00Eoo`03001oogoo00Ioo`0301moogoo0?moo`000Woo00<007ooOol02Goo00<007ooOol017oo
0`001Woo00<07gooOol0ogoo0003Ool00`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomoo`05Ool0
0`0OOomoo`3oOol1Ool00005Ool007ooOol00008Ool01000Oomoo`0017oo00<007ooOol01Goo00<0
7gooOol0ogoo0Goo0002Ool2000:Ool20005Ool00`00Oomoo`04Ool00`0OOomoo`3oOol2Ool001Eo
o`03001oogoo00Aoo`0301moogoo0?moo`9oo`005Goo00<007ooOol00goo00<07gooOol0ogoo0goo
000EOol20004Ool00`0OOomoo`3oOol3Ool001Eoo`03001oogoo009oo`0301moogoo0?moo`Aoo`00
5Goo00<007ooOol00Woo00<07gooOol0ogoo17oo000EOol01@00Oomoogoo01l0ogoo1goo000EOol0
1@00Oomoogoo01l0ogoo1goo000EOol01000Oomoo`0Oogoo27oo000EOol200000goo01moo`3oOol7
Ool001Eoo`03001oo`0O0?moo`Uoo`005Goo00<007oo01l0ogoo2Goo000EOol00`0001moo`3oOol9
Ool001Eoo`0300007goo0?moo`Uoo`005Goo00<07gooOol0ogoo2Goo000EOol00`0O001oo`3oOol9
Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9
Ool001Eoo`03001oogoo0?moo`Uoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0825959, 0.893586, \
0.00385924, 0.00844878}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["P versus x and y", "Subsubtitle",
  Background->RGBColor[0.929702, 0.996109, 0.566415]],

Cell[BoxData[
    \(P[x_] := G3\ x\ PS1 + G4\ \((1 - x)\)\ PS2\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(plt10 = 
      Plot[P[x], {x, 0, 1}, PlotStyle \[Rule] RGBColor[1, 0, 1]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -3.20351 0.00545843 [
[.21429 .05905 -9 -9 ]
[.21429 .05905 9 0 ]
[.40476 .05905 -9 -9 ]
[.40476 .05905 9 0 ]
[.59524 .05905 -9 -9 ]
[.59524 .05905 9 0 ]
[.78571 .05905 -9 -9 ]
[.78571 .05905 9 0 ]
[.97619 .05905 -3 -9 ]
[.97619 .05905 3 0 ]
[.01131 .18071 -18 -4.5 ]
[.01131 .18071 0 4.5 ]
[.01131 .28988 -18 -4.5 ]
[.01131 .28988 0 4.5 ]
[.01131 .39905 -18 -4.5 ]
[.01131 .39905 0 4.5 ]
[.01131 .50822 -18 -4.5 ]
[.01131 .50822 0 4.5 ]
[.01131 .61739 -18 -4.5 ]
[.01131 .61739 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .07155 m
.21429 .0778 L
s
[(0.2)] .21429 .05905 0 1 Mshowa
.40476 .07155 m
.40476 .0778 L
s
[(0.4)] .40476 .05905 0 1 Mshowa
.59524 .07155 m
.59524 .0778 L
s
[(0.6)] .59524 .05905 0 1 Mshowa
.78571 .07155 m
.78571 .0778 L
s
[(0.8)] .78571 .05905 0 1 Mshowa
.97619 .07155 m
.97619 .0778 L
s
[(1)] .97619 .05905 0 1 Mshowa
.125 Mabswid
.07143 .07155 m
.07143 .0753 L
s
.11905 .07155 m
.11905 .0753 L
s
.16667 .07155 m
.16667 .0753 L
s
.2619 .07155 m
.2619 .0753 L
s
.30952 .07155 m
.30952 .0753 L
s
.35714 .07155 m
.35714 .0753 L
s
.45238 .07155 m
.45238 .0753 L
s
.5 .07155 m
.5 .0753 L
s
.54762 .07155 m
.54762 .0753 L
s
.64286 .07155 m
.64286 .0753 L
s
.69048 .07155 m
.69048 .0753 L
s
.7381 .07155 m
.7381 .0753 L
s
.83333 .07155 m
.83333 .0753 L
s
.88095 .07155 m
.88095 .0753 L
s
.92857 .07155 m
.92857 .0753 L
s
.25 Mabswid
0 .07155 m
1 .07155 L
s
.02381 .18071 m
.03006 .18071 L
s
[(620)] .01131 .18071 1 0 Mshowa
.02381 .28988 m
.03006 .28988 L
s
[(640)] .01131 .28988 1 0 Mshowa
.02381 .39905 m
.03006 .39905 L
s
[(660)] .01131 .39905 1 0 Mshowa
.02381 .50822 m
.03006 .50822 L
s
[(680)] .01131 .50822 1 0 Mshowa
.02381 .61739 m
.03006 .61739 L
s
[(700)] .01131 .61739 1 0 Mshowa
.125 Mabswid
.02381 .09884 m
.02756 .09884 L
s
.02381 .12613 m
.02756 .12613 L
s
.02381 .15342 m
.02756 .15342 L
s
.02381 .20801 m
.02756 .20801 L
s
.02381 .2353 m
.02756 .2353 L
s
.02381 .26259 m
.02756 .26259 L
s
.02381 .31718 m
.02756 .31718 L
s
.02381 .34447 m
.02756 .34447 L
s
.02381 .37176 m
.02756 .37176 L
s
.02381 .42634 m
.02756 .42634 L
s
.02381 .45364 m
.02756 .45364 L
s
.02381 .48093 m
.02756 .48093 L
s
.02381 .53551 m
.02756 .53551 L
s
.02381 .5628 m
.02756 .5628 L
s
.02381 .5901 m
.02756 .5901 L
s
.02381 .04425 m
.02756 .04425 L
s
.02381 .01696 m
.02756 .01696 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
.0817 0 m
.10458 .08301 L
.14415 .19873 L
.18221 .28942 L
.22272 .36784 L
.26171 .42884 L
.30316 .48082 L
.34309 .5204 L
.3815 .55017 L
.40095 .56247 L
.42237 .57401 L
.44292 .58321 L
.46172 .59007 L
.48113 .59563 L
.49195 .59808 L
.502 .59993 L
.51119 .60127 L
.52099 .60233 L
.52659 .60277 L
.52933 .60293 L
.53186 .60306 L
.53411 .60315 L
.53659 .60323 L
.53788 .60326 L
.53908 .60329 L
.54035 .6033 L
.54106 .60331 L
.54171 .60331 L
.54289 .60332 L
.544 .60332 L
.54521 .60331 L
.54652 .6033 L
.54782 .60328 L
.54918 .60325 L
.55163 .60317 L
.5539 .60309 L
.55601 .60299 L
.5608 .60269 L
.56606 .60226 L
.57084 .60176 L
.58156 .60031 L
.59154 .59853 L
.60074 .59651 L
.62154 .59057 L
.6403 .58353 L
.66094 .57387 L
.70128 .54877 L
.74011 .51609 L
.78138 .47103 L
.82114 .41625 L
Mistroke
.85939 .35162 L
.90009 .26826 L
.93927 .17191 L
.97619 .06481 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol03Goo00=l7gooOol0n7oo000EOol00`00
Oomoo`0>Ool00g`OOomoo`3gOol001Eoo`03001oogoo00ioo`03O1moogoo0?Moo`005Goo0P003goo
00=l7gooOol0mgoo000EOol00`00Oomoo`0>Ool00g`OOomoo`3gOol001Eoo`03001oogoo00moo`03
O1moogoo0?Ioo`005Goo00<007ooOol03goo00=l7gooOol0mWoo000EOol00`00Oomoo`0?Ool00g`O
Oomoo`0HOol20004Ool20003Ool4000UOol20004Ool20005Ool3000SOol20004Ool20003Ool3000V
Ool20004Ool20004Ool2000[Ool50005Ool001Eoo`03001oogoo00moo`03O1moogoo01Moo`04001o
ogoo0008Ool00`00Oomoo`0UOol01000Oomoo`002goo00<007ooOol08Goo00@007ooOol000Qoo`04
001oogoo000TOol01000Oomoo`0027oo00@007ooOol002aoo`03001oogoo00Eoo`005Goo00<007oo
Ool047oo00=l7gooOol05Woo00@007ooOol000Uoo`03001oogoo02Aoo`04001oogoo0008Ool5000R
Ool01000Oomoo`0027oo00@007ooOol002Aoo`04001oogoo0008Ool01000Oomoo`00;7oo00<007oo
Ool01Goo000EOol00`00Oomoo`0@Ool00g`OOomoo`0FOol01000Oomoo`002Woo00<007ooOol08goo
00@007ooOol000Qoo`04001oogoo000SOol01000Oomoo`0027oo0`009Goo00@007ooOol000Uoo`80
02eoo`03001oogoo00Eoo`005Goo0P004Goo00=l7gooOol05Woo00@007ooOol000Qoo`04001oogoo
000TOol01000Oomoo`002Goo00<007oo00008goo00@007ooOol000Uoo`03001oogoo02Aoo`04001o
ogoo0008Ool01000Oomoo`00;7oo00<007ooOol01Goo000EOol00`00Oomoo`0AOol00g`OOomoo`0F
Ool2000:Ool2000VOol2000;Ool2000TOol2000:Ool3000UOol2000:Ool2000/Ool20007Ool001Eo
o`03001oogoo015oo`03O1moogoo0?Aoo`005Goo00<007ooOol04Goo00=l7gooOol0m7oo000EOol0
0`00Oomoo`0AOol00g`OOomoo`3dOol001Eoo`03001oogoo019oo`03O1moogoo0>]oo`03O1moogoo
00Eoo`005Goo00<007ooOol04Woo00=l7gooOol0jgoo00=l7gooOol01Goo000>OolL00000g`O0000
003Z00000g`O00000006000001Eoo`03001oogoo00Yoo`03001oogoo00Eoo`03O1moogoo009oo`03
001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03
001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03
001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03
001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03O1l007oo00Ioo`005Goo00<007ooOol0
4goo00=l7gooOol06goo00<007ooOol0<Goo00<007ooOol0<7oo00<007ooOol0<Goo00<007ooOol0
<7oo00=l7`00Ool01Woo000EOol00`00Oomoo`0COol00g`OOomoo`3XOol00g`OOomoo`07Ool001Eo
o`03001oogoo01=oo`03O1moogoo0>Qoo`03O1moogoo00Moo`005Goo00<007ooOol057oo00=l7goo
Ool0igoo00=l7gooOol01goo000EOol00`00Oomoo`0DOol00g`OOomoo`3VOol00g`OOomoo`08Ool0
01Eoo`03001oogoo01Aoo`03O1moogoo0>Ioo`03O1moogoo00Qoo`005Goo0P005Woo00=l7gooOol0
iGoo00=l7gooOol027oo000EOol00`00Oomoo`0EOol00g`OOomoo`3TOol00g`OOomoo`09Ool001Eo
o`03001oogoo01Eoo`03O1moogoo0>Aoo`03O1moogoo00Uoo`005Goo00<007ooOol05Woo00=l7goo
Ool0hgoo00=l7gooOol02Goo000EOol00`00Oomoo`0FOol00g`OOomoo`3ROol00g`OOomoo`0:Ool0
01Eoo`03001oogoo01Ioo`03O1moogoo0>9oo`03O1moogoo00Yoo`005Goo00<007ooOol05goo00=l
7gooOol0hGoo00=l7gooOol02Woo000EOol2000HOol00g`OOomoo`3POol00g`OOomoo`0;Ool001Eo
o`03001oogoo01Moo`03O1moogoo0>1oo`03O1moogoo00]oo`005Goo00<007ooOol067oo00=l7goo
Ool0ggoo00=l7gooOol02goo000EOol00`00Oomoo`0HOol00g`OOomoo`3NOol00g`OOomoo`0<Ool0
01Eoo`03001oogoo01Uoo`03O1moogoo0=eoo`03O1moogoo00aoo`005Goo00<007ooOol06Goo00=l
7gooOol0gGoo00=l7gooOol037oo000EOol00`00Oomoo`0IOol00g`OOomoo`3LOol00g`OOomoo`0=
Ool001Eoo`03001oogoo01Yoo`03O1moogoo0=]oo`03O1moogoo00eoo`005Goo0P006goo00=l7goo
Ool0fgoo00=l7gooOol03Goo000EOol00`00Oomoo`0JOol00g`OOomoo`3JOol00g`OOomoo`0>Ool0
01Eoo`03001oogoo01]oo`03O1moogoo0=Uoo`03O1moogoo00ioo`005Goo00<007ooOol06goo00=l
7gooOol0fGoo00=l7gooOol03Woo000EOol00`00Oomoo`0KOol00g`OOomoo`3HOol00g`OOomoo`0?
Ool00004Ool000000003Ool40003Ool20005Ool00`00Oomoo`0LOol00g`OOomoo`3GOol00g`OOomo
o`0?Ool00005Ool007ooOol00002Ool00`00Oomoo`03Ool01000Oomoo`0017oo00<007ooOol077oo
00=l7gooOol0egoo00=l7gooOol03goo00001Goo001oogoo00000goo00<007ooOol00Woo00@007oo
Ool000Aoo`<001aoo`03O1moogoo0=Ioo`03O1moogoo011oo`0000Aoo`00000000Eoo`05001oogoo
Ool00002Ool00`00Oomoo`02Ool00`00Oomoo`0MOol00g`OOomoo`3EOol00g`OOomoo`0@Ool0009o
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol07Goo00=l7gooOol0
e7oo00=l7gooOol04Goo0002Ool30003Ool20004Ool20005Ool00`00Oomoo`0MOol00g`OOomoo`3D
Ool00g`OOomoo`0AOol001Eoo`03001oogoo01ioo`03O1moogoo0=9oo`03O1moogoo019oo`005Goo
00<007ooOol07Woo00=l7gooOol0dWoo00=l7gooOol04Woo000EOol00`00Oomoo`0NOol00g`OOomo
o`3BOol00g`OOomoo`0BOol001Eoo`80021oo`03O1moogoo0=1oo`03O1moogoo01=oo`005Goo00<0
07ooOol07goo00=l7gooOol0d7oo00=l7gooOol04goo000EOol00`00Oomoo`0POol00g`OOomoo`3>
Ool00g`OOomoo`0DOol001Eoo`03001oogoo021oo`03O1moogoo0<ioo`03O1moogoo01Aoo`005Goo
00<007ooOol087oo00=l7gooOol0cGoo00=l7gooOol05Goo000EOol00`00Oomoo`0QOol00g`OOomo
o`3<Ool00g`OOomoo`0EOol001Eoo`03001oogoo025oo`03O1moogoo0<aoo`03O1moogoo01Eoo`00
5Goo00<007ooOol08Woo00=l7gooOol0bWoo00=l7gooOol05Woo000EOol2000SOol00g`OOomoo`3:
Ool00g`OOomoo`0FOol001Eoo`03001oogoo029oo`03O1moogoo0<Uoo`03O1moogoo01Moo`005Goo
00<007ooOol08goo00=l7gooOol0b7oo00=l7gooOol05goo000EOol00`00Oomoo`0SOol00g`OOomo
o`38Ool00g`OOomoo`0GOol001Eoo`03001oogoo02Aoo`03O1moogoo0<Ioo`03O1moogoo01Qoo`00
5Goo00<007ooOol097oo00=l7gooOol0aWoo00=l7gooOol067oo000EOol00`00Oomoo`0TOol00g`O
Oomoo`35Ool00g`OOomoo`0IOol001Eoo`8002Ioo`03O1moogoo0<Aoo`03O1moogoo01Uoo`005Goo
00<007ooOol09Goo00=l7gooOol0`goo00=l7gooOol06Woo000EOol00`00Oomoo`0VOol00g`OOomo
o`32Ool00g`OOomoo`0JOol001Eoo`03001oogoo02Ioo`03O1moogoo0<5oo`03O1moogoo01]oo`00
5Goo00<007ooOol09Woo00=l7gooOol0`Goo00=l7gooOol06goo000EOol00`00Oomoo`0WOol00g`O
Oomoo`2oOol00g`OOomoo`0LOol00004Ool000000005Ool30002Ool20005Ool00`00Oomoo`0WOol0
0g`OOomoo`2oOol00g`OOomoo`0LOol00005Ool007ooOol00005Ool01000Oomoo`000Woo00<007oo
Ool00Woo00<007ooOol0:7oo00=l7gooOol0_Goo00=l7gooOol07Goo00001Goo001oogoo00000Woo
1@0000Eoo`00Oomoo`0000Aoo`<002Qoo`03O1moogoo0;eoo`03O1moogoo01eoo`0000Aoo`000000
00=oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0:Goo00=l7gooOol0^goo00=l7goo
Ool07Woo0002Ool00`00Oomoo`03Ool00`00Ool00002Ool01000Oomoo`0017oo00<007ooOol0:Goo
00=l7gooOol0^goo00=l7gooOol07Woo0002Ool30004Ool20003Ool20005Ool00`00Oomoo`0ZOol0
0g`OOomoo`2iOol00g`OOomoo`0OOol001Eoo`03001oogoo02Yoo`03O1moogoo0;Uoo`03O1moogoo
01moo`005Goo00<007ooOol0:goo00=l7gooOol0]goo00=l7gooOol087oo000EOol00`00Oomoo`0[
Ool00g`OOomoo`2gOol00g`OOomoo`0POol001Eoo`8002eoo`03O1moogoo0;Eoo`03O1moogoo025o
o`005Goo00<007ooOol0;7oo00=l7gooOol0]Goo00=l7gooOol08Goo000EOol00`00Oomoo`0]Ool0
0g`OOomoo`2cOol00g`OOomoo`0ROol001Eoo`03001oogoo02eoo`03O1moogoo0;=oo`03O1moogoo
029oo`005Goo00<007ooOol0;Woo00=l7gooOol0/Goo00=l7gooOol08goo000EOol00`00Oomoo`0^
Ool00g`OOomoo`2aOol00g`OOomoo`0SOol001Eoo`03001oogoo02moo`03O1moogoo0:moo`03O1mo
ogoo02Aoo`005Goo00<007ooOol0;goo00=l7gooOol0[goo00=l7gooOol097oo000EOol2000aOol0
0g`OOomoo`2]Ool00g`OOomoo`0UOol001Eoo`03001oogoo031oo`03O1moogoo0:eoo`03O1moogoo
02Eoo`005Goo00<007ooOol0<Goo00=l7gooOol0Zgoo00=l7gooOol09Woo000EOol00`00Oomoo`0a
Ool00g`OOomoo`2[Ool00g`OOomoo`0VOol001Eoo`03001oogoo039oo`03O1moogoo0:Uoo`03O1mo
ogoo02Moo`005Goo00<007ooOol0<Woo00=l7gooOol0ZGoo00=l7gooOol09goo000EOol00`00Oomo
o`0cOol00g`OOomoo`2WOol00g`OOomoo`0XOol001Eoo`8003Eoo`03O1moogoo0:Ioo`03O1moogoo
02Qoo`005Goo00<007ooOol0=7oo00=l7gooOol0YGoo00=l7gooOol0:Goo000EOol00`00Oomoo`0e
Ool00g`OOomoo`2TOol00g`OOomoo`0YOol001Eoo`03001oogoo03Ioo`03O1moogoo0:9oo`03O1mo
ogoo02Yoo`005Goo00<007ooOol0=Woo00=l7gooOol0XGoo00=l7gooOol0:goo000017oo00000000
0goo0`0017oo0P001Goo00<007ooOol0=goo00=l7gooOol0X7oo00=l7gooOol0:goo00001Goo001o
ogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`0hOol00g`OOomoo`2NOol0
0g`OOomoo`0/Ool00005Ool007ooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`<003Uo
o`03O1moogoo09eoo`03O1moogoo02aoo`0000Aoo`00000000=oo`<000=oo`04001oogoo0004Ool0
0`00Oomoo`0iOol00g`OOomoo`2LOol00g`OOomoo`0]Ool0009oo`03001oogoo00=oo`03001oogoo
009oo`04001oogoo0004Ool00`00Oomoo`0jOol00g`OOomoo`2KOol00g`OOomoo`0]Ool0009oo`<0
00=oo`<000=oo`8000Eoo`03001oogoo03]oo`03O1moogoo09Uoo`03O1moogoo02ioo`005Goo00<0
07ooOol0>goo00=l7gooOol0VGoo00=l7gooOol0;Woo000EOol00`00Oomoo`0lOol00g`OOomoo`2G
Ool00g`OOomoo`0_Ool001Eoo`03001oogoo03eoo`03O1moogoo09Eoo`03O1moogoo031oo`005Goo
00<007ooOol0?Goo00=l7gooOol0UGoo00=l7gooOol0<7oo000EOol2000oOol00g`OOomoo`2COol0
0g`OOomoo`0aOol001Eoo`03001oogoo03moo`03O1moogoo095oo`03O1moogoo039oo`005Goo00<0
07ooOol0?goo00=l7gooOol0T7oo00=l7gooOol0<goo000EOol00`00Oomoo`10Ool00g`OOomoo`2?
Ool00g`OOomoo`0cOol001Eoo`03001oogoo045oo`03O1moogoo08eoo`03O1moogoo03Aoo`005Goo
00<007ooOol0@Woo00=l7gooOol0Rgoo00=l7gooOol0=Goo000EOol00`00Oomoo`12Ool00g`OOomo
o`2:Ool00g`OOomoo`0fOol001Eoo`8004Aoo`03O1moogoo08Uoo`03O1moogoo03Ioo`005Goo00<0
07ooOol0A7oo00=l7gooOol0Qgoo00=l7gooOol0=goo000EOol00`00Oomoo`15Ool00g`OOomoo`25
Ool00g`OOomoo`0hOol001Eoo`03001oogoo04Eoo`03O1moogoo08Aoo`03O1moogoo03Uoo`005Goo
00<007ooOol0AWoo00=l7gooOol0Pgoo00=l7gooOol0>Goo000EOol00`00Oomoo`17Ool00g`OOomo
o`21Ool00g`OOomoo`0jOol001Eoo`03001oogoo04Qoo`03O1moogoo07moo`03O1moogoo03]oo`00
5Goo00<007ooOol0B7oo00=l7gooOol0OWoo00=l7gooOol0?7oo000EOol2001:Ool00g`OOomoo`1l
Ool00g`OOomoo`0mOol001Eoo`03001oogoo04Yoo`03O1moogoo07Yoo`03O1moogoo03ioo`005Goo
00<007ooOol0Bgoo00=l7gooOol0N7oo00=l7gooOol0?goo000EOol00`00Oomoo`1<Ool00g`OOomo
o`1fOol00g`OOomoo`10Ool001Eoo`03001oogoo04eoo`03O1moogoo07Eoo`03O1moogoo041oo`00
00Aoo`00000000Aoo`8000Aoo`8000Eoo`03001oogoo04ioo`9l7gAoo`03O1moogoo045oo`0000Eo
o`00Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0D7oo00=l7gooOol0
L7oo00=l7gooOol0@Woo00001Goo001oogoo00000Woo00@007ooOol0009oo`04001oogoo0004Ool3
001AOol00g`OOomoo`1^Ool00g`OOomoo`13Ool00004Ool000000004Ool20003Ool01000Oomoo`00
17oo00<007ooOol0DWoo00=l7gooOol0K7oo00=l7gooOol0A7oo0002Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00@007ooOol000Aoo`03001oogoo05=oo`03O1moogoo06Yoo`03O1moogoo04Eoo`00
0Woo0`000goo0P0017oo0P001Goo00<007ooOol0E7oo00=l7gooOol0J7oo00=l7gooOol0AWoo000E
Ool00`00Oomoo`1EOol00g`OOomoo`1UOol2O1m9Ool001Eoo`03001oogoo05Ioo`9l7fAoo`03O1mo
ogoo04Uoo`005Goo00<007ooOol0F7oo00=l7gooOol0H7oo00=l7gooOol0BWoo000EOol2001JOol0
0g`OOomoo`1NOol00g`OOomoo`1;Ool001Eoo`03001oogoo05Yoo`03O1moogoo05aoo`03O1moogoo
04aoo`005Goo00<007ooOol0Fgoo0W`OFWoo0W`OCgoo000EOol00`00Oomoo`1MOol00g`OOomoo`1F
Ool00g`OOomoo`1?Ool001Eoo`03001oogoo05ioo`03O1moogoo05Aoo`03O1moogoo051oo`005Goo
00<007ooOol0Ggoo0W`ODWoo0W`ODgoo000EOol00`00Oomoo`1QOol00g`OOomoo`1>Ool00g`OOomo
o`1COol001Eoo`03001oogoo069oo`9l7daoo`9l7eIoo`005Goo0P00IGoo00=l7gooOol0Agoo0W`O
F7oo000EOol00`00Oomoo`1UOol2O1m6Ool00g`OOomoo`1HOol001Eoo`03001oogoo06Moo`9l7d9o
o`9l7e]oo`005Goo00<007ooOol0JGoo0W`O?goo00=l7gooOol0Fgoo000EOol00`00Oomoo`1[Ool3
O1ljOol2O1mNOol001Eoo`03001oogoo06ioo`=l7cEoo`9l7f1oo`005Goo00<007ooOol0LGoo0W`O
<7oo0g`OHWoo000EOol2001dOol3O1lYOol4O1mUOol001Eoo`03001oogoo07Ioo`9l7bAoo`=l7fUo
o`005Goo00<007ooOol0N7oo0g`O7Woo0g`OK7oo000EOol00`00Oomoo`1kOol8O1lAOol5O1m_Ool0
01Eoo`03001oogoo08=ooa5l7gAoo`005Goo00<007ooOol0ogoo2Goo0003Ool00`00Oomoo`02Ool2
0004Ool20005Ool00`00Oomoo`3oOol9Ool000=oo`05001oogooOol00002Ool01000Oomoo`000Woo
00<007ooOol00Woo00<007ooOol0ogoo2Goo0003Ool01@00Oomoogoo00000Woo00@007ooOol0009o
o`03001oogoo009oo`<00?moo`Uoo`0017oo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomo
o`3oOol>Ool00005Ool007ooOol00002Ool01000Oomoo`000Woo00@007ooOol00?mooa1oo`0000=o
o`0000000P000goo0P0017oo0P00ogoo4Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0825959, 585.39, \
0.00385924, 0.673356}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(tbl = 
        Table[{x\ G3\ PS1/\((G3\ x\ PS1 + G4\ \((1 - x)\)\ PS2)\), 
            G3\ x\ PS1 + G4\ \((1 - x)\)\ PS2}, {x, 0, 1, 
            0.01}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(plt11 = 
      ListPlot[tbl, PlotStyle \[Rule] RGBColor[1, 0, 1], 
        PlotJoined \[Rule] True]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -2.04324 0.00379482 [
[.21429 .03141 -9 -9 ]
[.21429 .03141 9 0 ]
[.40476 .03141 -9 -9 ]
[.40476 .03141 9 0 ]
[.59524 .03141 -9 -9 ]
[.59524 .03141 9 0 ]
[.78571 .03141 -9 -9 ]
[.78571 .03141 9 0 ]
[.97619 .03141 -3 -9 ]
[.97619 .03141 3 0 ]
[.01131 .13878 -18 -4.5 ]
[.01131 .13878 0 4.5 ]
[.01131 .23365 -18 -4.5 ]
[.01131 .23365 0 4.5 ]
[.01131 .32852 -18 -4.5 ]
[.01131 .32852 0 4.5 ]
[.01131 .42339 -18 -4.5 ]
[.01131 .42339 0 4.5 ]
[.01131 .51826 -18 -4.5 ]
[.01131 .51826 0 4.5 ]
[.01131 .61313 -18 -4.5 ]
[.01131 .61313 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .04391 m
.21429 .05016 L
s
[(0.2)] .21429 .03141 0 1 Mshowa
.40476 .04391 m
.40476 .05016 L
s
[(0.4)] .40476 .03141 0 1 Mshowa
.59524 .04391 m
.59524 .05016 L
s
[(0.6)] .59524 .03141 0 1 Mshowa
.78571 .04391 m
.78571 .05016 L
s
[(0.8)] .78571 .03141 0 1 Mshowa
.97619 .04391 m
.97619 .05016 L
s
[(1)] .97619 .03141 0 1 Mshowa
.125 Mabswid
.07143 .04391 m
.07143 .04766 L
s
.11905 .04391 m
.11905 .04766 L
s
.16667 .04391 m
.16667 .04766 L
s
.2619 .04391 m
.2619 .04766 L
s
.30952 .04391 m
.30952 .04766 L
s
.35714 .04391 m
.35714 .04766 L
s
.45238 .04391 m
.45238 .04766 L
s
.5 .04391 m
.5 .04766 L
s
.54762 .04391 m
.54762 .04766 L
s
.64286 .04391 m
.64286 .04766 L
s
.69048 .04391 m
.69048 .04766 L
s
.7381 .04391 m
.7381 .04766 L
s
.83333 .04391 m
.83333 .04766 L
s
.88095 .04391 m
.88095 .04766 L
s
.92857 .04391 m
.92857 .04766 L
s
.25 Mabswid
0 .04391 m
1 .04391 L
s
.02381 .13878 m
.03006 .13878 L
s
[(575)] .01131 .13878 1 0 Mshowa
.02381 .23365 m
.03006 .23365 L
s
[(600)] .01131 .23365 1 0 Mshowa
.02381 .32852 m
.03006 .32852 L
s
[(625)] .01131 .32852 1 0 Mshowa
.02381 .42339 m
.03006 .42339 L
s
[(650)] .01131 .42339 1 0 Mshowa
.02381 .51826 m
.03006 .51826 L
s
[(675)] .01131 .51826 1 0 Mshowa
.02381 .61313 m
.03006 .61313 L
s
[(700)] .01131 .61313 1 0 Mshowa
.125 Mabswid
.02381 .06288 m
.02756 .06288 L
s
.02381 .08185 m
.02756 .08185 L
s
.02381 .10083 m
.02756 .10083 L
s
.02381 .1198 m
.02756 .1198 L
s
.02381 .15775 m
.02756 .15775 L
s
.02381 .17672 m
.02756 .17672 L
s
.02381 .1957 m
.02756 .1957 L
s
.02381 .21467 m
.02756 .21467 L
s
.02381 .25262 m
.02756 .25262 L
s
.02381 .27159 m
.02756 .27159 L
s
.02381 .29057 m
.02756 .29057 L
s
.02381 .30954 m
.02756 .30954 L
s
.02381 .34749 m
.02756 .34749 L
s
.02381 .36647 m
.02756 .36647 L
s
.02381 .38544 m
.02756 .38544 L
s
.02381 .40441 m
.02756 .40441 L
s
.02381 .44236 m
.02756 .44236 L
s
.02381 .46134 m
.02756 .46134 L
s
.02381 .48031 m
.02756 .48031 L
s
.02381 .49928 m
.02756 .49928 L
s
.02381 .53723 m
.02756 .53723 L
s
.02381 .55621 m
.02756 .55621 L
s
.02381 .57518 m
.02756 .57518 L
s
.02381 .59415 m
.02756 .59415 L
s
.02381 .02493 m
.02756 .02493 L
s
.02381 .00596 m
.02756 .00596 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
.02381 .01472 m
.04771 .04678 L
.07004 .07727 L
.09096 .10626 L
.1106 .13382 L
.12908 .16002 L
.14651 .18494 L
.16298 .20864 L
.17857 .23118 L
.19336 .25261 L
.20742 .27299 L
.22079 .29238 L
.23355 .31081 L
.24573 .32835 L
.25739 .34503 L
.26856 .36089 L
.27927 .37597 L
.28957 .39031 L
.29947 .40395 L
.30902 .41691 L
.31824 .42924 L
.32714 .44095 L
.33576 .45208 L
.34411 .46266 L
.35221 .4727 L
.36008 .48224 L
.36774 .49129 L
.3752 .49987 L
.38247 .50801 L
.38957 .51572 L
.39652 .52302 L
.40332 .52992 L
.40999 .53645 L
.41653 .54261 L
.42296 .54842 L
.42928 .55389 L
.43551 .55903 L
.44165 .56385 L
.44772 .56836 L
.45371 .57257 L
.45965 .57648 L
.46553 .58011 L
.47136 .58346 L
.47716 .58654 L
.48292 .58935 L
.48865 .59189 L
.49436 .59418 L
.50006 .5962 L
.50575 .59797 L
.51144 .59949 L
Mistroke
.51714 .60076 L
.52284 .60177 L
.52857 .60254 L
.53431 .60305 L
.54008 .60331 L
.54589 .60332 L
.55173 .60307 L
.55763 .60257 L
.56357 .6018 L
.56957 .60078 L
.57564 .59948 L
.58177 .59792 L
.58799 .59607 L
.59428 .59395 L
.60067 .59154 L
.60715 .58884 L
.61373 .58584 L
.62043 .58253 L
.62724 .5789 L
.63418 .57496 L
.64125 .57068 L
.64846 .56607 L
.65582 .56111 L
.66334 .55579 L
.67103 .5501 L
.6789 .54403 L
.68696 .53758 L
.69521 .53072 L
.70367 .52345 L
.71235 .51576 L
.72127 .50762 L
.73043 .49904 L
.73986 .48999 L
.74956 .48046 L
.75954 .47044 L
.76984 .45991 L
.78046 .44885 L
.79142 .43725 L
.80274 .4251 L
.81444 .41236 L
.82655 .39904 L
.83909 .38511 L
.85208 .37054 L
.86556 .35533 L
.87954 .33945 L
.89407 .32288 L
.90918 .3056 L
.9249 .28759 L
.94128 .26883 L
.95836 .2493 L
Mistroke
.97619 .22896 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`005Goo00<007ooOol0:Woo0P0017oo0P000goo10009Goo0P0017oo0P001Goo0`00
8goo0P0017oo0P000goo0`009Woo0P0017oo0P0017oo0P00:goo1@001Goo000EOol2000ZOol01000
Oomoo`0027oo00<007ooOol09Goo00@007ooOol000]oo`03001oogoo025oo`04001oogoo0008Ool0
1000Oomoo`0097oo00@007ooOol000Qoo`04001oogoo000/Ool00`00Oomoo`05Ool001Eoo`03001o
ogoo02Uoo`04001oogoo0009Ool00`00Oomoo`0TOol01000Oomoo`0027oo1@008Woo00@007ooOol0
00Qoo`04001oogoo000TOol01000Oomoo`0027oo00@007ooOol002aoo`03001oogoo00Eoo`005Goo
00<007ooOol0:Goo00@007ooOol000Yoo`03001oogoo02=oo`04001oogoo0008Ool01000Oomoo`00
8goo00@007ooOol000Qoo`<002Eoo`04001oogoo0009Ool2000]Ool00`00Oomoo`05Ool001Eoo`03
O1moogoo02Uoo`04001oogoo0008Ool01000Oomoo`0097oo00@007ooOol000Uoo`03001oo`0002=o
o`04001oogoo0009Ool00`00Oomoo`0TOol01000Oomoo`0027oo00@007ooOol002aoo`03001oogoo
00Eoo`005Goo00<007`OOol0:Woo0P002Woo0P009Woo0P002goo0P0097oo0P002Woo0`009Goo0P00
2Woo0P00;7oo0P001goo000EOol200000g`OOomoo`3oOol7Ool001Eoo`03001oog`O0?moo`Uoo`00
5Goo00@007ooOoml7omoo`Qoo`005Goo00D007ooOomoog`O0?moo`Moo`005Goo00<007ooOol00Woo
00=l7gooOol0ogoo17oo000EOol00`00Oomoo`02Ool00g`OOomoo`3oOol4Ool000ioo`d00003O1l0
00000?l000<000005Goo00<007ooOol017oo00=l7gooOol00goo00<007ooOol02Woo00<007ooOol0
2Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol0
2Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol0
2Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol0
2Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol01Goo000EOol00`00Oomoo`04Ool00g`O
Oomoo`3oOol2Ool001Eoo`03001oogoo00Eoo`03O1moogoo0?moo`5oo`005Goo00<007ooOol01Woo
00=l7gooOol0ogoo000EOol20007Ool00g`OOomoo`3oOol001Eoo`03001oogoo00Moo`03O1moogoo
0?ioo`005Goo00<007ooOol027oo00=l7gooOol0oGoo000EOol00`00Oomoo`08Ool00g`OOomoo`3m
Ool001Eoo`03001oogoo00Uoo`03O1moogoo0?aoo`005Goo0P002goo00=l7gooOol0ngoo000EOol0
0`00Oomoo`0;Ool00g`OOomoo`3jOol001Eoo`03001oogoo00]oo`03O1moogoo0?Yoo`005Goo00<0
07ooOol037oo00=l7gooOol0nGoo000EOol00`00Oomoo`0=Ool00g`OOomoo`3hOol001Eoo`8000mo
o`03O1moogoo0?Moo`005Goo00<007ooOol03Woo00=l7gooOol0mgoo000EOol00`00Oomoo`0?Ool0
0g`OOomoo`3fOol001Eoo`03001oogoo011oo`03O1moogoo0?Eoo`005Goo00<007ooOol04Goo00=l
7gooOol0m7oo000EOol2000COol00g`OOomoo`3cOol001Eoo`03001oogoo019oo`03O1moogoo0?=o
o`005Goo00<007ooOol04goo00=l7gooOol0lWoo0002Ool20005Ool00`00Oomoo`02Ool20005Ool0
0`00Oomoo`0DOol00g`OOomoo`3aOol00005Ool007ooOol00004Ool01@00Oomoogoo00000Woo00<0
07ooOol00Woo00<007ooOol05Goo00=l7gooOol0l7oo0004Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool3000FOol00g`OOomoo`3_Ool0009oo`8000Ioo`04001oogooOol20005Ool0
0`00Oomoo`0FOol00g`OOomoo`3_Ool0009oo`03001oogoo009oo`04001oogoo0003Ool00`00Oomo
o`04Ool00`00Oomoo`0GOol00g`OOomoo`3^Ool0009oo`<0009oo`@000=oo`<000Aoo`03001oogoo
01Qoo`03O1moogoo0>eoo`005Goo00<007ooOol06Goo00=l7gooOol0k7oo000EOol00`00Oomoo`0I
Ool00g`OOomoo`3/Ool001Eoo`8001]oo`03O1moogoo0>]oo`005Goo00<007ooOol06goo00=l7goo
Ool0jWoo000EOol00`00Oomoo`0KOol00g`OOomoo`3ZOol001Eoo`03001oogoo01aoo`03O1moogoo
0>Uoo`005Goo00<007ooOol077oo00=l7gooOol0jGoo000EOol2000NOol00g`OOomoo`3XOol001Eo
o`03001oogoo01eoo`03O1moogoo0>Qoo`005Goo00<007ooOol07Woo00=l7gooOol0igoo000EOol0
0`00Oomoo`0OOol00g`OOomoo`3VOol001Eoo`03001oogoo021oo`03O1moogoo0>Eoo`005Goo0P00
8Woo00=l7gooOol0i7oo000EOol00`00Oomoo`0QOol00g`OOomoo`3TOol001Eoo`03001oogoo029o
o`03O1moogoo0>=oo`005Goo00<007ooOol08goo00=l7gooOol0hWoo000EOol00`00Oomoo`0TOol0
0g`OOomoo`3QOol001Eoo`8002Eoo`03O1moogoo0>5oo`005Goo00<007ooOol09Goo00=l7gooOol0
h7oo000EOol00`00Oomoo`0VOol00g`OOomoo`3OOol00004Ool000000004Ool20004Ool20005Ool0
0`00Oomoo`0VOol00g`OOomoo`3OOol00005Ool007ooOol00002Ool01000Oomoo`000Woo00@007oo
Ool000Aoo`03001oogoo02Moo`03O1moogoo0=Ioo`03O1moogoo00Eoo`0000Eoo`00Oomoo`00009o
o`04001oogoo0002Ool01000Oomoo`0017oo0`00:7oo00=l7gooOol0e7oo00=l7gooOol01Woo0000
17oo000000000goo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`0XOol00g`OOomoo`3C
Ool00g`OOomoo`07Ool0009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo00<0
07ooOol0:Goo00=l7gooOol0dGoo00=l7gooOol027oo0002Ool30003Ool20004Ool20005Ool00`00
Oomoo`0ZOol00g`OOomoo`3?Ool00g`OOomoo`09Ool001Eoo`03001oogoo02Yoo`03O1moogoo0<io
o`03O1moogoo00Yoo`005Goo0P00;7oo00=l7gooOol0c7oo00=l7gooOol02goo000EOol00`00Oomo
o`0/Ool00g`OOomoo`3;Ool00g`OOomoo`0;Ool001Eoo`03001oogoo02aoo`03O1moogoo0<Yoo`03
O1moogoo00aoo`005Goo00<007ooOol0;Goo00=l7gooOol0b7oo00=l7gooOol03Goo000EOol00`00
Oomoo`0^Ool00g`OOomoo`37Ool00g`OOomoo`0=Ool001Eoo`8002moo`03O1moogoo0<Ioo`03O1mo
ogoo00ioo`005Goo00<007ooOol0;goo00=l7gooOol0a7oo00=l7gooOol03goo000EOol00`00Oomo
o`0`Ool00g`OOomoo`32Ool00g`OOomoo`0@Ool001Eoo`03001oogoo031oo`03O1moogoo0<5oo`03
O1moogoo015oo`005Goo00<007ooOol0<Goo00=l7gooOol0_goo00=l7gooOol04Woo000EOol00`00
Oomoo`0aOol00g`OOomoo`2nOol00g`OOomoo`0COol001Eoo`8003=oo`03O1moogoo0;aoo`03O1mo
ogoo01Aoo`005Goo00<007ooOol0<goo00=l7gooOol0^Woo00=l7gooOol05Goo000EOol00`00Oomo
o`0dOol00g`OOomoo`2iOol00g`OOomoo`0EOol001Eoo`03001oogoo03Aoo`03O1moogoo0;Qoo`03
O1moogoo01Ioo`005Goo00<007ooOol0=Goo00=l7gooOol0]Woo00=l7gooOol05goo000EOol2000g
Ool00g`OOomoo`2dOol00g`OOomoo`0HOol001Eoo`03001oogoo03Moo`03O1moogoo0;9oo`03O1mo
ogoo01Uoo`005Goo00<007ooOol0=goo00=l7gooOol0/Goo00=l7gooOol06Woo000017oo00000000
0goo10000goo0P001Goo00<007ooOol0>7oo00=l7gooOol0[goo00=l7gooOol06goo00001Goo001o
ogoo00000Woo00<007ooOol00goo00@007ooOol000Aoo`03001oogoo03Qoo`03O1moogoo0:ioo`03
O1moogoo01aoo`0000Eoo`00Oomoo`0000=oo`03001oogoo00Eoo`03001oogoo009oo`<003Uoo`03
O1moogoo0:aoo`03O1moogoo01eoo`0000Aoo`00000000Eoo`03001oogoo009oo`8000Eoo`03001o
ogoo03Yoo`03O1moogoo0:]oo`03O1moogoo01eoo`000Woo00<007ooOol00Woo00@007ooOol000=o
o`03001oogoo00Aoo`03001oogoo03]oo`03O1moogoo0:Uoo`03O1moogoo01ioo`000Woo0`000goo
0P0017oo0`0017oo00<007ooOol0>goo00=l7gooOol0Z7oo00=l7gooOol07goo000EOol00`00Oomo
o`0lOol00g`OOomoo`2VOol00g`OOomoo`0POol001Eoo`8003ioo`03O1moogoo0:Aoo`03O1moogoo
025oo`005Goo00<007ooOol0?Goo00=l7gooOol0Xgoo00=l7gooOol08Woo000EOol00`00Oomoo`0n
Ool00g`OOomoo`2QOol00g`OOomoo`0SOol001Eoo`03001oogoo03ioo`03O1moogoo0:1oo`03O1mo
ogoo02Aoo`005Goo00<007ooOol0?goo00=l7gooOol0WWoo00=l7gooOol09Goo000EOol20011Ool0
0g`OOomoo`2LOol00g`OOomoo`0VOol001Eoo`03001oogoo045oo`03O1moogoo09Yoo`03O1moogoo
02Moo`005Goo00<007ooOol0@Goo00=l7gooOol0VGoo00=l7gooOol0:7oo000EOol00`00Oomoo`12
Ool00g`OOomoo`2GOol00g`OOomoo`0YOol001Eoo`03001oogoo04=oo`03O1moogoo09Ioo`03O1mo
ogoo02Uoo`005Goo0P00AGoo00=l7gooOol0U7oo00=l7gooOol0:Woo000EOol00`00Oomoo`14Ool0
0g`OOomoo`2COol00g`OOomoo`0[Ool001Eoo`03001oogoo04Eoo`03O1moogoo095oo`03O1moogoo
02aoo`005Goo00<007ooOol0AWoo00=l7gooOol0Sgoo00=l7gooOol0;Goo000EOol00`00Oomoo`17
Ool00g`OOomoo`2=Ool00g`OOomoo`0^Ool001Eoo`03001oogoo04Moo`03O1moogoo08aoo`03O1mo
ogoo02moo`005Goo0P00BGoo00=l7gooOol0RWoo00=l7gooOol0<7oo000EOol00`00Oomoo`19Ool0
0g`OOomoo`29Ool00g`OOomoo`0`Ool001Eoo`03001oogoo04Yoo`03O1moogoo08Moo`03O1moogoo
035oo`0000Aoo`00000000Aoo`8000Aoo`8000Eoo`03001oogoo04]oo`03O1moogoo08Eoo`03O1mo
ogoo039oo`0000Eoo`00Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0
C7oo00=l7gooOol0Pgoo00=l7gooOol0<goo00001Goo001oogoo00001Goo00@007ooOol0009oo`03
001oogoo009oo`<004aoo`03O1moogoo089oo`03O1moogoo03Aoo`0000Aoo`00000000Aoo`8000=o
o`04001oogoo0004Ool00`00Oomoo`1=Ool00g`OOomoo`20Ool00g`OOomoo`0eOol0009oo`03001o
ogoo00=oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`1>Ool00g`OOomoo`1nOol00g`O
Oomoo`0fOol0009oo`<000=oo`<000=oo`8000Eoo`03001oogoo04ioo`03O1moogoo07ioo`03O1mo
ogoo03Ioo`005Goo00<007ooOol0Cgoo00=l7gooOol0O7oo00=l7gooOol0=goo000EOol2001@Ool0
0g`OOomoo`1kOol00g`OOomoo`0hOol001Eoo`03001oogoo051oo`03O1moogoo07Uoo`03O1moogoo
03Uoo`005Goo00<007ooOol0DGoo00=l7gooOol0Mgoo00=l7gooOol0>Woo000EOol00`00Oomoo`1B
Ool00g`OOomoo`1eOol00g`OOomoo`0kOol001Eoo`03001oogoo05=oo`03O1moogoo07=oo`03O1mo
ogoo03aoo`005Goo0P00EGoo00=l7gooOol0LGoo00=l7gooOol0?Goo000EOol00`00Oomoo`1EOol0
0g`OOomoo`1_Ool00g`OOomoo`0nOol001Eoo`03001oogoo05Eoo`03O1moogoo06ioo`03O1moogoo
03moo`005Goo00<007ooOol0EWoo00=l7gooOol0K7oo00=l7gooOol0@7oo000EOol00`00Oomoo`1G
Ool00g`OOomoo`1YOol2O1m3Ool001Eoo`8005Qoo`03O1moogoo06Qoo`03O1moogoo04=oo`005Goo
00<007ooOol0F7oo00=l7gooOol0IWoo00=l7gooOol0A7oo000EOol00`00Oomoo`1IOol00g`OOomo
o`1UOol00g`OOomoo`14Ool001Eoo`03001oogoo05Yoo`03O1moogoo06=oo`03O1moogoo04Eoo`00
5Goo00<007ooOol0Fgoo00=l7gooOol0H7oo0W`OB7oo000EOol2001MOol00g`OOomoo`1NOol00g`O
Oomoo`18Ool001Eoo`03001oogoo05eoo`03O1moogoo05aoo`03O1moogoo04Uoo`005Goo00<007oo
Ool0GWoo00=l7gooOol0Fgoo00=l7gooOol0BGoo000EOol00`00Oomoo`1NOol00g`OOomoo`1JOol0
0g`OOomoo`1:Ool00004Ool000000005Ool00`00Oomoo`02Ool20005Ool00`00Oomoo`1OOol00g`O
Oomoo`1GOol2O1m=Ool00005Ool007ooOol00004Ool01@00Oomoogoo00000Woo00<007ooOol00Woo
00<007ooOol0H7oo00=l7gooOol0EGoo00=l7gooOol0CGoo00001Goo001oogoo000017oo00<007oo
Ool017oo00<007ooOol00Woo0`00HGoo00=l7gooOol0Dgoo00=l7gooOol0CWoo000017oo00000000
1Woo00@007ooOomoo`8000Eoo`03001oogoo069oo`03O1moogoo055oo`03O1moogoo04moo`000Woo
00<007ooOol00Woo00@007ooOol000=oo`03001oogoo00Aoo`03001oogoo06=oo`03O1moogoo04mo
o`03O1moogoo051oo`000Woo0`000Woo10000goo0`0017oo00<007ooOol0I7oo00=l7gooOol0CGoo
00=l7gooOol0DGoo000EOol00`00Oomoo`1UOol00g`OOomoo`1:Ool2O1mDOol001Eoo`8006Moo`03
O1moogoo04Qoo`03O1moogoo05Aoo`005Goo00<007ooOol0Igoo0W`OAgoo00=l7gooOol0EGoo000E
Ool00`00Oomoo`1YOol00g`OOomoo`13Ool00g`OOomoo`1FOol001Eoo`03001oogoo06Yoo`03O1mo
ogoo041oo`9l7eUoo`005Goo00<007ooOol0Jgoo00=l7gooOol0?Woo00=l7gooOol0FGoo000EOol2
001]Ool00g`OOomoo`0lOol00g`OOomoo`1JOol001Eoo`03001oogoo06eoo`03O1moogoo03Uoo`9l
7eeoo`005Goo00<007ooOol0KWoo0W`O>7oo00=l7gooOol0GGoo000EOol00`00Oomoo`1`Ool00g`O
Oomoo`0dOol00g`OOomoo`1NOol001Eoo`03001oogoo075oo`9l7c9oo`9l7f5oo`005Goo0P00M7oo
00=l7gooOol0;Goo0W`OHgoo000EOol00`00Oomoo`1dOol2O1l[Ool2O1mUOol001Eoo`03001oogoo
07Ioo`9l7bMoo`9l7fMoo`005Goo00<007ooOol0N7oo00=l7gooOol08Woo0W`OJGoo000EOol00`00
Oomoo`1iOol2O1lQOol00g`OOomoo`1YOol001Eoo`8007aoo`=l7aYoo`Al7faoo`005Goo00<007oo
Ool0OWoo0g`O57oo0g`OL7oo000EOol00`00Oomoo`21Ool5O1l:Ool5O1mcOol000=oo`03001oogoo
009oo`8000Aoo`8000Eoo`03001oogoo08Ioo`Yl7gQoo`000goo00D007ooOomoo`00009oo`04001o
ogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`3oOol9Ool000=oo`05001oogooOol00002Ool01000
Oomoo`000Woo00<007ooOol00Woo0`00ogoo2Goo0004Ool01000Oomoo`000Woo00@007ooOol0009o
o`03001oogoo009oo`03001oogoo0?moo`Uoo`0000Eoo`00Oomoo`00009oo`04001oogoo0002Ool0
1000Oomoo`0017oo00<007ooOol0ogoo2Goo00000goo000000020003Ool20004Ool2003oOolAOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0825959, 535.487, \
0.00385924, 0.968548}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[plt10, plt11]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -2.04315 0.00379464 [
[.21429 .0314 -9 -9 ]
[.21429 .0314 9 0 ]
[.40476 .0314 -9 -9 ]
[.40476 .0314 9 0 ]
[.59524 .0314 -9 -9 ]
[.59524 .0314 9 0 ]
[.78571 .0314 -9 -9 ]
[.78571 .0314 9 0 ]
[.97619 .0314 -3 -9 ]
[.97619 .0314 3 0 ]
[.01131 .13877 -18 -4.5 ]
[.01131 .13877 0 4.5 ]
[.01131 .23364 -18 -4.5 ]
[.01131 .23364 0 4.5 ]
[.01131 .3285 -18 -4.5 ]
[.01131 .3285 0 4.5 ]
[.01131 .42337 -18 -4.5 ]
[.01131 .42337 0 4.5 ]
[.01131 .51823 -18 -4.5 ]
[.01131 .51823 0 4.5 ]
[.01131 .6131 -18 -4.5 ]
[.01131 .6131 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .0439 m
.21429 .05015 L
s
[(0.2)] .21429 .0314 0 1 Mshowa
.40476 .0439 m
.40476 .05015 L
s
[(0.4)] .40476 .0314 0 1 Mshowa
.59524 .0439 m
.59524 .05015 L
s
[(0.6)] .59524 .0314 0 1 Mshowa
.78571 .0439 m
.78571 .05015 L
s
[(0.8)] .78571 .0314 0 1 Mshowa
.97619 .0439 m
.97619 .05015 L
s
[(1)] .97619 .0314 0 1 Mshowa
.125 Mabswid
.07143 .0439 m
.07143 .04765 L
s
.11905 .0439 m
.11905 .04765 L
s
.16667 .0439 m
.16667 .04765 L
s
.2619 .0439 m
.2619 .04765 L
s
.30952 .0439 m
.30952 .04765 L
s
.35714 .0439 m
.35714 .04765 L
s
.45238 .0439 m
.45238 .04765 L
s
.5 .0439 m
.5 .04765 L
s
.54762 .0439 m
.54762 .04765 L
s
.64286 .0439 m
.64286 .04765 L
s
.69048 .0439 m
.69048 .04765 L
s
.7381 .0439 m
.7381 .04765 L
s
.83333 .0439 m
.83333 .04765 L
s
.88095 .0439 m
.88095 .04765 L
s
.92857 .0439 m
.92857 .04765 L
s
.25 Mabswid
0 .0439 m
1 .0439 L
s
.02381 .13877 m
.03006 .13877 L
s
[(575)] .01131 .13877 1 0 Mshowa
.02381 .23364 m
.03006 .23364 L
s
[(600)] .01131 .23364 1 0 Mshowa
.02381 .3285 m
.03006 .3285 L
s
[(625)] .01131 .3285 1 0 Mshowa
.02381 .42337 m
.03006 .42337 L
s
[(650)] .01131 .42337 1 0 Mshowa
.02381 .51823 m
.03006 .51823 L
s
[(675)] .01131 .51823 1 0 Mshowa
.02381 .6131 m
.03006 .6131 L
s
[(700)] .01131 .6131 1 0 Mshowa
.125 Mabswid
.02381 .06288 m
.02756 .06288 L
s
.02381 .08185 m
.02756 .08185 L
s
.02381 .10082 m
.02756 .10082 L
s
.02381 .1198 m
.02756 .1198 L
s
.02381 .15774 m
.02756 .15774 L
s
.02381 .17672 m
.02756 .17672 L
s
.02381 .19569 m
.02756 .19569 L
s
.02381 .21466 m
.02756 .21466 L
s
.02381 .25261 m
.02756 .25261 L
s
.02381 .27158 m
.02756 .27158 L
s
.02381 .29056 m
.02756 .29056 L
s
.02381 .30953 m
.02756 .30953 L
s
.02381 .34748 m
.02756 .34748 L
s
.02381 .36645 m
.02756 .36645 L
s
.02381 .38542 m
.02756 .38542 L
s
.02381 .4044 m
.02756 .4044 L
s
.02381 .44234 m
.02756 .44234 L
s
.02381 .46131 m
.02756 .46131 L
s
.02381 .48029 m
.02756 .48029 L
s
.02381 .49926 m
.02756 .49926 L
s
.02381 .53721 m
.02756 .53721 L
s
.02381 .55618 m
.02756 .55618 L
s
.02381 .57515 m
.02756 .57515 L
s
.02381 .59413 m
.02756 .59413 L
s
.02381 .02493 m
.02756 .02493 L
s
.02381 .00596 m
.02756 .00596 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
.02381 .01472 m
.06244 .13533 L
.10458 .24161 L
.14415 .32205 L
.18221 .3851 L
.22272 .43962 L
.26171 .48203 L
.30316 .51816 L
.34309 .54567 L
.3815 .56637 L
.40095 .57492 L
.42237 .58295 L
.44292 .58934 L
.46172 .59411 L
.48113 .59798 L
.49195 .59968 L
.502 .60096 L
.51119 .6019 L
.52099 .60263 L
.52659 .60294 L
.52933 .60305 L
.53186 .60314 L
.53411 .6032 L
.53659 .60326 L
.53788 .60328 L
.53908 .6033 L
.54035 .60331 L
.54106 .60331 L
.54171 .60332 L
.54289 .60332 L
.544 .60332 L
.54521 .60331 L
.54652 .6033 L
.54782 .60329 L
.54918 .60327 L
.55163 .60322 L
.5539 .60316 L
.55601 .60309 L
.5608 .60288 L
.56606 .60258 L
.57084 .60224 L
.58156 .60123 L
.59154 .59999 L
.60074 .59858 L
.62154 .59446 L
.6403 .58956 L
.66094 .58285 L
.70128 .5654 L
.74011 .54268 L
.78138 .51135 L
Mistroke
.82114 .47327 L
.85939 .42834 L
.90009 .37039 L
.93927 .30341 L
.97619 .22895 L
Mfstroke
.02381 .01472 m
.04771 .04678 L
.07004 .07727 L
.09096 .10625 L
.1106 .13381 L
.12908 .16002 L
.14651 .18493 L
.16298 .20863 L
.17857 .23116 L
.19336 .2526 L
.20742 .27298 L
.22079 .29236 L
.23355 .3108 L
.24573 .32833 L
.25739 .34501 L
.26856 .36087 L
.27927 .37595 L
.28957 .39029 L
.29947 .40393 L
.30902 .4169 L
.31824 .42922 L
.32714 .44093 L
.33576 .45206 L
.34411 .46264 L
.35221 .47268 L
.36008 .48222 L
.36774 .49126 L
.3752 .49985 L
.38247 .50799 L
.38957 .5157 L
.39652 .523 L
.40332 .5299 L
.40999 .53643 L
.41653 .54259 L
.42296 .5484 L
.42928 .55386 L
.43551 .559 L
.44165 .56382 L
.44772 .56833 L
.45371 .57254 L
.45965 .57646 L
.46553 .58009 L
.47136 .58344 L
.47716 .58651 L
.48292 .58932 L
.48865 .59187 L
.49436 .59415 L
.50006 .59618 L
.50575 .59795 L
.51144 .59946 L
Mistroke
.51714 .60073 L
.52284 .60174 L
.52857 .60251 L
.53431 .60302 L
.54008 .60328 L
.54589 .60329 L
.55173 .60304 L
.55763 .60254 L
.56357 .60178 L
.56957 .60075 L
.57564 .59945 L
.58177 .59789 L
.58799 .59605 L
.59428 .59392 L
.60067 .59151 L
.60715 .58881 L
.61373 .58581 L
.62043 .5825 L
.62724 .57888 L
.63418 .57493 L
.64125 .57066 L
.64846 .56604 L
.65582 .56108 L
.66334 .55576 L
.67103 .55007 L
.6789 .54401 L
.68696 .53755 L
.69521 .5307 L
.70367 .52343 L
.71235 .51573 L
.72127 .5076 L
.73043 .49902 L
.73986 .48997 L
.74956 .48044 L
.75954 .47042 L
.76984 .45989 L
.78046 .44883 L
.79142 .43723 L
.80274 .42508 L
.81444 .41235 L
.82655 .39902 L
.83909 .38509 L
.85208 .37053 L
.86556 .35531 L
.87954 .33943 L
.89407 .32287 L
.90918 .30559 L
.9249 .28758 L
.94128 .26882 L
.95836 .24928 L
Mistroke
.97619 .22895 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`005Goo00<007ooOol0:Woo0P0017oo0P000goo10009Goo0P0017oo0P001Goo0`00
8goo0P0017oo0P000goo0`009Woo0P0017oo0P0017oo0P00:goo1@001Goo000EOol2000ZOol01000
Oomoo`0027oo00<007ooOol09Goo00@007ooOol000]oo`03001oogoo025oo`04001oogoo0008Ool0
1000Oomoo`0097oo00@007ooOol000Qoo`04001oogoo000/Ool00`00Oomoo`05Ool001Eoo`03001o
ogoo02Uoo`04001oogoo0009Ool00`00Oomoo`0TOol01000Oomoo`0027oo1@008Woo00@007ooOol0
00Qoo`04001oogoo000TOol01000Oomoo`0027oo00@007ooOol002aoo`03001oogoo00Eoo`005Goo
00<007ooOol0:Goo00@007ooOol000Yoo`03001oogoo02=oo`04001oogoo0008Ool01000Oomoo`00
8goo00@007ooOol000Qoo`<002Eoo`04001oogoo0009Ool2000]Ool00`00Oomoo`05Ool001Eoo`03
O1moogoo02Uoo`04001oogoo0008Ool01000Oomoo`0097oo00@007ooOol000Uoo`03001oo`0002=o
o`04001oogoo0009Ool00`00Oomoo`0TOol01000Oomoo`0027oo00@007ooOol002aoo`03001oogoo
00Eoo`005Goo0W`O:goo0P002Woo0P009Woo0P002goo0P0097oo0P002Woo0`009Goo0P002Woo0P00
;7oo0P001goo000EOol00`00O1ml7`3oOol9Ool001Eoo`03001l7g`O0?moo`Uoo`005Goo00@007`O
Ooml7omoo`Qoo`005Goo00D007ooO1moog`O0?moo`Moo`005Goo00<007ooO1l00Woo00=l7gooOol0
ogoo17oo000EOol00`00Ooml7`02Ool00g`OOomoo`3oOol4Ool000ioo`X00004O1l00000O1oo0005
000001Eoo`04001oogooO1l3Ool00g`OOomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00
Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00
Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00
Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool001Eoo`04001oogooO1l3Ool00g`OOomoo`3o
Ool2Ool001Eoo`04001oogooO1l4Ool00g`OOomoo`3oOol1Ool001Eoo`05001oogooOoml7`04Ool0
0g`OOomoo`3oOol001Eoo`80009oo`03O1moogoo009oo`03O1moogoo0?moo`005Goo00D007ooOomo
og`O00Eoo`03O1moogoo0?ioo`005Goo00<007ooOol00Woo00=l7gooOol00goo00=l7gooOol0oGoo
000EOol00`00Oomoo`02Ool00g`OOomoo`03Ool00g`OOomoo`3mOol001Eoo`03001oogoo009oo`03
O1moogoo00Aoo`03O1moogoo0?aoo`005Goo0P0017oo00=l7gooOol017oo00=l7gooOol0ngoo000E
Ool00`00Oomoo`03Ool00g`OOomoo`05Ool00g`OOomoo`3jOol001Eoo`03001oogoo00=oo`03O1mo
ogoo00Eoo`03O1moogoo0?Yoo`005Goo00<007ooOol017oo00=l7gooOol01Goo00=l7gooOol0nGoo
000EOol00`00Oomoo`04Ool00g`OOomoo`06Ool00g`OOomoo`3hOol001Eoo`8000Eoo`03O1moogoo
00Moo`03O1moogoo0?Moo`005Goo00<007ooOol01Goo00=l7gooOol01Woo00=l7gooOol0mgoo000E
Ool00`00Oomoo`05Ool00g`OOomoo`07Ool00g`OOomoo`3fOol001Eoo`03001oogoo00Eoo`03O1mo
ogoo00Qoo`03O1moogoo0?Eoo`005Goo00<007ooOol01Goo00=l7gooOol02Goo00=l7gooOol0m7oo
000EOol20007Ool00g`OOomoo`09Ool00g`OOomoo`3cOol001Eoo`03001oogoo00Ioo`03O1moogoo
00Uoo`03O1moogoo0?=oo`005Goo00<007ooOol01Woo00=l7gooOol02Woo00=l7gooOol0lWoo0002
Ool20005Ool00`00Oomoo`02Ool20005Ool00`00Oomoo`07Ool00g`OOomoo`0:Ool00g`OOomoo`3a
Ool00005Ool007ooOol00004Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol01goo
00=l7gooOol02goo00=l7gooOol0l7oo0004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool30007Ool00g`OOomoo`0<Ool00g`OOomoo`3_Ool0009oo`8000Ioo`04001oogooOol20005
Ool00`00Oomoo`08Ool00g`OOomoo`0;Ool00g`OOomoo`3_Ool0009oo`03001oogoo009oo`04001o
ogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00g`OOomoo`0<Ool00g`OOomoo`3^Ool0009o
o`<0009oo`@000=oo`<000Aoo`03001oogoo00Uoo`03O1moogoo00aoo`03O1moogoo0>eoo`005Goo
00<007ooOol02Goo00=l7gooOol03Goo00=l7gooOol0k7oo000EOol00`00Oomoo`09Ool00g`OOomo
o`0=Ool00g`OOomoo`3/Ool001Eoo`8000]oo`03O1moogoo00eoo`03O1moogoo0>]oo`005Goo00<0
07ooOol02Woo00=l7gooOol03Woo00=l7gooOol0jWoo000EOol00`00Oomoo`0;Ool00g`OOomoo`0=
Ool00g`OOomoo`3ZOol001Eoo`03001oogoo00]oo`03O1moogoo00ioo`03O1moogoo0>Uoo`005Goo
00<007ooOol037oo00=l7gooOol03Goo00=l7gooOol0jGoo000EOol2000=Ool00g`OOomoo`0>Ool0
0g`OOomoo`3XOol001Eoo`03001oogoo00aoo`03O1moogoo00ioo`03O1moogoo0>Qoo`005Goo00<0
07ooOol03Goo00=l7gooOol03Woo00=l7gooOol0igoo000EOol00`00Oomoo`0=Ool00g`OOomoo`0?
Ool00g`OOomoo`3VOol001Eoo`03001oogoo00ioo`03O1moogoo00moo`03O1moogoo0>Eoo`005Goo
0P003goo00=l7gooOol047oo00=l7gooOol0i7oo000EOol00`00Oomoo`0>Ool00g`OOomoo`0@Ool0
0g`OOomoo`3TOol001Eoo`03001oogoo00moo`03O1moogoo011oo`03O1moogoo0>=oo`005Goo00<0
07ooOol03goo00=l7gooOol04Goo00=l7gooOol0hWoo000EOol00`00Oomoo`0@Ool00g`OOomoo`0A
Ool00g`OOomoo`3QOol001Eoo`80015oo`03O1moogoo015oo`03O1moogoo0>5oo`005Goo00<007oo
Ool04Goo00=l7gooOol04Goo00=l7gooOol0h7oo000EOol00`00Oomoo`0AOol00g`OOomoo`0BOol0
0g`OOomoo`3OOol00004Ool000000004Ool20004Ool20005Ool00`00Oomoo`0AOol00g`OOomoo`0B
Ool00g`OOomoo`3OOol00005Ool007ooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`03
001oogoo019oo`03O1moogoo019oo`03O1moogoo0=Ioo`03O1moogoo00Eoo`0000Eoo`00Oomoo`00
009oo`04001oogoo0002Ool01000Oomoo`0017oo0`004Woo00=l7gooOol04goo00=l7gooOol0e7oo
00=l7gooOol01Woo000017oo000000000goo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomo
o`0COol00g`OOomoo`0BOol00g`OOomoo`3COol2O1l8Ool0009oo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`0017oo00<007ooOol04goo00=l7gooOol04goo00=l7gooOol0dGoo0W`O2Goo
0002Ool30003Ool20004Ool20005Ool00`00Oomoo`0DOol00g`OOomoo`0COol00g`OOomoo`3?Ool0
0g`OOoml7`09Ool001Eoo`03001oogoo01Aoo`03O1moogoo01=oo`03O1moogoo0<ioo`03O1moog`O
00Yoo`005Goo0P005Woo00=l7gooOol04goo00=l7gooOol0c7oo00Al7gooOoml7`Yoo`005Goo00<0
07ooOol05Goo00=l7gooOol057oo00=l7gooOol0bgoo00=l7gooO1l02goo000EOol00`00Oomoo`0F
Ool00g`OOomoo`0COol00g`OOomoo`3:Ool017`OOomoog`O2goo000EOol00`00Oomoo`0FOol00g`O
Oomoo`0DOol00g`OOomoo`38Ool017`OOomoog`O37oo000EOol00`00Oomoo`0GOol00g`OOomoo`0D
Ool00g`OOomoo`37Ool017`OOomoog`O37oo000EOol2000HOol00g`OOomoo`0DOol00g`OOomoo`36
Ool017`OOomoog`O3Goo000EOol00`00Oomoo`0HOol00g`OOomoo`0DOol00g`OOomoo`34Ool01G`O
OomoogooO1l03Goo000EOol00`00Oomoo`0HOol00g`OOomoo`0EOol00g`OOomoo`32Ool01G`OOomo
ogooO1l03Woo000EOol00`00Oomoo`0IOol00g`OOomoo`0DOol00g`OOomoo`31Ool00g`OOomoo`02
Ool00g`OOomoo`0<Ool001Eoo`03001oogoo01Uoo`03O1moogoo01Eoo`03O1moogoo0;moo`03O1mo
ogoo009oo`03O1moogoo00eoo`005Goo00<007ooOol06Woo00=l7gooOol057oo00=l7gooOol0_Woo
00=l7gooOol00goo00=l7gooOol03Goo000EOol2000KOol00g`OOomoo`0EOol00g`OOomoo`2lOol0
0g`OOomoo`03Ool00g`OOomoo`0>Ool001Eoo`03001oogoo01]oo`03O1moogoo01Eoo`03O1moogoo
0;Yoo`03O1moogoo00Aoo`03O1moogoo00ioo`005Goo00<007ooOol06goo00=l7gooOol05Woo00=l
7gooOol0^Goo00=l7gooOol00goo00=l7gooOol03goo000EOol00`00Oomoo`0LOol00g`OOomoo`0E
Ool00g`OOomoo`2hOol00g`OOomoo`04Ool00g`OOomoo`0?Ool001Eoo`03001oogoo01aoo`03O1mo
ogoo01Ioo`03O1moogoo0;Ioo`03O1moogoo00Aoo`03O1moogoo011oo`005Goo0P007Woo00=l7goo
Ool05Woo00=l7gooOol0]7oo00=l7gooOol01Goo00=l7gooOol047oo000EOol00`00Oomoo`0MOol0
0g`OOomoo`0GOol00g`OOomoo`2bOol00g`OOomoo`05Ool00g`OOomoo`0AOol001Eoo`03001oogoo
01ioo`03O1moogoo01Ioo`03O1moogoo0;5oo`03O1moogoo00Ioo`03O1moogoo015oo`0000Aoo`00
000000=oo`@000=oo`8000Eoo`03001oogoo01ioo`03O1moogoo01Moo`03O1moogoo0:moo`03O1mo
ogoo00Ioo`03O1moogoo019oo`0000Eoo`00Oomoo`00009oo`03001oogoo00=oo`04001oogoo0004
Ool00`00Oomoo`0OOol00g`OOomoo`0FOol00g`OOomoo`2^Ool00g`OOomoo`06Ool00g`OOomoo`0C
Ool00005Ool007ooOol00003Ool00`00Oomoo`05Ool00`00Oomoo`02Ool3000OOol00g`OOomoo`0G
Ool00g`OOomoo`2/Ool00g`OOomoo`07Ool00g`OOomoo`0COol00004Ool000000005Ool00`00Oomo
o`02Ool20005Ool00`00Oomoo`0POol00g`OOomoo`0GOol00g`OOomoo`2[Ool00g`OOomoo`06Ool0
0g`OOomoo`0DOol0009oo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomo
o`0POol00g`OOomoo`0HOol00g`OOomoo`2YOol00g`OOomoo`06Ool00g`OOomoo`0EOol0009oo`<0
00=oo`8000Aoo`<000Aoo`03001oogoo025oo`03O1moogoo01Moo`03O1moogoo0:Qoo`03O1moogoo
00Moo`03O1moogoo01Eoo`005Goo00<007ooOol08Woo00=l7gooOol05goo00=l7gooOol0YWoo00=l
7gooOol01goo00=l7gooOol05Woo000EOol2000SOol00g`OOomoo`0HOol00g`OOomoo`2TOol00g`O
Oomoo`08Ool00g`OOomoo`0FOol001Eoo`03001oogoo02=oo`03O1moogoo01Moo`03O1moogoo0:=o
o`03O1moogoo00Qoo`03O1moogoo01Moo`005Goo00<007ooOol08goo00=l7gooOol067oo00=l7goo
Ool0XGoo00=l7gooOol027oo00=l7gooOol067oo000EOol00`00Oomoo`0TOol00g`OOomoo`0GOol0
0g`OOomoo`2POol00g`OOomoo`09Ool00g`OOomoo`0HOol001Eoo`03001oogoo02Aoo`03O1moogoo
01Qoo`03O1moogoo09ioo`03O1moogoo00Uoo`03O1moogoo01Uoo`005Goo0P009Woo00=l7gooOol0
67oo00=l7gooOol0W7oo00=l7gooOol02Woo00=l7gooOol06Goo000EOol00`00Oomoo`0VOol00g`O
Oomoo`0HOol00g`OOomoo`2JOol00g`OOomoo`0:Ool00g`OOomoo`0JOol001Eoo`03001oogoo02Io
o`03O1moogoo01Qoo`03O1moogoo09Uoo`03O1moogoo00Yoo`03O1moogoo01]oo`005Goo00<007oo
Ool09goo00=l7gooOol067oo00=l7gooOol0Ugoo00=l7gooOol02goo00=l7gooOol06goo000EOol0
0`00Oomoo`0WOol00g`OOomoo`0IOol00g`OOomoo`2FOol00g`OOomoo`0:Ool00g`OOomoo`0LOol0
01Eoo`8002Uoo`03O1moogoo01Uoo`03O1moogoo09Aoo`03O1moogoo00Yoo`03O1moogoo01eoo`00
5Goo00<007ooOol0:Goo00=l7gooOol067oo00=l7gooOol0Tgoo00=l7gooOol02goo00=l7gooOol0
7Goo000EOol00`00Oomoo`0YOol00g`OOomoo`0IOol00g`OOomoo`2AOol00g`OOomoo`0;Ool00g`O
Oomoo`0NOol001Eoo`03001oogoo02Yoo`03O1moogoo01Uoo`03O1moogoo08moo`03O1moogoo00]o
o`03O1moogoo01moo`005Goo00<007ooOol0:goo00=l7gooOol06Goo00=l7gooOol0SGoo00=l7goo
Ool02goo00=l7gooOol087oo000EOol00`00Oomoo`0/Ool00g`OOomoo`0HOol00g`OOomoo`2<Ool0
0g`OOomoo`0<Ool00g`OOomoo`0POol001Eoo`8002eoo`03O1moogoo01Uoo`03O1moogoo08Yoo`03
O1moogoo00aoo`03O1moogoo025oo`005Goo00<007ooOol0;Goo00=l7gooOol06Goo00=l7gooOol0
RGoo00=l7gooOol02goo00=l7gooOol08Woo000EOol00`00Oomoo`0^Ool00g`OOomoo`0IOol00g`O
Oomoo`27Ool00g`OOomoo`0<Ool00g`OOomoo`0ROol00004Ool000000004Ool20004Ool20005Ool0
0`00Oomoo`0_Ool00g`OOomoo`0IOol00g`OOomoo`25Ool00g`OOomoo`0<Ool00g`OOomoo`0SOol0
0005Ool007ooOol00002Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo02moo`03O1mo
ogoo01Yoo`03O1moogoo08=oo`03O1moogoo00aoo`03O1moogoo02Aoo`0000Eoo`00Oomoo`0000Eo
o`04001oogoo0002Ool00`00Oomoo`02Ool3000`Ool00g`OOomoo`0IOol00g`OOomoo`22Ool00g`O
Oomoo`0=Ool00g`OOomoo`0TOol00004Ool000000004Ool20003Ool01000Oomoo`0017oo00<007oo
Ool0<Goo00=l7gooOol06Goo00=l7gooOol0P7oo00=l7gooOol03Goo00=l7gooOol09Goo0002Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol0<Woo00=l7gooOol06Goo
00=l7gooOol0OWoo00=l7gooOol03Goo00=l7gooOol09Woo0002Ool30003Ool30003Ool20005Ool0
0`00Oomoo`0bOol00g`OOomoo`0IOol00g`OOomoo`1nOol00g`OOomoo`0<Ool00g`OOomoo`0WOol0
01Eoo`03001oogoo03=oo`03O1moogoo01Uoo`03O1moogoo07aoo`03O1moogoo00aoo`03O1moogoo
02Qoo`005Goo0P00=Goo00=l7gooOol067oo00=l7gooOol0Ngoo00=l7gooOol03Goo00=l7gooOol0
:7oo000EOol00`00Oomoo`0eOol00g`OOomoo`0HOol00g`OOomoo`1iOol00g`OOomoo`0=Ool00g`O
Oomoo`0YOol001Eoo`03001oogoo03Ioo`03O1moogoo01Qoo`03O1moogoo07Moo`03O1moogoo00eo
o`03O1moogoo02Yoo`005Goo00<007ooOol0=goo00=l7gooOol067oo00=l7gooOol0MGoo00=l7goo
Ool03Goo00=l7gooOol0:goo000EOol00`00Oomoo`0hOol00g`OOomoo`0HOol00g`OOomoo`1cOol0
0g`OOomoo`0=Ool00g`OOomoo`0/Ool001Eoo`8003Yoo`03O1moogoo01Qoo`03O1moogoo075oo`03
O1moogoo00eoo`03O1moogoo02eoo`005Goo00<007ooOol0>Goo00=l7gooOol06Goo00=l7gooOol0
Kgoo00=l7gooOol03Woo00=l7gooOol0;Goo000EOol00`00Oomoo`0jOol00g`OOomoo`0HOol00g`O
Oomoo`1^Ool00g`OOomoo`0>Ool00g`OOomoo`0^Ool001Eoo`03001oogoo03]oo`03O1moogoo01Qo
o`03O1moogoo06aoo`03O1moogoo00ioo`03O1moogoo02moo`005Goo00<007ooOol0?7oo00=l7goo
Ool067oo00=l7gooOol0JGoo0W`O47oo00=l7gooOol0<7oo000EOol2000nOol00g`OOomoo`0GOol0
0g`OOomoo`1XOol00g`OOomoo`0?Ool00g`OOomoo`0aOol001Eoo`03001oogoo03ioo`03O1moogoo
01Moo`03O1moogoo06Ioo`03O1moogoo00moo`03O1moogoo039oo`005Goo00<007ooOol0?goo00=l
7gooOol05goo00=l7gooOol0IGoo00=l7gooOol03Woo00=l7gooOol0<goo000EOol00`00Oomoo`10
Ool00g`OOomoo`0GOol00g`OOomoo`1SOol00g`OOomoo`0>Ool00g`OOomoo`0dOol001Eoo`03001o
ogoo045oo`03O1moogoo01Moo`03O1moogoo061oo`9l7a1oo`03O1moogoo03Eoo`005Goo0P00@goo
00=l7gooOol05goo00=l7gooOol0GWoo00=l7gooOol03goo00=l7gooOol0=Woo000EOol00`00Oomo
o`13Ool2O1lHOol00g`OOomoo`1LOol00g`OOomoo`0?Ool00g`OOomoo`0gOol001Eoo`03001oogoo
04Eoo`03O1moogoo01Ioo`03O1moogoo05]oo`03O1moogoo00ioo`03O1moogoo03Qoo`005Goo00<0
07ooOol0AWoo00=l7gooOol05Goo00=l7gooOol0FWoo00=l7gooOol03Woo00=l7gooOol0>Goo0000
17oo000000001Goo00<007ooOol00Woo0P001Goo00<007ooOol0Agoo00=l7gooOol05Goo00=l7goo
Ool0Egoo0W`O47oo00=l7gooOol0>Woo00001Goo001oogoo000017oo00D007ooOomoo`00009oo`03
001oogoo009oo`03001oogoo04Qoo`03O1moogoo01Eoo`03O1moogoo05Eoo`03O1moogoo00ioo`9l
7ceoo`0000Eoo`00Oomoo`0000Aoo`03001oogoo00Aoo`03001oogoo009oo`<004Uoo`03O1moogoo
01Eoo`03O1moogoo05=oo`03O1moogoo00ioo`03O1moogoo03eoo`0000Aoo`00000000Ioo`04001o
ogooOol20005Ool00`00Oomoo`1:Ool2O1lFOol00g`OOomoo`1AOol00g`OOomoo`0>Ool00g`OOomo
o`0nOol0009oo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`1<Ool0
0g`OOomoo`0DOol00g`OOomoo`1?Ool00g`OOomoo`0=Ool2O1m1Ool0009oo`<0009oo`@000=oo`<0
00Aoo`03001oogoo04eoo`9l7aEoo`03O1moogoo04eoo`03O1moogoo00eoo`03O1moogoo045oo`00
5Goo00<007ooOol0Cgoo0W`O57oo00=l7gooOol0BWoo0W`O3goo00=l7gooOol0@Woo000EOol2001B
Ool00g`OOomoo`0BOol00g`OOomoo`18Ool00g`OOomoo`0=Ool2O1m5Ool001Eoo`03001oogoo059o
o`9l7a=oo`9l7dMoo`03O1moogoo00eoo`03O1moogoo04Eoo`005Goo00<007ooOol0E7oo00=l7goo
Ool04Woo00=l7gooOol0@goo00=l7gooOol037oo0W`OB7oo000EOol00`00Oomoo`1EOol2O1lCOol0
0g`OOomoo`10Ool2O1l=Ool2O1m:Ool001Eoo`03001oogoo05Moo`9l7a9oo`03O1moogoo03ioo`03
O1moogoo00]oo`9l7daoo`005Goo0P00FWoo00=l7gooOol047oo00=l7gooOol0?7oo00=l7gooOol0
2Woo0W`OCWoo000EOol00`00Oomoo`1JOol2O1lAOol00g`OOomoo`0iOol2O1l;Ool2O1m@Ool001Eo
o`03001oogoo05aoo`9l7a1oo`9l7cQoo`03O1moogoo00Uoo`9l7e9oo`005Goo00<007ooOol0GWoo
0W`O47oo00=l7gooOol0=7oo00=l7gooOol027oo0W`OE7oo000EOol00`00Oomoo`1POol3O1l>Ool2
O1lbOol2O1l9Ool2O1mFOol001Eoo`8006Aoo`=l7`eoo`03O1moogoo02eoo`9l7`Uoo`9l7eQoo`00
5Goo00<007ooOol0IWoo0W`O37oo0W`O:goo0W`O2Goo0W`OFWoo000EOol00`00Oomoo`1XOol3O1l;
Ool2O1lWOol2O1l8Ool3O1mLOol001Eoo`03001oogoo06]oo`=l7`Yoo`03O1moogoo029oo`9l7`Qo
o`9l7emoo`005Goo00<007ooOol0KWoo17`O1goo0W`O8Goo00=l7gooOol017oo17`OHGoo000EOol2
001cOol5O1l4Ool3O1lJOol4O1l2Ool5O1mUOol001Eoo`03001oogoo07Moo`Al7`=oo`=l7aAoo`=l
7`03Ooml7g`O00=l7fYoo`005Goo00<007ooOol0Ngoo2g`O2Woo2G`OKgoo0003Ool00`00Oomoo`02
Ool20004Ool20005Ool00`00Oomoo`23Ool?O1mfOol000=oo`05001oogooOol00002Ool01000Oomo
o`000Woo00<007ooOol00Woo00<007ooOol0ogoo2Goo0003Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`03001oogoo009oo`<00?moo`Uoo`0017oo00@007ooOol0009oo`04001oogoo0002Ool0
0`00Oomoo`02Ool00`00Oomoo`3oOol9Ool00005Ool007ooOol00002Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`03001oogoo0?moo`Uoo`0000=oo`0000000P000goo0P0017oo0P00ogoo4Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0825959, 535.483, \
0.00385924, 0.968594}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
CellGrouping->Manual,
WindowSize->{459, 630},
WindowMargins->{{35, Automatic}, {Automatic, -9}},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 191, 4, 128, "Title"],

Cell[CellGroupData[{
Cell[1992, 61, 116, 1, 46, "Subsubtitle"],
Cell[2111, 64, 153, 2, 70, "Input"],
Cell[2267, 68, 149, 2, 50, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2453, 75, 107, 1, 48, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2585, 80, 72, 1, 30, "Input"],
Cell[2660, 83, 64, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2761, 89, 72, 1, 30, "Input"],
Cell[2836, 92, 64, 1, 29, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2949, 99, 104, 1, 48, "Subsubtitle"],
Cell[3056, 102, 44, 1, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3137, 108, 114, 1, 48, "Subsubtitle"],
Cell[3254, 111, 78, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[3357, 116, 145, 3, 70, "Input"],
Cell[3505, 121, 14068, 414, 186, 4114, 287, "GraphicsData", "PostScript", \
"Graphics"],
Cell[17576, 537, 130, 3, 29, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[17755, 546, 119, 1, 48, "Subsubtitle"],
Cell[17877, 549, 60, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[17962, 554, 91, 1, 30, "Input"],
Cell[18056, 557, 143, 3, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18236, 565, 91, 1, 30, "Input"],
Cell[18330, 568, 141, 2, 32, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[18520, 576, 123, 1, 48, "Subsubtitle"],
Cell[18646, 579, 86, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[18757, 584, 145, 3, 70, "Input"],
Cell[18905, 589, 14220, 415, 186, 4104, 286, "GraphicsData", "PostScript", \
"Graphics"],
Cell[33128, 1006, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33295, 1014, 49, 1, 30, "Input"],
Cell[33347, 1017, 17902, 505, 186, 4918, 340, "GraphicsData", "PostScript", \
"Graphics"],
Cell[51252, 1524, 130, 3, 29, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[51431, 1533, 106, 1, 48, "Subsubtitle"],

Cell[CellGroupData[{
Cell[51562, 1538, 139, 3, 70, "Input"],
Cell[51704, 1543, 14485, 436, 186, 4487, 308, "GraphicsData", "PostScript", \
"Graphics"],
Cell[66192, 1981, 130, 3, 29, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[66371, 1990, 93, 1, 48, "Subsubtitle"],
Cell[66467, 1993, 75, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[66567, 1998, 106, 2, 50, "Input"],
Cell[66676, 2002, 15129, 407, 186, 3799, 263, "GraphicsData", "PostScript", \
"Graphics"],
Cell[81808, 2411, 130, 3, 29, "Output"]
}, Open  ]],
Cell[81953, 2417, 190, 4, 50, "Input"],

Cell[CellGroupData[{
Cell[82168, 2425, 132, 3, 70, "Input"],
Cell[82303, 2430, 15664, 480, 186, 5009, 344, "GraphicsData", "PostScript", \
"Graphics"],
Cell[97970, 2912, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[98137, 2920, 51, 1, 30, "Input"],
Cell[98191, 2923, 19979, 580, 186, 5841, 401, "GraphicsData", "PostScript", \
"Graphics"],
Cell[118173, 3505, 130, 3, 29, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

